(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    338774,       9114]
NotebookOptionsPosition[    256347,       7755]
NotebookOutlinePosition[    278465,       8198]
CellTagsIndexPosition[    277813,       8174]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Advanced Counting Techniques", "BookChapterTitle",
 CounterAssignments->{{
   "ChapterNumber", 
    8}},ExpressionUUID->"90393f42-285c-49fe-9b1e-ff41c080fa3d"],

Cell[CellGroupData[{

Cell["Introduction", "Section",ExpressionUUID->"634f0c93-103e-4a16-ba57-88c3f248d241"],

Cell[TextData[{
 "In this chapter, we will describe how to apply ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to three important topics in counting: recurrence relations, generating \
functions, and inclusion\[Dash]exclusion. We begin by describing how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to solve recurrence relations, including the recurrence \
relations that describe the complexity of divide-and-conquer algorithms. \
After studying recurrence relations, we show how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to manipulate generating functions and how these capabilities can help \
solve counting problems. We conclude the chapter with a discussion of the \
principle of inclusion\[Dash]exclusion."
}], "Text",ExpressionUUID->"1bcc21bd-863e-49c5-b4ff-2a6a5e78fcc0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.1 Recurrence Relations", "Section",
 CellTags->"Section1",ExpressionUUID->"3dd88c94-41fe-4900-aa96-71d35a31eecd"],

Cell[TextData[{
 "A recurrence relation describes a relationship between the members of a \
sequence and their predecessors. For example, the famous Fibonacci sequence \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["f", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "65f9e000-88df-4cbf-adcf-4310a6e5f0ee"],
 " satisfies the recurrence relation"
}], "Text",ExpressionUUID->"177fce75-0e91-4c5f-9e8c-ffd8103dde05"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", "n"], "=", 
   RowBox[{
    SubscriptBox["f", 
     RowBox[{"n", "-", "1"}]], "+", 
    SubscriptBox["f", 
     RowBox[{"n", "-", "2"}]]}]}], TraditionalForm]], "Equation",ExpressionUUI\
D->"025b8f0d-3dfb-4b6c-a36c-d88e0c1e3246"],

Cell[TextData[{
 "Together with the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "6dfb1c47-be1d-4147-9f26-ba7d4923dfa8"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "2"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "7f3f2c82-26cf-497d-b3af-a885a295f620"],
 ", this relation is sufficient to define the entire sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["f", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "0790d1ad-2b9d-4614-847f-ebc0c38497b2"],
 "."
}], "Text",ExpressionUUID->"2ec85a55-c5d7-4c86-8329-0d42828ee921"],

Cell[TextData[{
 "To understand how to work with recurrence relations in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", we have to remember that a sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "6ece1f95-2f6e-49e4-bfb8-5cab90eb5644"],
 " is a function whose domain is a subset of the integers (usually the \
positive integers or nonnegative integers, depending on the context) and \
whose codomain contains the terms of the sequence (which can be numbers, \
matrices, circles, functions, etc.). (See the definition of sequence given in \
Section 2.4 of the textbook.)"
}], "Text",ExpressionUUID->"e2145534-174e-4b2d-8c5a-244170afa7ad"],

Cell[TextData[{
 "With this point of view, the sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "5fdd31f4-759f-40f4-8da6-7b2413418278"],
 " is a function ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "ebf72bf6-96f7-4a6f-b037-1673fe831c70"],
 " and the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "6bd97c80-40c1-4807-8e50-69c924298e4f"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " term of the sequence is the value of the function evaluated at the integer \
",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7ed3c210-3513-4b1b-828b-b453c7a058b9"],
 ", that is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{"a", "(", "n", ")"}]}], TraditionalForm]],ExpressionUUID->
  "49d45ede-42e4-4ba6-9801-b073a36596d7"],
 ". This is only a change in notation, but it makes it easier to see that a \
recurrence relation can be represented with the Wolfram Language as a \
function taking integer arguments."
}], "Text",ExpressionUUID->"2a30eaad-a41d-455e-83b1-329bc221e5db"],

Cell["\<\
We can represent the Fibonacci sequence by the indexed variable and function \
below, which we use to compute the first 20 terms of the Fibonacci sequence. \
The initial conditions are given as specific assignments to an indexed \
variable, and the function that implements the recurrence relation stores \
computed values by assigning them to the indexed variable.\
\>", "Text",ExpressionUUID->"749a671e-4b5a-4286-8ecc-c98b05dfd1b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fibonacci", "[", "1", "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fibonacci", "[", "2", "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fibonacci", "[", "n_Integer", "]"}], ":=", 
   RowBox[{
    RowBox[{"fibonacci", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{"fibonacci", "[", 
      RowBox[{"n", "-", "1"}], "]"}], "+", 
     RowBox[{"fibonacci", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[1]:=",ExpressionUUID->"b496d452-f253-421f-882a-f5db8b504704"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"fibonacci", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"e49ae543-e79f-455a-9c27-9fd0c8334ff3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", "21",
    ",", "34", ",", "55", ",", "89", ",", "144", ",", "233", ",", "377", ",", 
   "610", ",", "987", ",", "1597", ",", "2584", ",", "4181", ",", "6765"}], 
  "}"}]], "Output",
 CellLabel->"Out[4]=",ExpressionUUID->"94e72dba-4dc9-4a7e-981a-f9df6502d3ad"]
}, Open  ]],

Cell["\<\
Using indexed variables and functions like the one above is the approach we \
developed in Section 5.3 of this manual to implement functions with recursive \
definitions. This is a useful general approach, but the Wolfram Language has \
more specific, and more efficient, methods for working with recurrence \
relations.\
\>", "Text",ExpressionUUID->"713e1b7d-f1e7-4f72-b12a-b87cbeab253c"],

Cell[TextData[{
 "The Wolfram Language function ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " is used to generate lists of the values of a sequence defined by a \
recurrence relation. ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " requires three arguments. The first argument must be a list of equations \
specifying the recurrence relation and all initial conditions. Note that \
these must be given as equations, using ",
 StyleBox[ButtonBox["Equal",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Equal"], "FunctionLink"],
 " (",
 StyleBox["==", "Code"],
 "). In addition, the equations should be in terms of indexed variables such \
as ",
 StyleBox["fibonacci[n]", "Code",
  IgnoreSpellCheck->True],
 " or ",
 StyleBox["a[k\[ThinSpace]-\[ThinSpace]1]", "Code"],
 ", or ",
 StyleBox["b[0]", "Code"],
 ". The second argument is the symbol used to name the sequence in the \
equations, for example, ",
 StyleBox["fibonacci", "Code",
  IgnoreSpellCheck->True],
 " or ",
 StyleBox["a", "Code"],
 ". The final argument is a range specification of the same form as used in a \
",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ". For example, ",
 StyleBox["{n,\[ThinSpace]10,\[ThinSpace]20}", "Code"],
 " would be used to generate the list of the values with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "10"}], TraditionalForm]],ExpressionUUID->
  "b5b200e8-4bb0-4c3b-a6ef-652cd03cb6a7"],
 " through ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "20"}], TraditionalForm]],ExpressionUUID->
  "f2f534c9-f796-4830-9835-f51b43697187"],
 " and ",
 StyleBox["{k,\[ThinSpace]10}", "Code"],
 " would generate the values up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "10"}], TraditionalForm]],ExpressionUUID->
  "1184f66c-07d0-481b-94ca-0f3c58e8aa95"],
 ". "
}], "Text",ExpressionUUID->"72efb391-23f8-486b-82ac-b4d6566703ee"],

Cell["\<\
To illustrate, the following generates the first 20 terms of the Fibonacci \
sequence. \
\>", "Text",ExpressionUUID->"d84c1a3b-3195-4d7e-9d84-e2fed349cf44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RecurrenceTable", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "n", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "+", 
       RowBox[{"a", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "a", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"ea5f9f0f-d88b-40e1-9900-0840dbba1900"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", "21",
    ",", "34", ",", "55", ",", "89", ",", "144", ",", "233", ",", "377", ",", 
   "610", ",", "987", ",", "1597", ",", "2584", ",", "4181", ",", "6765"}], 
  "}"}]], "Output",
 CellLabel->"Out[5]=",ExpressionUUID->"b3df81ec-8cab-4092-b00b-c2710b21b2ae"]
}, Open  ]],

Cell[TextData[{
 "For some common sequences like the Fibonacci sequence, the Wolfram Language \
includes special functions to compute these values. For example, the 15th \
Fibonacci number can be computed using the ",
 StyleBox[ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"], "FunctionLink"],
 " function."
}], "Text",ExpressionUUID->"053fdd6a-43b3-4555-b486-92ce8b47605b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fibonacci", "[", "15", "]"}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"46d0133d-a6dd-4f4f-950b-0fd03b752a91"],

Cell[BoxData["610"], "Output",
 CellLabel->"Out[6]=",ExpressionUUID->"223be65b-9c83-43af-a0dc-e7a8a3b03a65"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " function is very flexible, able to handle a wide variety of recurrence \
relations. For example, consider the recurrence relation defined by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", 
     RowBox[{"n", "+", "1"}]], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["a", "n"], "2"], "-", 
     RowBox[{"n", "\[CenterDot]", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "a9cf488c-b310-4dba-9641-4e8d54962a71"],
 ", with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "0"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "7d8679b9-4b31-4f36-b1b6-b5f1389b0b5e"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "85427a16-7fcc-4eb7-b371-739df9cf1ab8"],
 ". The following expression computes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "10"], TraditionalForm]],ExpressionUUID->
  "27fe58e7-dce7-4b4c-b1ac-28b9761b58c4"],
 ". Note the use of the ",
 StyleBox[ButtonBox["Last",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Last"], "FunctionLink"],
 " function to obtain the last element of the sequence. This is equivalent \
to, but perhaps more expressive than, the ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"], "FunctionLink"],
 " specification ",
 StyleBox["[[-1]]", "Code"],
 ". "
}], "Text",ExpressionUUID->"b13735d2-05cc-4254-bb3b-e3a52e9c0944"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Last", "[", 
  RowBox[{"RecurrenceTable", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"n", "+", "1"}], "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "n", "]"}], "^", "2"}], "-", 
        RowBox[{"n", "*", 
         RowBox[{"a", "[", 
          RowBox[{"n", "-", "1"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{"a", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "a", 
    ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "10"}], "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"5ef972ed-d277-443f-a5b7-f29fcbabe148"],

Cell[BoxData["83095558751833088261963048239982609365670356"], "Output",
 CellLabel->"Out[7]=",ExpressionUUID->"9e2ad163-b35f-42ee-af75-ab9f39fa694c"]
}, Open  ]],

Cell[TextData[{
 "While ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " is very general, sometimes a less-flexible function can be useful. The ",
 StyleBox[ButtonBox["LinearRecurrence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LinearRecurrence"], "FunctionLink"],
 " function produces output similar to that of ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " but applies only to linear homogeneous recurrence relations (defined in \
Section 8.2 of the textbook). ",
 StyleBox[ButtonBox["LinearRecurrence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LinearRecurrence"], "FunctionLink"],
 " applies for recurrence relations of the form"
}], "Text",ExpressionUUID->"a0db4996-bd6c-4e76-b944-60a471864d1a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}], "+", "\[CenterEllipsis]", "+", 
    RowBox[{
     SubscriptBox["c", "k"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "k"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"c5348678-893c-4ce2-b9cf-b3f4be998b45"],

Cell[TextData[{
 "with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], ",", 
    SubscriptBox["a", "2"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["a", "k"]}], TraditionalForm]],ExpressionUUID->
  "35f2a3f7-61bb-4141-bcad-82a50bf324c2"],
 ". ",
 StyleBox[ButtonBox["LinearRecurrence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LinearRecurrence"], "FunctionLink"],
 " requires three arguments. The first argument is the list of coefficients \
in the recurrence relation, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["c", "1"], ",", 
     SubscriptBox["c", "2"], ",", "\[Ellipsis]", ",", 
     SubscriptBox["c", "k"]}], "}"}], TraditionalForm]],ExpressionUUID->
  "cb12a80a-2c55-40fe-af84-416353539f71"],
 ". The second argument is the list of initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["a", "1"], ",", 
     SubscriptBox["a", "2"], ",", "\[Ellipsis]", ",", 
     SubscriptBox["a", "k"]}], "}"}], TraditionalForm]],ExpressionUUID->
  "43b9c126-43a4-4b56-ab46-6afc171d34c3"],
 ". Note that the two lists should generally be the same length. The final \
argument is either a single integer to indicate the number of terms of the \
sequence to produce or a pair of integers representing a range of indices."
}], "Text",ExpressionUUID->"af887004-7ea2-4798-8eb0-9a79c3bf0892"],

Cell[TextData[{
 "By way of comparison, the following two expressions use ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["LinearRecurrence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LinearRecurrence"], "FunctionLink"],
 " to compute the first 20 terms of the sequence defined by the recurrence \
relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"2", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}], "-", 
     RowBox[{"3", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "2"}]]}], "+", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "3"}]]}]}], TraditionalForm]],ExpressionUUID->
  "23ec163b-9131-4e41-9856-924b9fff7aae"],
 ", with initial values ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], "=", "1"}], ",", 
    RowBox[{
     SubscriptBox["a", "2"], "=", "3"}], ",", 
    RowBox[{
     SubscriptBox["a", "3"], "=", "5"}]}], TraditionalForm]],ExpressionUUID->
  "75ed0f0c-0311-41d3-8dc2-37c7ec39c010"],
 ". "
}], "Text",ExpressionUUID->"03a416df-df89-41bf-8837-ec1e92e5624d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RecurrenceTable", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "n", "]"}], "==", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"a", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "-", 
       RowBox[{"3", "*", 
        RowBox[{"a", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}], "+", 
       RowBox[{"a", "[", 
        RowBox[{"n", "-", "3"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}], ",", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], "\[Equal]", "3"}], ",", 
     RowBox[{
      RowBox[{"a", "[", "3", "]"}], "\[Equal]", "5"}]}], "}"}], ",", "a", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"38e9a73d-67ce-4d9e-b342-be482a658e24"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", "5", ",", "2", ",", 
   RowBox[{"-", "8"}], ",", 
   RowBox[{"-", "17"}], ",", 
   RowBox[{"-", "8"}], ",", "27", ",", "61", ",", "33", ",", 
   RowBox[{"-", "90"}], ",", 
   RowBox[{"-", "218"}], ",", 
   RowBox[{"-", "133"}], ",", "298", ",", "777", ",", "527", ",", 
   RowBox[{"-", "979"}], ",", 
   RowBox[{"-", "2762"}], ",", 
   RowBox[{"-", "2060"}], ",", "3187"}], "}"}]], "Output",
 CellLabel->"Out[8]=",ExpressionUUID->"b049695d-7300-407c-bd41-291fa5a5efd0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LinearRecurrence", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", "20"}], "]"}]], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"b36c3d73-3bae-4ee6-be2d-d15057f42c97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", "5", ",", "2", ",", 
   RowBox[{"-", "8"}], ",", 
   RowBox[{"-", "17"}], ",", 
   RowBox[{"-", "8"}], ",", "27", ",", "61", ",", "33", ",", 
   RowBox[{"-", "90"}], ",", 
   RowBox[{"-", "218"}], ",", 
   RowBox[{"-", "133"}], ",", "298", ",", "777", ",", "527", ",", 
   RowBox[{"-", "979"}], ",", 
   RowBox[{"-", "2762"}], ",", 
   RowBox[{"-", "2060"}], ",", "3187"}], "}"}]], "Output",
 CellLabel->"Out[9]=",ExpressionUUID->"f22e375d-4609-4056-a997-d98d2d077976"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tower of Hanoi Problem", "Subsection",
 CellTags->"Section1a",ExpressionUUID->"3386d020-aef5-4fe6-95ac-4c0d54acf17b"],

Cell["\<\
In Example 2 of Section 8.1 of the textbook, the author describes the famous \
\[OpenCurlyDoubleQuote]Tower of Hanoi\[CloseCurlyDoubleQuote] puzzle and \
derives the recurrence relation\
\>", "Text",ExpressionUUID->"305c9edb-4cdf-4b4e-90d9-c02135b63a06"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["H", "n"], "=", 
    RowBox[{
     RowBox[{"2", 
      SubscriptBox["H", 
       RowBox[{"n", "-", "1"}]]}], "+", "1"}]}], ",", "     ", 
   RowBox[{
    SubscriptBox["H", "1"], "=", "1"}]}], TraditionalForm]], "Equation",Expres\
sionUUID->"25392025-56df-41bf-b168-5757fe3eb6f0"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "n"], TraditionalForm]],ExpressionUUID->
  "a5a9e5dd-dc80-4184-92be-bd4ac7f22da7"],
 " represents the number of moves required to solve the puzzle for ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7a84a7ec-d53d-4e3d-a5e8-ab89afc0edae"],
 " disks. As discussed in the textbook, this has the solution"
}], "Text",ExpressionUUID->"a3af472d-23da-4292-a5f8-f0a49e04ce0d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["H", "n"], "=", 
   RowBox[{
    SuperscriptBox["2", "n"], "-", "1."}]}], TraditionalForm]], "Equation",Exp\
ressionUUID->"c0956d7d-0d26-447e-9449-6142a34d5248"],

Cell[TextData[{
 "Later in this manual, we will see how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to derive this result."
}], "Text",ExpressionUUID->"23ce5eb4-21b2-4c29-b814-63e86a884ece"],

Cell[TextData[{
 "Rather than just computing the values, we can illustrate the solution to \
the Tower of Hanoi puzzle by writing functions in the Wolfram Language to \
compute the moves needed and to describe them. We will write a small program \
consisting of three functions: the main program ",
 StyleBox["hanoi", "Code",
  IgnoreSpellCheck->True],
 ", a utility function ",
 StyleBox["printMove", "Code",
  IgnoreSpellCheck->True],
 ", and ",
 StyleBox["transferDisk", "Code",
  IgnoreSpellCheck->True],
 ", which does most of the work."
}], "Text",ExpressionUUID->"6e586275-b95d-4811-8b97-92dd3e6831ab"],

Cell[TextData[{
 "The easiest part to write is the function ",
 StyleBox["printMove", "Code"],
 ", which merely displays the move to make at a given step."
}], "Text",ExpressionUUID->"4c8a7a0d-df4a-478f-a9db-8a6543ae0a5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"printMove", "[", 
   RowBox[{"src_String", ",", "dest_String"}], "]"}], ":=", 
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Move disk from peg \>\"", ",", "src", ",", "\"\< to peg \>\"", ",", 
    "dest", ",", "\"\<.\>\""}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[10]:=",ExpressionUUID->"8cb030af-43cc-4cc5-a207-3636297b0392"],

Cell[TextData[{
 "The function ",
 StyleBox[ButtonBox["Print",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Print"], "FunctionLink"],
 " combines all of its arguments and display them on a single line."
}], "Text",ExpressionUUID->"c26bab90-7c17-4601-b127-b01ddc4dc6aa"],

Cell[TextData[{
 "Next, we write the recursive function ",
 StyleBox["transferDisk", "Code"],
 ", which does most of the work. This function models the idea of \
transferring a stack of ",
 StyleBox["ndisks", "Code",
  IgnoreSpellCheck->True],
 " disks from the source peg, which is given as the argument ",
 StyleBox["src", "Code"],
 ", to the destination peg, ",
 StyleBox["dest", "Code",
  IgnoreSpellCheck->True],
 ", via the intermediate peg, ",
 StyleBox["via", "Code"],
 ". As is described in the textbook, in order to move a stack of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "a71aada6-4a5c-45ef-ab13-15684b57f43d"],
 " disks, first move the top ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "-", "1"}], TraditionalForm]],ExpressionUUID->
  "157bea41-4cd7-4042-8135-598cddf51634"],
 " pegs to the intermediate peg (using the destination as the intermediary), \
then move the bottom disk to the destination, and then move the smaller stack \
from the intermediate peg to the destination. Unless, of course, there is \
only one disk, in which you just move that disk to the destination. This is \
coded as follows:"
}], "Text",ExpressionUUID->"44df87a5-a9a7-48fd-9dcf-935d478d70cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"transferDisk", "[", 
   RowBox[{
   "src_String", ",", "via_String", ",", "dest_String", ",", 
    "ndisks_Integer"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"ndisks", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{"printMove", "[", 
     RowBox[{"src", ",", "dest"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"transferDisk", "[", 
      RowBox[{"src", ",", "dest", ",", "via", ",", 
       RowBox[{"ndisks", "-", "1"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"printMove", "[", 
      RowBox[{"src", ",", "dest"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"transferDisk", "[", 
      RowBox[{"via", ",", "src", ",", "dest", ",", 
       RowBox[{"ndisks", "-", "1"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[11]:=",ExpressionUUID->"fcf2ffe6-7ef3-473d-8ebc-731c896e5bee"],

Cell[TextData[{
 "Finally, we package the recursive procedure in a top-level function, ",
 StyleBox["hanoi", "Code",
  IgnoreSpellCheck->True],
 ", providing an interface to the recursive engine."
}], "Text",ExpressionUUID->"0038cfbc-837e-421d-b87c-81bf51dd86be"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hanoi", "[", "ndisks_Integer", "]"}], "/;", 
   RowBox[{"ndisks", ">", "1"}]}], ":=", 
  RowBox[{"transferDisk", "[", 
   RowBox[{"\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "ndisks"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[12]:=",ExpressionUUID->"bfc64105-7dfa-4e2a-b9dd-84c5ada9d8ee"],

Cell[TextData[{
 "Our ",
 StyleBox["hanoi", "Code",
  IgnoreSpellCheck->True],
 " program can exhibit a specific solution to the Tower of Hanoi puzzle for \
any number of disks:"
}], "Text",ExpressionUUID->"4302b43e-b1e6-41ca-bc3e-9bc285d67fe3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hanoi", "[", "2", "]"}]], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"509d0210-5270-4810-8dd8-0f7b5709c6e3"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "B", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"4c24c4b7-cbe5-4ae7-a231-10b2151d0b6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"def43aa4-cebd-4b15-b6c4-9305fce1f91e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "B", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"323e90df-a3c7-475a-acd6-9024b92a69bf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hanoi", "[", "3", "]"}]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"ece993d3-fce9-4846-8326-9c67dd1b4088"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"183508d6-1b14-40c5-ac1f-49cc7d364e30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "B", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"5275c861-8be5-4afe-acf1-b63ce380025e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "C", " to peg ", "B", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"d587e16a-20d3-4d9b-9e29-552126f05e90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"394639e9-9c9d-4b07-a1d9-0f9d7ba42793"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "B", " to peg ", "A", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"80defe3d-5128-4731-b3d6-6063904c61da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"B\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "B", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"405143eb-9e4f-43b3-ac03-9af103858a9f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Move disk from peg \"\>", "\[InvisibleSpace]", "\<\"A\"\>", 
   "\[InvisibleSpace]", "\<\" to peg \"\>", "\[InvisibleSpace]", "\<\"C\"\>", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["Move disk from peg ", "A", " to peg ", "C", "."],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[14]:=",ExpressionUUID->"dffbc256-bab9-4839-b32c-8aa2060205cd"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Try experimenting with different values of ",
 StyleBox["ndisk", "Code",
  IgnoreSpellCheck->True],
 " to get a feel for how large the problem becomes for even moderately large \
numbers of disks."
}], "Text",ExpressionUUID->"5495407f-1427-47fe-993c-71b65d5ef673"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamic Programming", "Subsection",
 CellTags->"Section1b",ExpressionUUID->"ac410640-c2e7-4eef-a96b-5f7a60a708bc"],

Cell["\<\
We conclude this section with an implementation of Algorithm 1 from Section \
8.1 of the text. Recall that the goal of this algorithm is to find the \
maximum number of attendees that can be achieved by a schedule of talks. \
\>", "Text",ExpressionUUID->"91711a7f-b36c-4556-a65d-30b0a35529f4"],

Cell["\<\
We will represent each talk as a list of three elements, with the start time \
being the first element, the end time in the second position, and the weight, \
or attendance, will be last. Time of day will be represented by a single \
number with whole part equal to the hour in the 24-hour system and with \
fractional part equal to the part of an hour that corresponds to the number \
of minutes. For instance, 2:30 P.M. would be represented as 14.5. \
\>", "Text",ExpressionUUID->"4f515774-88a6-454a-bee0-bbcb80c688e5"],

Cell["As an example, consider the following eight talks. ", "Text",ExpressionUUID->"b2270ff5-e761-423f-b288-546e8d92aeb7"],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    RowBox[{"Start", " ", "Time"}], 
    RowBox[{"End", " ", "Time"}], "Attendance"},
   {
    RowBox[{"9", ":", 
     RowBox[{"00", " ", "AM"}]}], 
    RowBox[{"11", ":", 
     RowBox[{"00", " ", "AM"}]}], "17"},
   {
    RowBox[{"9", ":", 
     RowBox[{"00", " ", "AM"}]}], 
    RowBox[{"10", ":", 
     RowBox[{"30", " ", "AM"}]}], "15"},
   {
    RowBox[{"10", ":", 
     RowBox[{"00", " ", "AM"}]}], 
    RowBox[{"11", ":", 
     RowBox[{"30", " ", "AM"}]}], "22"},
   {
    RowBox[{"10", ":", 
     RowBox[{"30", " ", "AM"}]}], 
    RowBox[{"12", ":", 
     RowBox[{"00", " ", "PM"}]}], "11"},
   {
    RowBox[{"11", ":", 
     RowBox[{"30", " ", "AM"}]}], 
    RowBox[{"1", ":", 
     RowBox[{"30", " ", "PM"}]}], "18"},
   {
    RowBox[{"12", ":", 
     RowBox[{"00", " ", "PM"}]}], 
    RowBox[{"1", ":", 
     RowBox[{"00", " ", "PM"}]}], "12"},
   {
    RowBox[{"1", ":", 
     RowBox[{"30", " ", "PM"}]}], 
    RowBox[{"3", ":", 
     RowBox[{"00", " ", "PM"}]}], "21"},
   {
    RowBox[{"2", ":", 
     RowBox[{"00", " ", "PM"}]}], 
    RowBox[{"4", ":", 
     RowBox[{"00", " ", "PM"}]}], "17"}
  },
  BaseStyle->{FontFamily -> "Times"},
  GridBoxDividers->{
   "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
    "RowsIndexed" -> \
{}}]],ExpressionUUID->"7ce59874-312e-4cf3-8746-6bca8feff64a"]], "Text",Express\
ionUUID->"35bd8660-cb2a-4b05-95f8-3b141b03c782"],

Cell["\<\
We create the following list of lists to represent the talks. \
\>", "Text",ExpressionUUID->"1447f91d-ef49-4b38-9a1d-5dcaa08fc1b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"talks", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"9", ",", "11", ",", "17"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"9", ",", "10.5", ",", "15"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10", ",", "11.5", ",", "22"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10.5", ",", "12", ",", "11"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"11.5", ",", "13.5", ",", "18"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"12", ",", "13", ",", "12"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"13.5", ",", "15", ",", "21"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"14", ",", "16", ",", "17"}], "}"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[15]:=",ExpressionUUID->"78e27e43-7541-46eb-849d-89b093e922e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"9", ",", "11", ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "10.5`", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "11.5`", ",", "22"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.5`", ",", "12", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11.5`", ",", "13.5`", ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "13", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13.5`", ",", "15", ",", "21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"14", ",", "16", ",", "17"}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[15]=",ExpressionUUID->"de7ee490-3492-44e6-b46e-7165362fd078"]
}, Open  ]],

Cell["\<\
Recall the description of Algorithm 1 from the text. We summarize the general \
outline of the algorithm below.\
\>", "Text",ExpressionUUID->"c9c3ccd0-1e03-4699-b725-33f1e7987205"],

Cell[CellGroupData[{

Cell["Sort the talks in order of increasing end time. ", "Item1Numbered",ExpressionUUID->"20038812-4b83-4c51-b1d8-9fb9b58691ea"],

Cell[TextData[{
 "For each index ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "1d707009-b62b-4a3e-9541-a7adc646b578"],
 ", compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "bd24b121-204a-408c-979d-388fc3c4e122"],
 "\[LongDash]the maximum index ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "c5c965cc-7cf3-40fa-8e04-543bafe708df"],
 " such that talk ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "bc0a529c-89ab-48f4-b691-97664ce03eec"],
 " is compatible with talk ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "031d6513-6793-49e2-bb47-8bae2c00f6a6"],
 "."
}], "Item1Numbered",ExpressionUUID->"39739be4-06d1-469d-9197-e49f842585db"],

Cell[TextData[{
 "For each index ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "6f89cb19-8707-44dc-b384-e549964d0df9"],
 ", compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "b262eaef-082e-4656-bc34-3850e52ca138"],
 ", which is computed by the recurrence relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"T", "(", "j", ")"}], "=", 
    RowBox[{"max", "(", 
     RowBox[{
      RowBox[{
       SubscriptBox["w", "j"], "+", 
       RowBox[{"T", "(", 
        RowBox[{"p", "(", "j", ")"}], ")"}]}], ",", 
      RowBox[{"T", "(", 
       RowBox[{"j", "-", "1"}], ")"}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"c86776b1-4480-4ebc-8bc5-0cea1ab8425b"],
 " ",
 "and with initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"T", "(", "0", ")"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"544a6db3-ad4c-4515-9da4-830483574d3e"],
 "."
}], "Item1Numbered",ExpressionUUID->"057e84ce-5639-4e71-a846-01c8659b4e22"],

Cell[TextData[{
 "The maximum total number of attendees is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "35167eb6-609f-44bb-b8f3-00bc88da5340"],
 ", where ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "cf7a1721-0a52-4e07-8df3-2b15ab06b49f"],
 " is the number of talks."
}], "Item1Numbered",ExpressionUUID->"bb4ad7ea-e202-41c0-970c-971dc5e34adf"]
}, Open  ]],

Cell[TextData[{
 "For step 1, we will make use of ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " with a custom ordering function. ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " can accept an optional argument in the form of a pure function of two \
arguments. This function should return true if the first argument precedes \
the second and false otherwise. Since we must sort the talks in increasing \
order of end time (which is stored in position 2 in the lists representing \
the talks), we will use the following function as the second argument to ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 ". Recall that ",
 StyleBox["#1", "Code"],
 " and ",
 StyleBox["#2", "Code"],
 " indicate the inputs to the function and ",
 StyleBox["&", "Code"],
 " is used to terminate a pure ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"d917f556-ef19-4658-b371-a7a1893821a3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"#1", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "<", 
   RowBox[{"#2", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "&"}]], "myCode",
 Editable->False,ExpressionUUID->"35af29e9-492f-471d-9924-6cbe80503d04"],

Cell[TextData[{
 "For step 2, we must compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "2f582c52-a363-43ae-8223-10d553d9c0b3"],
 ". To do this, we will create a function that accepts the sorted list of \
talks and returns an indexed variable that represents the function ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "67d84fb7-516c-49f2-9d4c-1b37d1799a5d"],
 ". Recall that the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "d6b80c95-ee3b-4216-a474-b4026972c583"],
 " is the largest index among talks compatible with the talk with index ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "4233a8b8-651a-4a47-ad85-db699e56c268"],
 ", so we name the function ",
 StyleBox["compatible", "Code"],
 "."
}], "Text",ExpressionUUID->"740bfea8-03e8-453c-8cae-634243e3d409"],

Cell[TextData[{
 "After declaring local variables, the function ",
 StyleBox["compatible", "Code"],
 " will loop through all the indices, ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "bf1c8d77-60cd-4c61-b3f0-ca041c6c512a"],
 ", from 1 to the number of talks in the list. We use a local variable, ",
 StyleBox["jstart", "Code",
  IgnoreSpellCheck->True],
 ", to store the start time of the current talk being analyzed. We then \
consider all the talks earlier in the list beginning with the talk with index \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"j", "-", "1"}], TraditionalForm]],ExpressionUUID->
  "eb50eb0d-164c-4d58-95ea-e1ff77f067d9"],
 " and working backwards to talk 1. For each talk, we check to see if it ends \
before talk ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "c1d40cf8-a235-46fa-accf-6926664857c6"],
 " starts. When we find such a talk, we set its index to the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "cb50e710-0d09-4e79-8cbe-7db2e546d2c3"],
 " (since we are working backward, the first one found is the talk with the \
largest index). If no compatible talk is found, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "dd83ad9c-a519-40da-a8d5-ff373d9296aa"],
 " is set to 0. Here is the function."
}], "Text",ExpressionUUID->"6fd37306-2308-470c-a8c9-4db956488602"],

Cell[BoxData[
 RowBox[{
  RowBox[{"compatible", "[", "talkList_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "j", ",", "jstart", ",", "i"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", 
        RowBox[{"Length", "[", "talkList", "]"}]}], ",", 
       RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"jstart", "=", 
         RowBox[{
          RowBox[{"talkList", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"p", "[", "j", "]"}], "=", 
         RowBox[{"Catch", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"For", "[", 
            RowBox[{
             RowBox[{"i", "=", 
              RowBox[{"j", "-", "1"}]}], ",", 
             RowBox[{"i", "\[GreaterEqual]", "1"}], ",", 
             RowBox[{"i", "--"}], ",", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"talkList", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "\[LessEqual]", "jstart"}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"Throw", "[", "i", "]"}]}], "\[IndentingNewLine]", 
              "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Throw", "[", "0", "]"}]}], "\[IndentingNewLine]", 
          "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "p"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[16]:=",ExpressionUUID->"c6cfbc8c-3401-448e-b307-221f1c4f1d39"],

Cell[TextData[{
 "For step 3, we must compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "(", "j", ")"}], TraditionalForm]],ExpressionUUID->
  "16c78f2a-9dd8-4034-b2b6-b2e6aa7236a0"],
 ". To do this, we create a function that accepts as input the sorted list of \
talks and the indexed variable representing the function ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "9411c783-20af-4ed2-b50c-888f943b9eb7"],
 ". Initialize ",
 StyleBox["T", "Code"],
 " by setting its value at 0 to 0. Then, consider each integer ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "b36eead5-81d2-434e-a11b-6bf8fe694b5d"],
 " from 1 to the number of talks and apply the formula: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"T", "(", "j", ")"}], "=", 
    RowBox[{"max", "(", 
     RowBox[{
      RowBox[{
       SubscriptBox["w", "j"], "+", 
       RowBox[{"T", "(", 
        RowBox[{"p", "(", "j", ")"}], ")"}]}], ",", 
      RowBox[{"T", "(", 
       RowBox[{"j", "-", "1"}], ")"}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"94c76da4-2e35-484c-a072-bbee11897a99"],
 "."
}], "Text",ExpressionUUID->"1a31da92-b190-4832-af5f-4211b402ce44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"totalAttendance", "[", 
   RowBox[{"talkList_", ",", "p_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"j", ",", "T"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"T", "[", "0", "]"}], "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", 
        RowBox[{"Length", "[", "talkList", "]"}]}], ",", 
       RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "[", "j", "]"}], "=", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"talkList", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "+", 
           RowBox[{"T", "[", 
            RowBox[{"p", "[", "j", "]"}], "]"}]}], ",", 
          RowBox[{"T", "[", 
           RowBox[{"j", "-", "1"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]",
       "]"}], ";", "\[IndentingNewLine]", "T"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[17]:=",ExpressionUUID->"caaf965c-d9ac-438d-9092-e6647010a97e"],

Cell["\<\
We can now put the pieces together as outlined at the start of this \
subsection.\
\>", "Text",ExpressionUUID->"c884001d-b501-4571-85d4-75041046fb9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"maximumAttendance", "[", "talkList_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"L", ",", "p", ",", "T"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"L", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"talkList", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#1", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "<", 
          RowBox[{"#2", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "&"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"p", "=", 
      RowBox[{"compatible", "[", "L", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"T", "=", 
      RowBox[{"totalAttendance", "[", 
       RowBox[{"L", ",", "p"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"T", "[", 
      RowBox[{"Length", "[", "talkList", "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[18]:=",ExpressionUUID->"3ad7dce0-6cf3-4edd-93f7-d39cfdc212dc"],

Cell["\<\
And thus, the maximum attendance for the talks described above is: \
\>", "Text",ExpressionUUID->"cf3ae91b-d961-4970-89dd-bcf73fa2b05c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"maximumAttendance", "[", "talks", "]"}]], "Input",
 CellLabel->"In[19]:=",ExpressionUUID->"f9309f81-3b64-4003-8c4c-8c056aee2a6e"],

Cell[BoxData["61"], "Output",
 CellLabel->"Out[19]=",ExpressionUUID->"e5727142-3b76-4a81-8889-544dae1d87bc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.2 Solving Linear Recurrence Relations", "Section",
 CellTags->"Section2",ExpressionUUID->"aa7a30bb-ab63-496b-b659-a8c50e1b4419"],

Cell[TextData[{
 "The Wolfram Language has a very powerful recurrence solver, ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 ". Its use, however, can obscure some of the important ideas that are \
involved. Therefore, we will first use some of the Wolfram Language\
\[CloseCurlyQuote]s more fundamental facilities to solve certain kinds of \
recurrence relations one step at a time."
}], "Text",ExpressionUUID->"7051c954-fe89-43d2-951c-3287d168d234"],

Cell[TextData[{
 "Given a recursively defined sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "7f50b1f2-5348-49f4-aed4-e35725dab94b"],
 ", we would like to find a formula, involving only the index ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "94d995e5-188e-40ca-97a3-ce3a5a61c669"],
 " (and, perhaps, other fixed constants and known functions) that does not \
depend on knowing the value of any prior elements of the sequence."
}], "Text",ExpressionUUID->"dfa3f506-1840-4e6a-991d-ce1022d182bf"],

Cell[CellGroupData[{

Cell["\<\
Linear Homogeneous Recurrence Relations with Constant Coefficients\
\>", "Subsection",
 CellTags->"Section2a",ExpressionUUID->"7d3f1f76-a830-4815-86c9-b6bb7afa6391"],

Cell["\<\
We will begin by considering recurrence relations that are linear, \
homogeneous, and which have constant coefficients; that is, they have the form\
\>", "Text",ExpressionUUID->"f7b4f78c-fdaf-453a-b0d0-8819c9de31a2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}], "+", "\[CenterEllipsis]", "+", 
    RowBox[{
     SubscriptBox["c", "k"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "k"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"ff9cc218-d816-41cd-aae9-6d99847e06ae"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], ",", 
    SubscriptBox["c", "2"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["c", "k"]}], TraditionalForm]],ExpressionUUID->
  "eee1e3a3-8038-4207-9635-9677864ac744"],
 " are real constants and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]],ExpressionUUID->
  "88bbdef9-11f7-43df-8364-2b92a5d199e3"],
 " is nonzero. Recall that the integer ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "3505b5a4-f40b-472e-b0fc-ec8e8052cf76"],
 " is called the degree of this recurrence relation. To have a unique \
solution, at least ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "c736da09-c1f1-49b5-9e7d-326cbb668922"],
 " initial conditions must be specified."
}], "Text",ExpressionUUID->"e12e5475-745c-4fdc-82aa-d11e4a3f1720"],

Cell["\<\
The general method for solving such a recurrence relation involves finding \
the roots of its characteristic polynomial \
\>", "Text",ExpressionUUID->"6f708d1d-03c4-40a9-ba55-38ab7589f6df"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["r", "k"], "-", 
   RowBox[{
    SubscriptBox["c", "1"], 
    SuperscriptBox["r", 
     RowBox[{"k", "-", "1"}]]}], "-", 
   RowBox[{
    SubscriptBox["c", "2"], 
    SuperscriptBox["r", 
     RowBox[{"k", "-", "2"}]]}], "-", "\[CenterEllipsis]", "-", 
   RowBox[{
    SubscriptBox["c", 
     RowBox[{"k", "-", "1"}]], "r"}], "-", 
   SubscriptBox["c", "k"]}], TraditionalForm]], "Equation",ExpressionUUID->\
"0b8b6e09-e533-4cda-bc81-dfa6afe6b576"],

Cell[TextData[{
 "When this polynomial has distinct roots, all solutions are linear \
combinations of the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "6cf73bde-ca80-4a50-bc3d-e4ef6225b22f"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " powers of these roots. When there are repeated roots, the situation is a \
little more complicated, as we will see."
}], "Text",ExpressionUUID->"4450d464-9882-43e1-a9f7-f4ccd9b610b5"],

Cell[CellGroupData[{

Cell["A First Example", "Subsubsection",ExpressionUUID->"15dbe47e-7e7b-449d-a3e1-7e3938c5445b"],

Cell["\<\
Consider the linear homogeneous recurrence relation with constant \
coefficients of degree two \
\>", "Text",ExpressionUUID->"eba5d25c-08fe-41a8-b903-9f5e8332bee8"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"2", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{"3", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"66ae4fe5-dd6b-491b-b0e3-64663db5ec0d"],

Cell[TextData[{
 "subject to the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "fa041d3c-eb86-49b3-ae2f-066fe64a0aac"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "19e18026-d516-4387-bc61-423b8c859da3"],
 ". Its characteristic equation is"
}], "Text",ExpressionUUID->"63da9f00-c40b-4086-a7f5-7f86a20fcb87"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"2", "r"}], "-", "3"}], "=", "0"}], TraditionalForm]], "Equation",\
ExpressionUUID->"e0a0be4b-444f-4062-bf12-4030e642eb3f"],

Cell[TextData[{
 "To solve the recurrence relation, we find the roots of the equation by \
applying the ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " function."
}], "Text",ExpressionUUID->"504e9d35-453c-4c3e-a807-b867db34112b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"r", "^", "2"}], "-", 
     RowBox[{"2", "r"}], "-", "3"}], "\[Equal]", "0"}], ",", "r"}], 
  "]"}]], "Input",
 CellLabel->"In[20]:=",ExpressionUUID->"2f9844ad-1666-4e0f-93f1-c048d192285e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", "3"}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[20]=",ExpressionUUID->"ef7c2579-48f3-4b19-a767-7b5c535bf9be"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " function computes the values of the variable ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "578738db-31b6-4da4-862f-1893c843082b"],
 ", given as the second argument, that satisfy the equation in the first \
argument. Note that the output is a list of lists, within which are rules \
specifying the solutions."
}], "Text",ExpressionUUID->"678ff6ca-1713-4c09-99b9-8bae8d337f70"],

Cell[TextData[{
 "Now that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has determined that the solutions are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]],ExpressionUUID->
  "15325f6d-41d5-44a5-aa85-26c6051b5ae6"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "3"}], TraditionalForm]],ExpressionUUID->
  "d3d7d31b-5130-4063-aef5-2661fdae22b6"],
 ", we can write down the form of the solution to the recurrence as"
}], "Text",ExpressionUUID->"efefc077-d297-4305-a0e7-3be476c5e481"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"\[Alpha]", "\[CenterDot]", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}], "+", 
    RowBox[{"\[Beta]", "\[CenterDot]", 
     SuperscriptBox["3", "n"]}]}]}], TraditionalForm]], "Equation",ExpressionU\
UID->"f1a2c418-b0ba-48e8-a41f-25553d2a22f4"],

Cell["where \[Alpha] and \[Beta] are constants that we have yet to \
determine.", "Text",ExpressionUUID->"8ae34b1e-5044-4de9-bf2e-29490473b1fa"],

Cell[TextData[{
 "Since the initial conditions are ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "e78f3e1d-9075-4328-a67b-03244c74dee8"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "f68e4598-4607-44d3-bcb1-ba0826366b74"],
 ", our recurrence relation must satisfy the following pair of equations."
}], "Text",ExpressionUUID->"0e236bb0-80f2-4b37-813b-446c5ee789c1"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], "+", 
        RowBox[{"3", "\[Beta]"}]}], "=", "4"}]},
     {
      RowBox[{
       RowBox[{"\[Alpha]", "+", 
        RowBox[{"9", "\[Beta]"}]}], "=", "2"}]}
    }]}], TraditionalForm]], "Equation",ExpressionUUID->"2b646ee3-c641-4efb-\
875e-d782286297e4"],

Cell[TextData[{
 "To find the solution to this system of linear equations, we again use ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 ":"
}], "Text",ExpressionUUID->"376dcbd7-788b-4f44-8132-3bac52a778a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "alpha"}], "+", 
       RowBox[{"3", "*", "beta"}]}], "\[Equal]", "4"}], ",", 
     RowBox[{
      RowBox[{"alpha", "+", 
       RowBox[{"9", " ", "*", " ", "beta"}]}], "\[Equal]", "2"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[21]:=",ExpressionUUID->"5729e6bf-179e-4710-a81f-4ece136cd5d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"alpha", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["5", "2"]}]}], ",", 
    RowBox[{"beta", "\[Rule]", 
     FractionBox["1", "2"]}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[21]=",ExpressionUUID->"b92d6563-4e41-497d-a9ee-ecc628af2cbd"]
}, Open  ]],

Cell["\<\
That the first argument is a list of equations indicates that they represent \
a system of equations to be solved simultaneously. Likewise, the variables to \
be solved for form a list.\
\>", "Text",ExpressionUUID->"92867c96-1672-4267-94ed-a64629882afb"],

Cell["\<\
Now that we have the values for \[Alpha] and \[Beta], we see that the \
complete solution to the recurrence relation is\
\>", "Text",ExpressionUUID->"fcc3d964-af35-4700-b692-b1f4476c7329"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"-", "5"}], "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["3", "n"]}]}]}], TraditionalForm]], "Equation",ExpressionU\
UID->"9aac857e-a382-4b04-ae75-356a231877cf"],

Cell[TextData[{
 "This formula allows us to write a function for finding the terms of the \
sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["a", "n"], "}"}], TraditionalForm]],ExpressionUUID->
  "84756322-447d-4e22-8989-f8e33b9a2ab6"],
 ", which can be more efficient than a recursive approach."
}], "Text",ExpressionUUID->"cc0085a1-0b9d-450c-8c49-7e6b2443b7f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"aFormula", "[", "n_Integer", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "5"}], "/", "2"}], ")"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", "n"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", 
    RowBox[{"3", "^", "n"}]}]}]}]], "Input",
 CellLabel->"In[22]:=",ExpressionUUID->"caab3f0e-50ac-4cbf-a358-e53cf8e1f02c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"aFormula", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[23]:=",ExpressionUUID->"fbaa04c0-c00c-4eec-9d24-159baf6df851"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "2", ",", "16", ",", "38", ",", "124", ",", "362", ",", "1096", 
   ",", "3278", ",", "9844", ",", "29522"}], "}"}]], "Output",
 CellLabel->"Out[23]=",ExpressionUUID->"f5dc63e5-4d7d-4e5a-9a59-a27608190087"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Second Example", "Subsubsection",ExpressionUUID->"37b11016-7e92-45ba-9107-b5ff8212b057"],

Cell["\<\
We consider another example. We will solve the recurrence relation\
\>", "Text",ExpressionUUID->"0d854eda-871d-4bcf-b2ba-d98e9c152aad"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"-", "5"}], "3"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{
     FractionBox["2", "3"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"a460cb23-d45e-460e-ae93-2ce712dc56ce"],

Cell[TextData[{
 "with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    FractionBox["1", "2"]}], TraditionalForm]],ExpressionUUID->
  "3a8b5b60-dcca-4dad-bbcd-a3c28c7a5a19"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "a24f3710-8ebf-4681-ade9-a801c1b8dc28"],
 "."
}], "Text",ExpressionUUID->"3d932fc2-e641-48ed-84c1-ef86ffe2b391"],

Cell[TextData[{
 "To do this, we have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solve the characteristic equation of the recurrence relation, and then \
solve the system of linear equations obtained from the roots of the \
characteristic equation and the initial conditions. Note that this method \
works because this recurrence relation is linear, homogeneous, and has \
constant coefficients."
}], "Text",ExpressionUUID->"e16d0948-5f50-4585-96ba-30bb4dc1153a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"charEqnRoots", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"r", "^", "2"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"5", "/", "3"}], ")"}], "*", "r"}], "-", 
      RowBox[{"(", 
       RowBox[{"2", "/", "3"}], ")"}]}], "\[Equal]", "0"}], ",", "r"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[24]:=",ExpressionUUID->"d4f6d575-8021-48c1-b227-4ae1349db655"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"-", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     FractionBox["1", "3"]}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[24]=",ExpressionUUID->"b1ca4e7c-ca71-44af-bcb7-1261e76a4c22"]
}, Open  ]],

Cell[TextData[{
 "Note that we can transform the output from a list of lists of rules into a \
simple list of the solutions using the ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Code"],
 ") operator as shown below."
}], "Text",ExpressionUUID->"1cd809a9-14d8-4d0f-b625-aeccda603716"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"charRootsL", "=", 
  RowBox[{"r", "/.", "charEqnRoots"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[25]:=",ExpressionUUID->"5fdaaae0-4196-4f02-8313-38787f70eb53"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2"}], ",", 
   FractionBox["1", "3"]}], "}"}]], "Output",
 CellLabel->"Out[25]=",ExpressionUUID->"82c5ce9a-e2b7-4991-930f-c6e6a648ef86"]
}, Open  ]],

Cell[TextData[{
 "When ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " is given a list of lists of rules as its right operand, its output is the \
list obtained by applying the rules in each sublist in turn. "
}], "Text",ExpressionUUID->"4992d311-edd4-482b-beb7-35dd47280cd2"],

Cell["\<\
This allows us to solve for \[Alpha] and \[Beta] by referencing the solutions \
to the characteristic equation, rather than typing them. \
\>", "Text",ExpressionUUID->"5a4f6757-9f9d-4d83-b317-c5d3b3852e3a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"alpha", "*", 
        RowBox[{"charRootsL", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "+", 
       RowBox[{"beta", "*", 
        RowBox[{"charRootsL", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}], "\[Equal]", 
      RowBox[{"1", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"alpha", "*", 
        RowBox[{
         RowBox[{"charRootsL", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
       RowBox[{"beta", "*", 
        RowBox[{
         RowBox[{"charRootsL", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]", "4"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"07d4f508-b2c6-42fc-8e47-5f5107309d3d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"alpha", "\[Rule]", 
     FractionBox["23", "28"]}], ",", 
    RowBox[{"beta", "\[Rule]", 
     FractionBox["45", "7"]}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[26]=",ExpressionUUID->"e11362e4-8d9c-472d-92ca-8ea037729006"]
}, Open  ]],

Cell["\<\
Thus, we see that the solution to the recurrence relation is \
\>", "Text",ExpressionUUID->"e4a26ec5-3ba4-4d2f-88f7-799444999525"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     FractionBox["23", "28"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "2"}], ")"}], "n"]}], "+", 
    RowBox[{
     FractionBox["45", "7"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["1", "3"], ")"}], "n"]}]}]}], TraditionalForm]], "Equation",\
ExpressionUUID->"17150132-d530-49f1-b5d4-85ceaa2b13d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Fibonacci Sequence", "Subsubsection",ExpressionUUID->"ce90a4f6-8b65-476d-b175-98ed971d9c8c"],

Cell["\<\
We can derive an explicit formula for the Fibonacci sequence this way as \
well. The characteristic polynomial for the Fibonacci sequence is \
\>", "Text",ExpressionUUID->"7aa4e6b8-2c21-4a0e-bdac-4f2c408c2b5e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["r", "2"], "-", "r", "-", "1"}], 
  TraditionalForm]], "Equation",ExpressionUUID->"3d56e77f-fa10-477f-a85a-\
429bbdbe0037"],

Cell["We find the roots of the characteristic equation.", "Text",ExpressionUUID->"8ac1ac4a-2028-493f-bc25-44e94a666b98"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cEqnRoots", "=", 
  RowBox[{"r", "/.", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"r", "^", "2"}], "-", "r", "-", "1"}], "\[Equal]", "0"}], ",", 
     "r"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[27]:=",ExpressionUUID->"24cac90c-f7f4-481b-b99f-d621814931e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox["5"]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}]}]}], "}"}]], "Output",
 CellLabel->"Out[27]=",ExpressionUUID->"6111a753-6dae-4427-b39d-e2e235a91596"]
}, Open  ]],

Cell[TextData[{
 "Therefore, the formula for the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "63993001-2610-45b3-b4d8-9ace723c76ea"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " Fibonacci number is of the form"
}], "Text",ExpressionUUID->"9a412f5d-ce68-4487-95d3-7c0c132379d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fn", "=", 
  RowBox[{
   RowBox[{"alpha", "*", 
    RowBox[{
     RowBox[{"cEqnRoots", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}], "+", 
   RowBox[{"beta", "*", 
    RowBox[{
     RowBox[{"cEqnRoots", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "^", "n"}]}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[28]:=",ExpressionUUID->"7ce4231e-a9ca-4e1b-bb1b-e0c52989e37e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox["5"]}], ")"}]}], ")"}], "n"], " ", "alpha"}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SqrtBox["5"]}], ")"}]}], ")"}], "n"], " ", "beta"}]}]], "Output",
 CellLabel->"Out[28]=",ExpressionUUID->"890dfc19-4060-4485-ae95-405bd297096c"]
}, Open  ]],

Cell["\<\
We find the coefficients \[Alpha] and \[Beta] in the formula by using the \
initial conditions.\
\>", "Text",ExpressionUUID->"cda31b3d-9533-43b7-b2c6-137dac2ed518"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphas", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"alpha", "*", 
         RowBox[{"cEqnRoots", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "+", 
        RowBox[{"beta", "*", 
         RowBox[{"cEqnRoots", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"alpha", "*", 
         RowBox[{
          RowBox[{"cEqnRoots", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
        RowBox[{"beta", "*", 
         RowBox[{
          RowBox[{"cEqnRoots", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]", 
       "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[29]:=",ExpressionUUID->"120e1f28-c2db-430d-95b7-3a09201bc54c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"alpha", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["1", 
       SqrtBox["5"]]}]}], ",", 
    RowBox[{"beta", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "5"}], "-", 
        SqrtBox["5"]}], 
       RowBox[{"5", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SqrtBox["5"]}], ")"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[29]=",ExpressionUUID->"07339e11-f1a5-4b40-9e23-8453bc3ee726"]
}, Open  ]],

Cell[TextData[{
 "We can use ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Code"],
 ") to substitute the values for \[Alpha] and \[Beta] into the formula ",
 StyleBox["Fn", "Code",
  IgnoreSpellCheck->True],
 ". Note that we access the \[OpenCurlyDoubleQuote]first\
\[CloseCurlyDoubleQuote] element of alphas in order to not have a nested list."
}], "Text",ExpressionUUID->"e5c502ba-dcb4-4f30-b706-1b7de7bc36c4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fn", "/.", 
  RowBox[{"alphas", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"5473f3a5-88a7-4ef4-b126-fca26e3c7624"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox["5"]}], ")"}]}], ")"}], "n"], 
    SqrtBox["5"]]}], "-", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   SuperscriptBox["2", 
    RowBox[{"-", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "5"}], "-", 
     SqrtBox["5"]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]]}]}]], "Output",
 CellLabel->"Out[30]=",ExpressionUUID->"b3fb89a4-fa33-4804-a10a-64fc87581527"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Fn", "/.", 
   RowBox[{"alphas", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",ExpressionUUID->"52f6c1b5-ca5e-494a-9ace-e18d02d62b72"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{"5", "+", 
      SqrtBox["5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox["5"]}], ")"}], "n"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox["5"]}], ")"}], "n"]}], ")"}]}], 
   RowBox[{"5", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}]}]]}]], "Output",
 CellLabel->"Out[31]=",ExpressionUUID->"67d09d8d-f8bf-4a45-8b31-36b4e57ddb86"]
}, Open  ]],

Cell["\<\
If we are to use such a formula to repeatedly compute values, then we should \
define a function. You can do this by retyping the formula or copy and paste \
it into a function definition. Alternatively, you can use the expression as \
the function definition as shown below.\
\>", "Text",ExpressionUUID->"909ab1b5-8de5-4587-9d34-05ba13e0a74a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fibonacci2", "[", "n_", "]"}], "=", 
  RowBox[{"Fn", "/.", 
   RowBox[{"alphas", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[32]:=",ExpressionUUID->"9a37ba77-54b1-4f5e-af01-37eb99588075"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox["5"]}], ")"}]}], ")"}], "n"], 
    SqrtBox["5"]]}], "-", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   SuperscriptBox["2", 
    RowBox[{"-", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "5"}], "-", 
     SqrtBox["5"]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]]}]}]], "Output",
 CellLabel->"Out[32]=",ExpressionUUID->"c1720eff-8296-41f5-8f8c-1c21b9868fe7"]
}, Open  ]],

Cell[TextData[{
 "Note that in this situation, it is important to use ",
 StyleBox[ButtonBox["Set",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Set"], "FunctionLink"],
 " (",
 StyleBox["=", "Code"],
 "), not the usual ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 "). This is so that the right-hand side resolves into the expression before \
the function is defined."
}], "Text",ExpressionUUID->"370f0a01-9c72-43ef-a904-f784abd0c661"],

Cell[TextData[{
 "Observe that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will not necessarily simplify values automatically."
}], "Text",ExpressionUUID->"4c8145b8-5483-4a25-84fd-afc4edf465c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fibonacci2", "[", "1", "]"}]], "Input",
 CellLabel->"In[33]:=",ExpressionUUID->"7107d01e-db31-44b9-994e-ce71a1523127"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"1", "-", 
     SqrtBox["5"]}], 
    RowBox[{"2", " ", 
     SqrtBox["5"]}]]}], "+", 
  RowBox[{
   FractionBox["1", "10"], " ", 
   RowBox[{"(", 
    RowBox[{"5", "+", 
     SqrtBox["5"]}], ")"}]}]}]], "Output",
 CellLabel->"Out[33]=",ExpressionUUID->"37e77bf9-b893-4c7b-96dd-42aa46517d63"]
}, Open  ]],

Cell[TextData[{
 "However, applying the ",
 StyleBox[ButtonBox["Simplify",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Simplify"], "FunctionLink"],
 " function will reduce the expression to the expected value."
}], "Text",ExpressionUUID->"8f89add6-4516-4091-a0aa-4f482171fb88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fibonacci2", "[", "1", "]"}], "//", "Simplify"}]], "Input",
 CellLabel->"In[34]:=",ExpressionUUID->"f801fdc0-72bb-4ff8-b2cb-61f7a8885611"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[34]=",ExpressionUUID->"b1d8895d-ffd9-45ee-af06-6beb5431a769"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Solver", "Subsubsection",ExpressionUUID->"8e6c93a9-33af-48b3-9eaa-0edeaa44998a"],

Cell[TextData[{
 "Now, we generalize what we have been doing and write a function in the \
Wolfram Language to solve a degree two linear, homogeneous recurrence \
relation with constant coefficients, provided that the roots of the \
characteristic polynomial are distinct. We will write a function ",
 StyleBox["recSol2Distinct", "Code"],
 " that solves the recurrence"
}], "Text",ExpressionUUID->"d32a1086-3455-4b6f-a376-a29feec15ea2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"c", "\[CenterDot]", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{"d", "\[CenterDot]", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"d8a3ade7-08de-4b53-a70a-9fb706df7332"],

Cell[TextData[{
 "subject to the initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "u"}], TraditionalForm]],ExpressionUUID->
  "ad648403-d9ce-4f10-9036-45e6643b74db"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "v"}], TraditionalForm]],ExpressionUUID->
  "2e87479e-9ca1-4135-9a12-be53a40ec8a6"],
 ", and then returns a ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " that can be used to compute terms of the sequence."
}], "Text",ExpressionUUID->"3ef87e57-9635-4057-8f04-99f73182579f"],

Cell[TextData[{
 "For the moment, we assume that the characteristic polynomial ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"c", "\[CenterDot]", "r"}], "-", "d"}], TraditionalForm]],
  ExpressionUUID->"d0057da6-4169-4468-8f2f-83875f978b02"],
 " has two distinct roots. Later, we will modify the function to relax that \
restriction. With the assumption that the roots of the characteristic \
polynomial are distinct, all our function needs to do is to repeat the steps \
we did manually in the examples above."
}], "Text",ExpressionUUID->"5f5e65c4-517b-4cfb-9ddb-7f933e4d34da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"recSol2Distinct", "[", 
   RowBox[{"c_", ",", "d_", ",", "u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "CERoots", ",", "alphas", ",", "alpha", ",", "beta", ",", "f", ",", 
      "r"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "first", " ", "solve", " ", "the", " ", "characteristic", " ", 
      "equation"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CERoots", "=", 
      RowBox[{"r", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"r", "^", "2"}], "-", 
           RowBox[{"c", "*", "r"}], "-", "d"}], "\[Equal]", "0"}], ",", "r"}],
         "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "next", " ", "solve", " ", "using", " ", "the", " ", "initial", " ", 
       "conditions"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"alphas", "=", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"alpha", "*", 
              RowBox[{"CERoots", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "+", 
             RowBox[{"beta", "*", 
              RowBox[{"CERoots", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "\[Equal]", "u"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"alpha", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
             RowBox[{"beta", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]", 
            "v"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "finally", " ", "substitute", " ", "the", " ", "results", " ", "into", 
       " ", "the", " ", "general", " ", "form"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Function", "[", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"alpha", "*", 
          RowBox[{
           RowBox[{"CERoots", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}], "+", 
         RowBox[{"beta", "*", 
          RowBox[{
           RowBox[{"CERoots", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "^", "n"}]}]}], "/.", 
        "alphas"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[35]:=",ExpressionUUID->"303f1c21-8b6a-4cf8-8b83-d825145c9d83"],

Cell[TextData[{
 "Observe that the final expression in the body of the ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " is an application of ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 ". This means that the result in ",
 StyleBox["recSol2Distinct", "Code"],
 " will be a pure function. The first argument to ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " is the variable n, which is the variable representing the input to the \
function as opposed to the symbols used internally to the ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 ". "
}], "Text",ExpressionUUID->"2264fc0e-c2db-4210-a671-3c2f3941e6aa"],

Cell[TextData[{
 "To construct a function for computing the Fibonacci sequence, invoke the \
new function with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{"d", "=", "1"}]}], TraditionalForm]],ExpressionUUID->
  "6e381f7f-ab82-432d-bf3d-67e3ae2d7c23"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "=", 
    RowBox[{"v", "=", "1"}]}], TraditionalForm]],ExpressionUUID->
  "c36a2635-35d0-4e8e-8ca8-7c733dc38629"],
 ". We assign the resulting ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " to the symbol ",
 StyleBox["f", "Code"],
 " and use it to compute the first 10 Fibonacci numbers."
}], "Text",ExpressionUUID->"77f6b445-a636-4ffb-81b7-7487e852511c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"recSol2Distinct", "[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"f", "[", "n", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[36]:=",ExpressionUUID->"f18a8c25-5919-4730-af28-ee49dedf3999"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", "21",
    ",", "34", ",", "55"}], "}"}]], "Output",
 CellLabel->"Out[37]=",ExpressionUUID->"a4163ad6-5955-4a06-96e1-74c8e7d0b2fa"]
}, Open  ]],

Cell[TextData[{
 "We can apply ",
 StyleBox["f", "Code"],
 " to a variable and simplify to see a closed-form formula for the Fibonacci \
numbers."
}], "Text",ExpressionUUID->"080e127a-06a6-45f1-94ab-088ad1231ede"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "n", "]"}], "//", "Simplify"}]], "Input",
 CellLabel->"In[38]:=",ExpressionUUID->"88e1d0db-1cc6-4032-a551-854f29f5de29"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"-", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{"5", "+", 
      SqrtBox["5"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox["5"]}], ")"}], "n"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SqrtBox["5"]}], ")"}], "n"]}], ")"}]}], 
   RowBox[{"5", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}]}]]}]], "Output",
 CellLabel->"Out[38]=",ExpressionUUID->"86547043-799c-4097-a2d4-d94031dbd444"]
}, Open  ]],

Cell[TextData[{
 "Evaluating the symbol ",
 StyleBox["f", "Code"],
 " without an argument tells us very little about the recurrence relation, \
but provides some information about how ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " work."
}], "Text",ExpressionUUID->"4f022a14-a97c-4097-bb72-a345d776d98f"],

Cell[CellGroupData[{

Cell[BoxData["f"], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"12c3c2e3-6f66-4f7f-9d86-09bf46e2bfe5"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{"n$", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"alpha$2158", " ", 
      SuperscriptBox[
       RowBox[{
       "CERoots$2158", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
        "n$"]}], "+", 
     RowBox[{"beta$2158", " ", 
      SuperscriptBox[
       RowBox[{
       "CERoots$2158", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
        "n$"]}]}], "/.", "\[VeryThinSpace]", "alphas$2158"}]}], 
  "]"}]], "Output",
 CellLabel->"Out[39]=",ExpressionUUID->"f9020c75-7656-44b7-810f-fc969a822c66"]
}, Open  ]],

Cell[TextData[{
 "The dollar signs indicate that the variables in the expression are \
localized to the ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 ". The numbers after the dollar signs ensure that the symbols being used are \
unique. If you use the variable ",
 StyleBox["alphas", "Code"],
 " in a different module, or even redefine ",
 StyleBox["f", "Code"],
 ", the values will change. But those unique symbols store the appropriate \
values, so that when you apply ",
 StyleBox["f", "Code"],
 " to a value or variable, the substitution represented by ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Code"],
 ") and the computations are performed."
}], "Text",ExpressionUUID->"17da2d36-d51d-449d-b986-1296f734bbf5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Recurrence with Repeated Roots", "Subsubsection",ExpressionUUID->"654d4e8b-1488-432e-a574-3370380867b2"],

Cell["\<\
We will next create a function that can handle the case of repeated roots. \
First, though, we look at an example of a recurrence relation whose \
characteristic polynomial has a double root. The recurrence relation\
\>", "Text",ExpressionUUID->"9a8859f9-5d1c-455c-8f19-1da7b66f43f5"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"4", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "-", 
    RowBox[{"4", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"71e2f4b5-4fc6-4369-a0c3-ddb2cca8a63b"],

Cell["has characteristic equation", "Text",ExpressionUUID->"7d1f3cbd-2871-400d-b382-4b7f3587fade"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"charEqn", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"r", "^", "2"}], "-", 
    RowBox[{"4", "*", "r"}], "+", "4"}], "\[Equal]", "0"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[40]:=",ExpressionUUID->"0851f034-4b24-4e15-9ffc-5cc08e2c8ca9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", "-", 
   RowBox[{"4", " ", "r"}], "+", 
   SuperscriptBox["r", "2"]}], "\[Equal]", "0"}]], "Output",
 CellLabel->"Out[40]=",ExpressionUUID->"9c832680-8e55-4472-82d4-9f7908ffbae0"]
}, Open  ]],

Cell["Its roots are:", "Text",ExpressionUUID->"6863c26d-69bf-4ac7-a402-964ce86d97a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CERoots", "=", 
  RowBox[{"r", "/.", 
   RowBox[{"Solve", "[", 
    RowBox[{"charEqn", ",", "r"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[41]:=",ExpressionUUID->"91c71cfe-6e0d-45cb-84b9-693d3b9ac8af"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "2"}], "}"}]], "Output",
 CellLabel->"Out[41]=",ExpressionUUID->"b7af534c-a9e5-4c66-b90f-4020340e1c44"]
}, Open  ]],

Cell[TextData[{
 "We can clearly see that in this case the root is repeated, but for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to recognize it, we need to use the following test."
}], "Text",ExpressionUUID->"c0d1a498-3455-4253-b35b-a8a4bce0d0d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CERoots", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
  RowBox[{"CERoots", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellLabel->"In[42]:=",ExpressionUUID->"8d296261-4aca-4fb2-afa2-a472ae21b73c"],

Cell[BoxData["True"], "Output",
 CellLabel->"Out[42]=",ExpressionUUID->"5170dd79-277c-4223-877c-6317eb715748"]
}, Open  ]],

Cell[TextData[{
 "If we call the double root (2 in this case) ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "0"], TraditionalForm]],ExpressionUUID->
  "49e82996-22a8-4ac4-a720-105cd8625ef9"],
 ", then the recurrence relation has the explicit solution"
}], "Text",ExpressionUUID->"6dac7caa-a8f0-4228-b448-e78507310b21"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"\[Alpha]", "\[CenterDot]", 
     SubsuperscriptBox["r", "0", "n"]}], "+", 
    RowBox[{"n", "\[CenterDot]", "\[Beta]", "\[CenterDot]", 
     SubsuperscriptBox["r", "0", "n"]}]}]}], TraditionalForm]], "Equation",Exp\
ressionUUID->"caa56a50-5fab-42cd-9873-9f271fbad8b0"],

Cell[TextData[{
 "for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "ac33ed35-7a43-45f9-b589-aff3748601ae"],
 ", and for some constants \[Alpha] and \[Beta]. The initial conditions of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "87d67da9-9c54-4351-adbb-69a211ec9550"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "c28238d5-36ee-4144-bbc1-b9341c261e3d"],
 " produce the system of equations"
}], "Text",ExpressionUUID->"de08b8ea-cc73-443b-a9ab-1e0d8cfc3475"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]", "\[CenterDot]", 
         SuperscriptBox["2", "1"]}], "+", 
        RowBox[{"1", "\[CenterDot]", "\[Beta]", "\[CenterDot]", 
         SuperscriptBox["2", "1"]}]}], "=", "1"}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]", "\[CenterDot]", 
         SuperscriptBox["2", "2"]}], "+", 
        RowBox[{"2", "\[CenterDot]", "\[Beta]", "\[CenterDot]", 
         SuperscriptBox["2", "2"]}]}], "=", "4"}]}
    }]}], TraditionalForm]], "Equation",ExpressionUUID->"98c41362-e3b7-4714-\
bbba-1b5618b04663"],

Cell["As before, we solve this system for \[Alpha] and \[Beta].", "Text",ExpressionUUID->"369fc591-5f23-4519-bf3e-1d19a4ec2353"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphas2", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"alpha", "*", 
          RowBox[{"CERoots", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "+", 
         RowBox[{"beta", "*", 
          RowBox[{"CERoots", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"alpha", "*", 
          RowBox[{
           RowBox[{"CERoots", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
         RowBox[{"2", "*", "beta", "*", 
          RowBox[{
           RowBox[{"CERoots", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]", 
        "4"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[43]:=",ExpressionUUID->"fab7669a-e105-45ee-a2a2-e9b914b4f305"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"alpha", "\[Rule]", "0"}], ",", 
   RowBox[{"beta", "\[Rule]", 
    FractionBox["1", "2"]}]}], "}"}]], "Output",
 CellLabel->"Out[43]=",ExpressionUUID->"568dcbaf-f23a-42fc-8c97-e2e807a5b4a4"]
}, Open  ]],

Cell[TextData[{
 "And finally, substitute these values into the general form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"\[Alpha]", "\[CenterDot]", 
      SubsuperscriptBox["r", "0", "n"]}], "+", 
     RowBox[{"n", "\[CenterDot]", "\[Beta]", "\[CenterDot]", 
      SubsuperscriptBox["r", "0", "n"]}]}]}], TraditionalForm]],
  ExpressionUUID->"094d940c-ba2d-42d7-a289-3aae5b3edbfc"],
 "."
}], "Text",ExpressionUUID->"4a208ca7-ee24-4d1d-8ce3-9f16b61b1bd2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"alpha", "*", 
    RowBox[{
     RowBox[{"CERoots", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}], "+", 
   RowBox[{"n", "*", "beta", "*", 
    RowBox[{
     RowBox[{"CERoots", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}]}], "/.", 
  "alphas2"}]], "Input",
 CellLabel->"In[44]:=",ExpressionUUID->"aca4da73-36c5-4d09-9efd-d82ebacca5b7"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]], "Output",
 CellLabel->"Out[44]=",ExpressionUUID->"a65c0508-cd21-47a8-9b3f-62ee637e263f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A More General Recurrence Solver", "Subsubsection",ExpressionUUID->"ff0af02b-213b-4fe6-bb1f-18d29c855458"],

Cell[TextData[{
 "The steps carried out above are quite general and we can write a function, ",
 StyleBox["recSolver2", "Code"],
 ", which solves a recurrence relation (degree two, linear, homogeneous, with \
constant coefficients) regardless of whether the characteristic polynomial \
has distinct roots or not. The following function solves the recurrence"
}], "Text",ExpressionUUID->"7ca1f596-ba81-4e15-97ab-43a7350331be"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"c", "\[CenterDot]", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{"d", "\[CenterDot]", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"fffc08dd-b4f5-4afb-8ce0-8ccd535e6c6f"],

Cell[TextData[{
 "with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "u"}], TraditionalForm]],ExpressionUUID->
  "927835a1-bde3-41ec-811d-6cdc3b487b9e"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "v"}], TraditionalForm]],ExpressionUUID->
  "d57fd46d-b8c6-4ae3-bdcc-94e9db362fc7"],
 "."
}], "Text",ExpressionUUID->"3faca974-3cf0-403f-8d1b-5557722aaa11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"recSolver2", "[", 
   RowBox[{"c_", ",", "d_", ",", "u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"CERoots", ",", "alphas", ",", "alpha", ",", "beta", ",", "r"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "first", " ", "solve", " ", "the", " ", "characteristic", " ", 
      "equation"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CERoots", "=", 
      RowBox[{"r", "/.", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"r", "^", "2"}], "-", 
           RowBox[{"c", "*", "r"}], "-", "d"}], "\[Equal]", "0"}], ",", "r"}],
         "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "then", " ", "test", " ", "if", " ", "the", " ", "roots", " ", "are", 
       " ", "the", " ", "same"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"CERoots", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
        RowBox[{"CERoots", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"the", " ", "roots", " ", "are", " ", "the", " ", "same"}], 
         ",", " ", 
         RowBox[{"follow", " ", "the", " ", "last", " ", "example"}]}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"alphas", "=", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"alpha", "*", 
                 RowBox[{"CERoots", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "+", 
                RowBox[{"beta", "*", 
                 RowBox[{"CERoots", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}]}], "\[Equal]", "u"}], ",", 
              
              RowBox[{
               RowBox[{
                RowBox[{"alpha", "*", 
                 RowBox[{
                  RowBox[{"CERoots", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
                RowBox[{"2", "*", "beta", "*", 
                 RowBox[{
                  RowBox[{"CERoots", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]",
                "v"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"Function", "[", 
          RowBox[{"n", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"alpha", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}], "+", 
             RowBox[{"n", "*", "beta", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}]}], "/.", 
            "alphas"}]}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"otherwise", ",", " ", 
         RowBox[{"use", " ", "the", " ", "recSol2Distinct", " ", "method"}]}],
         " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"alphas", "=", 
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"alpha", "*", 
                 RowBox[{"CERoots", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "+", 
                RowBox[{"beta", "*", 
                 RowBox[{"CERoots", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}]}], "\[Equal]", "u"}], ",", 
              
              RowBox[{
               RowBox[{
                RowBox[{"alpha", "*", 
                 RowBox[{
                  RowBox[{"CERoots", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], "+", 
                RowBox[{"beta", "*", 
                 RowBox[{
                  RowBox[{"CERoots", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "^", "2"}]}]}], "\[Equal]",
                "v"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"alpha", ",", "beta"}], "}"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"Function", "[", 
          RowBox[{"n", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"alpha", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "^", "n"}]}], "+", 
             RowBox[{"beta", "*", 
              RowBox[{
               RowBox[{"CERoots", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "^", "n"}]}]}], "/.", 
            "alphas"}]}], "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[45]:=",ExpressionUUID->"c3651833-92e2-4e31-95b5-53aa958434db"],

Cell[TextData[{
 "The ",
 StyleBox["recSolver2", "Code"],
 " function first tests for a repeated root and then does the appropriate \
computation. We test this function on the examples we did by hand, such as \
the Fibonacci sequence:"
}], "Text",ExpressionUUID->"421b4674-29aa-47cc-b512-1363ab979458"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"recSolver2", "[", 
   RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "[", "n", 
  "]"}]], "Input",
 CellLabel->"In[46]:=",ExpressionUUID->"f9396282-6c14-4bbc-98a4-c77d6e6394f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox["5"]}], ")"}]}], ")"}], "n"], 
    SqrtBox["5"]]}], "-", 
  RowBox[{
   FractionBox["1", "5"], " ", 
   SuperscriptBox["2", 
    RowBox[{"-", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "5"}], "-", 
     SqrtBox["5"]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["5"]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]]}]}]], "Output",
 CellLabel->"Out[46]=",ExpressionUUID->"3d777c8e-7b48-490b-b01c-481d15a41a51"]
}, Open  ]],

Cell["For the example with a double root:", "Text",ExpressionUUID->"89b6a466-33ce-4c61-a4ac-cc570e6e3baf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"recSolver2", "[", 
   RowBox[{"4", ",", 
    RowBox[{"-", "4"}], ",", "1", ",", "4"}], "]"}], "[", "n", "]"}]], "Input",\

 CellLabel->"In[47]:=",ExpressionUUID->"711d2859-d653-4f1e-bc87-e473a6f1be35"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]], "Output",
 CellLabel->"Out[47]=",ExpressionUUID->"769544f5-2d8f-417e-8ebe-28b720043c12"]
}, Open  ]],

Cell["\<\
In both of those examples, the result is consistent with what we had obtained \
before. We will now use the solver to find the first 10 terms of the sequence \
defined by the following recurrence relation and initial conditions. \
\>", "Text",ExpressionUUID->"5f45494d-8cfc-48ab-a60e-71c56c2e431d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"4", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}], "-", 
     RowBox[{"3", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "2"}]]}]}]}], ",", "   ", 
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], ",", "  ", 
   RowBox[{
    RowBox[{"and", " ", 
     SubscriptBox["a", "2"]}], "=", "2"}]}], TraditionalForm]], "Equation",Exp\
ressionUUID->"93d6969b-0cb2-4bdf-8fde-c9ca3deffc37"],

Cell[TextData[{
 "We define ",
 StyleBox["g", "Code"],
 " to be the solution, but suppress the output with a semicolon, since we \
know the output of the assignment will just show the form of the pure \
function definition in terms of the local variables."
}], "Text",ExpressionUUID->"14db3f90-11ea-4bdc-a27c-08f80ac57e9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"recSolver2", "[", 
    RowBox[{"4", ",", 
     RowBox[{"-", "3"}], ",", "1", ",", "2"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[48]:=",ExpressionUUID->"12389314-7da9-4ec2-93ee-7c842e19f538"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"g", "[", "n", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[49]:=",ExpressionUUID->"cf882c47-159e-4df1-95a6-30709351f45e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "5", ",", "14", ",", "41", ",", "122", ",", "365", ",", 
   "1094", ",", "3281", ",", "9842"}], "}"}]], "Output",
 CellLabel->"Out[49]=",ExpressionUUID->"c309932f-e9e9-4240-83f1-1917ec42f31e"]
}, Open  ]],

Cell["\<\
As another example, consider the following recurrence relation\
\>", "Text",ExpressionUUID->"33bc1fbb-25d6-470b-bb97-46073b882d76"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"-", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "-", 
    SubscriptBox["a", 
     RowBox[{"n", "-", "2"}]]}]}], TraditionalForm]], "Equation",ExpressionUUI\
D->"794f2195-af85-485c-9bf2-997d859b3897"],

Cell[TextData[{
 "with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "1728bca6-00f5-477c-81eb-3472ae6ba4bd"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "1d248a38-453c-48b2-b5bc-704a817d675e"],
 "."
}], "Text",ExpressionUUID->"0b99b2a6-5927-40a8-bb71-3c592d1c9f82"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"recSolver2", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"h", "[", "n", "]"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[50]:=",ExpressionUUID->"1cb2ec1f-46b7-4566-9db5-023df2ca42e9"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"2", " ", "n"}], "3"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "/", "3"}]]}], ")"}]}], 
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], ")"}]}], 
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellLabel->"Out[51]=",ExpressionUUID->"2c9ff2e5-7821-4583-940c-bc59919bf0f1"]
}, Open  ]],

Cell[TextData[{
 "Notice that the solution to this recurrence is very complicated and \
requires the use of cube roots of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]],ExpressionUUID->
  "1654b992-02af-4832-b55f-946369d7befa"],
 ". However, if we compute the first 10 terms, we notice a very simple \
pattern emerges."
}], "Text",ExpressionUUID->"06decb25-4e97-4406-bfa0-2b9121fb3d4f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"h", "[", "n", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[52]:=",ExpressionUUID->"dfc3b10c-62e2-48d9-bc64-d08d1545aeca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", 
   RowBox[{"-", "3"}], ",", "1", ",", "2", ",", 
   RowBox[{"-", "3"}], ",", "1", ",", "2", ",", 
   RowBox[{"-", "3"}], ",", "1"}], "}"}]], "Output",
 CellLabel->"Out[52]=",ExpressionUUID->"51ff6713-5e49-4825-935d-0f5c2e8f97f9"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can make this pattern more explicit if we replace the numerical initial \
conditions with symbolic constants."
}], "Text",ExpressionUUID->"460f3583-9c9d-485a-b9f8-793eaa01ceaf"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", 
   RowBox[{"recSolver2", "[", 
    RowBox[{
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "1"}], ",", "\[Lambda]", ",", "\[Mu]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"k", "[", "n", "]"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[53]:=",ExpressionUUID->"ddd15485-89bb-4da9-8edf-dcd38c892d70"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"2", " ", "n"}], "3"]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", "\[Lambda]"}], "+", "\[Mu]"}], ")"}]}], 
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], ")"}], "n"], " ", 
    RowBox[{"(", 
     RowBox[{"\[Lambda]", "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]], " ", "\[Mu]"}]}], ")"}]}], 
   RowBox[{"1", "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "/", "3"}]]}]]}]], "Output",
 CellLabel->"Out[54]=",ExpressionUUID->"bde861b9-7d88-4f71-a00c-53f05e27c472"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"k", "[", "n", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[55]:=",ExpressionUUID->"cb2497cc-0c46-49e4-b53e-c557382d27c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Lambda]", ",", "\[Mu]", ",", 
   RowBox[{
    RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]"}], ",", "\[Lambda]", ",", 
   "\[Mu]", ",", 
   RowBox[{
    RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]"}], ",", "\[Lambda]", ",", 
   "\[Mu]", ",", 
   RowBox[{
    RowBox[{"-", "\[Lambda]"}], "-", "\[Mu]"}], ",", "\[Lambda]"}], 
  "}"}]], "Output",
 CellLabel->"Out[55]=",ExpressionUUID->"06c839ca-6a28-4269-879e-b23de263e7fe"]
}, Open  ]],

Cell["\<\
Note that the Greek letters are entered by pressing \[EscapeKey], then typing \
the name of the letter, and pressing \[EscapeKey] again, for example, \
\[EscapeKey]lambda\[EscapeKey] produces \[Lambda].\
\>", "Text",ExpressionUUID->"400eca21-8e92-4119-a756-034a292c7e6d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonhomogeneous Recurrence Relations", "Subsection",
 CellTags->"Section2b",ExpressionUUID->"eaaff216-bb72-4fa2-bf9c-f297be33940a"],

Cell["\<\
So far, we have restricted our attention to homogeneous linear recurrence \
relations with constant coefficients. However, the techniques used in solving \
them may be extended to provide solutions to nonhomogeneous linear recurrence \
relations with constant coefficients. That is, recurrence relations of the \
form\
\>", "Text",ExpressionUUID->"af610aba-b09f-4456-8246-17b9add99072"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}], "+", "\[CenterEllipsis]", "+", 
    RowBox[{
     SubscriptBox["c", "k"], 
     SubscriptBox["a", 
      RowBox[{"n", "-", "k"}]]}], "+", 
    RowBox[{"F", "(", "n", ")"}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"9de55e70-d39b-4ae7-9ff9-1f08c991d32d"],

Cell[TextData[{
 "with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "1"], ",", 
    SubscriptBox["c", "2"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["c", "k"]}], TraditionalForm]],ExpressionUUID->
  "1a5a6a28-b3e6-402b-aeb2-e60aec9563a8"],
 " real numbers and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "1c02fc3d-a30a-4932-909f-cf8a91e1eb24"],
 " a function depending only on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "a708fbd7-11c0-4046-a999-f4d4a70bf821"],
 ". To solve this more general form of a recurrence relation, we do two \
things: (1) find the solutions of the associated homogeneous recurrence \
relation (the relation obtained by removing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"F", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "e4ef88a0-54c2-46fb-8162-0df0a4c62348"],
 ") and (2) find a particular solution for the nonhomogeneous equation."
}], "Text",ExpressionUUID->"05abdf17-2aa1-43d6-8318-b0efd4f0fae0"],

Cell["Consider the following example: ", "Text",ExpressionUUID->"f69463cc-5ee5-4b27-b4f7-d3b049f67a1d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"6", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "-", 
    RowBox[{"9", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}], "+", 
    RowBox[{"n", "\[CenterDot]", 
     SuperscriptBox["3", "n"]}]}]}], TraditionalForm]], "Equation",ExpressionU\
UID->"ebaee1e7-1693-42ac-aa8d-b1427961dc81"],

Cell["from Example 12 of Section 8.2 in the text.", "Text",ExpressionUUID->"ca88b651-7c48-400a-ad50-1db3c4fc7119"],

Cell["\<\
The first step is to find the solutions to the associated homogeneous \
recurrence relation\
\>", "Text",ExpressionUUID->"1623ee01-0608-4f26-924a-23af21dfebfa"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["a", "n"], "=", 
   RowBox[{
    RowBox[{"6", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]]}], "-", 
    RowBox[{"9", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"4294e357-c5a4-49cf-8814-cd9ca3fdc81d"],

Cell[TextData[{
 "To do this, we can use our ",
 StyleBox["recSolver2", "Code"],
 ". We will use \[Alpha] and \[Beta] for the initial conditions so that we \
get all the solutions."
}], "Text",ExpressionUUID->"09635580-fd4a-4df3-b108-68ba49eda592"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hSolution", "=", 
   RowBox[{"recSolver2", "[", 
    RowBox[{"6", ",", 
     RowBox[{"-", "9"}], ",", "\[Alpha]", ",", "\[Beta]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"hSolution", "[", "n", "]"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[56]:=",ExpressionUUID->"3c00d87a-510f-4357-937c-0172607f3dff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["3", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", "\[Alpha]"}], "-", "\[Beta]"}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["3", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", "n", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "\[Alpha]"}], "+", "\[Beta]"}], 
    ")"}]}]}]], "Output",
 CellLabel->"Out[57]=",ExpressionUUID->"b483c7b5-1e34-4848-adb6-91e6f8aa2d87"]
}, Open  ]],

Cell[TextData[{
 "The second step is to find a particular solution. Theorem 6 in Section 8.2 \
of the textbook tells us how to find the form of the particular solution. \
Note that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", "n", ")"}], "=", 
    RowBox[{"n", "\[CenterDot]", 
     SuperscriptBox["3", "n"]}]}], TraditionalForm]],ExpressionUUID->
  "61d46c3b-93a0-4af1-9535-7684743cd0b5"],
 " and 3 is a root of the characteristic polynomial with multiplicity 2 (you \
can verify this by solving the characteristic equation of the associated \
homogeneous relation; it is also made apparent by the form of ",
 StyleBox["hSolution", "Code"],
 "). Thus, the theorem tells us that there is a particular solution of the \
form"
}], "Text",ExpressionUUID->"af9a0ae3-be35-496a-8606-d497507da310"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["n", "2"], "(", 
    RowBox[{
     RowBox[{"p", "\[CenterDot]", "n"}], "+", "q"}], ")"}], 
   SuperscriptBox["3", "n"]}], TraditionalForm]], "Equation",ExpressionUUID->\
"9b5c6669-6567-46d4-8a0b-2d6a50904d9e"],

Cell["\<\
We will define a function for the form of this particular solution.\
\>", "Text",ExpressionUUID->"f8ad793a-9708-4906-ace3-5cd1c608f1df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pForm", "[", "n_", "]"}], "=", 
  RowBox[{
   RowBox[{"n", "^", "2"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p", "*", "n"}], "+", "q"}], ")"}], "*", 
   RowBox[{"3", "^", "n"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[58]:=",ExpressionUUID->"376bb80a-6fdf-4883-9088-313def479341"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["3", "n"], " ", 
  SuperscriptBox["n", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"n", " ", "p"}], "+", "q"}], ")"}]}]], "Output",
 CellLabel->"Out[58]=",ExpressionUUID->"a8c90fcd-0455-45b0-a46c-e53bc61ef5da"]
}, Open  ]],

Cell[TextData[{
 "To find a particular solution, we need to find the values of ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "ce6804c0-7745-4563-b7b9-ff01dc0316fe"],
 " and ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "ca285882-5983-4d3b-8c1e-90202edd4ba1"],
 ". To find these values, we substitute the terms of ",
 StyleBox["pForm", "Code"],
 " into the recurrence relation. This gives us an equation in terms of ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "1c9ef79d-b99c-4e47-8fc3-f05cc6d707b4"],
 " and ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "cfd326c2-3a24-4ef5-aa5d-23377d5595b8"],
 " (and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "da47f20c-07a2-46a6-a820-21ce1c38cfcb"],
 ")."
}], "Text",ExpressionUUID->"b1d9e0b1-6195-44ff-b65e-2a031dc9acec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEqn", "=", 
  RowBox[{
   RowBox[{"pForm", "[", "n", "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"6", "*", 
     RowBox[{"pForm", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "-", 
    RowBox[{"9", "*", 
     RowBox[{"pForm", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}], "+", 
    RowBox[{"n", "*", 
     RowBox[{"3", "^", "n"}]}]}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[59]:=",ExpressionUUID->"2e639f58-d430-4e0b-a79f-168242c9e990"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["3", "n"], " ", 
   SuperscriptBox["n", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"n", " ", "p"}], "+", "q"}], ")"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    SuperscriptBox["3", "n"], " ", "n"}], "-", 
   RowBox[{
    SuperscriptBox["3", "n"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "n"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "n"}], ")"}], " ", "p"}], "+", "q"}], 
     ")"}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["3", "n"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "n"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", "p"}], "+", "q"}], 
     ")"}]}]}]}]], "Output",
 CellLabel->"Out[59]=",ExpressionUUID->"909b1130-68f5-4004-8eb3-034a113c08f0"]
}, Open  ]],

Cell[TextData[{
 "We simplify the equation with ",
 StyleBox[ButtonBox["Simplify",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Simplify"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"18d230a3-d356-456a-8b1a-ac8390b70788"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pEqn", "=", 
  RowBox[{"Simplify", "[", "pEqn", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[60]:=",ExpressionUUID->"98056576-8c5e-4d97-baf6-e45260265ba9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["3", "n"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "p"}], "+", 
     RowBox[{"n", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"6", " ", "p"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", "q"}]}], ")"}]}], "\[Equal]", "0"}]], "Output",
 CellLabel->"Out[60]=",ExpressionUUID->"752da592-e221-4f56-a3fc-d62914d53f4c"]
}, Open  ]],

Cell[TextData[{
 "Next, we will have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solve that equation for ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "3fd45841-a207-4f83-983d-d4e5f51e91d9"],
 " and ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "f0db8926-7e67-40c8-a3c1-5f9180b8f11e"],
 ". In order to indicate that we want ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find values of ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "bd8e6dce-5897-442b-9be0-75f4c86098e8"],
 " and ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "40eab006-3f26-47ce-ae86-8af4c093f9d0"],
 " that satisfy the equation for all values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "97d7cc78-ee3b-4663-a44f-db8c5bff8da1"],
 ", we will ask ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve"
}], "Text",ExpressionUUID->"becea88c-e5f7-4339-bff2-64ce6686e4ca"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[ForAll]", "n"}], ")"}], " ", 
    SuperscriptBox["3", "n"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], "p"}], "+", 
      RowBox[{"n", "(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"6", "p"}]}], ")"}], "+", 
      RowBox[{"2", "q"}]}], ")"}]}], "=", "0"}], TraditionalForm]], "Equation",\
ExpressionUUID->"44321418-5a6a-4258-8937-8cb68afeb2b8"],

Cell[TextData[{
 "We encode this using the ",
 StyleBox[ButtonBox["ForAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ForAll"], "FunctionLink"],
 " expression, with first argument ",
 StyleBox["n", "Code"],
 ", indicating that ",
 StyleBox["n", "Code"],
 " is the variable being quantified, and with second argument the equation. \
This expression will be the first argument to ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 ". The second argument will be ",
 StyleBox["{p,q}", "Code"],
 ", indicating that those are the variables we wish to solve for."
}], "Text",ExpressionUUID->"116cbddc-6617-45e2-ae82-cb8c229470a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pVals", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"ForAll", "[", 
     RowBox[{"n", ",", "pEqn"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "q"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[61]:=",ExpressionUUID->"f15f6f13-8140-45ba-89ae-2bb6609fb9e5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"p", "\[Rule]", 
     FractionBox["1", "6"]}], ",", 
    RowBox[{"q", "\[Rule]", 
     FractionBox["1", "2"]}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[61]=",ExpressionUUID->"9dc90fbf-f016-4482-a876-20631133bcd4"]
}, Open  ]],

Cell["Thus, the particular solution is:", "Text",ExpressionUUID->"a5442893-40d3-4453-bf40-6113d0533a98"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pForm", "[", "n", "]"}], "/.", 
  RowBox[{"pVals", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellLabel->"In[62]:=",ExpressionUUID->"5ed943f6-10b2-47d2-9aab-0919b1371820"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["3", "n"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox["1", "2"], "+", 
    FractionBox["n", "6"]}], ")"}], " ", 
  SuperscriptBox["n", "2"]}]], "Output",
 CellLabel->"Out[62]=",ExpressionUUID->"28182ac4-8fdb-44f7-bafa-af14f0f896df"]
}, Open  ]],

Cell[TextData[{
 "Putting it all together, we see that all solutions to the recurrence \
relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"6", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}], "-", 
     RowBox[{"9", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "2"}]]}], "+", 
     RowBox[{"n", "\[CenterDot]", 
      SuperscriptBox["3", "n"]}]}]}], TraditionalForm]],
  CellChangeTimes->{{3.558282112814363*^9, 3.558282131726244*^9}},
  ExpressionUUID->"5dacb056-5114-4f91-a2f6-a2a57fda4b7a"],
 " are of the form:"
}], "Text",ExpressionUUID->"69e021d0-00fb-4ec6-a47b-4da0ff8fa8af"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"hSolution", "[", "n", "]"}], "+", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"pForm", "[", "n", "]"}], "/.", 
    RowBox[{"pVals", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]], "Input",
 CellLabel->"In[63]:=",ExpressionUUID->"acdb790d-0476-42b9-acd9-bd88e562e46d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["3", "n"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], "+", 
     FractionBox["n", "6"]}], ")"}], " ", 
   SuperscriptBox["n", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["3", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", "\[Alpha]"}], "-", "\[Beta]"}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["3", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", "n", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "\[Alpha]"}], "+", "\[Beta]"}], 
    ")"}]}]}]], "Output",
 CellLabel->"Out[63]=",ExpressionUUID->"50b71482-15a5-4f48-bebd-824372463699"]
}, Open  ]],

Cell["where \[Alpha] and \[Beta] are the initial conditions.", "Text",ExpressionUUID->"d7cf57c6-041d-4723-b465-67415e36b6d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s Recurrence Solver"
}], "Subsection",
 CellTags->"Section2c",ExpressionUUID->"06538a81-a148-4776-9511-e73252624068"],

Cell[TextData[{
 "Now that we have seen how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to implement an algorithm to solve simple recurrence relations, it is time \
to introduce the Wolfram Language built-in function for solving recurrence \
relations."
}], "Text",ExpressionUUID->"8a02b186-e551-4809-bb04-bc51f7f4e60d"],

Cell[TextData[{
 "We have already seen the Wolfram Language function ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " for working with polynomial equations and systems of equations. Similarly, \
there is a function ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 ", which is engineered for dealing with recurrence relations. It is a much \
more sophisticated version of our ",
 StyleBox["recSolver2", "Code"],
 " function and can deal with recurrence relations of arbitrary degree, \
repeated roots, and nonlinear recurrence relations. The syntax of ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " is very similar to that of ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 ". The first argument is an equation or list of equations representing the \
recurrence relation and any initial conditions in terms of symbols of the \
form ",
 StyleBox["a[n+1]", "Code"],
 ", ",
 StyleBox["a[n]", "Code"],
 ", ",
 StyleBox["a[n-1]", "Code"],
 ", etc. The second argument is of one of two forms: ",
 StyleBox["a", "Code"],
 " or ",
 StyleBox["a[n]", "Code"],
 ", where ",
 StyleBox["a", "Code"],
 " is the symbol used in the first argument to name the sequence. The form of \
the output depends on which of these is used. The final argument is the \
symbol used in the first argument to represent the index of the sequence, for \
example, ",
 StyleBox["n", "Code"],
 "."
}], "Text",ExpressionUUID->"8ac5fbb7-3fdc-4344-a912-0b1bd308ab1a"],

Cell[TextData[{
 "For example, to solve the recurrence relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]], "+", 
     RowBox[{"2", "\[CenterDot]", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "349ae25e-1c8f-44ab-aa49-ba744bb1962a"],
 " with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    RowBox[{
     SubscriptBox["a", "2"], "=", "1"}]}], TraditionalForm]],ExpressionUUID->
  "8651fefd-1896-4a38-b9b7-1d582ad2b1f1"],
 ", you can enter the following."
}], "Text",ExpressionUUID->"5d474616-5ee7-429c-a6d7-fb45e1d26cf3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solveOutput", "=", 
  RowBox[{"RSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "[", "n", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"a", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "+", 
        RowBox[{"2", "*", 
         RowBox[{"a", "[", 
          RowBox[{"n", "-", "2"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", 
       RowBox[{"a", "[", "2", "]"}], "\[Equal]", "1"}]}], "}"}], ",", 
    RowBox[{"a", "[", "n", "]"}], ",", "n"}], "]"}]}]], "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"61b69945-cdd6-4365-bbc8-0e642ebfaad6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "[", "n", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "+", "n"}]], "+", 
       SuperscriptBox["2", "n"]}], ")"}]}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[64]=",ExpressionUUID->"724933a5-fc7c-4743-b527-120006d66e29"]
}, Open  ]],

Cell[TextData[{
 "Note that the structure of the solution is similar to that given by ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 ": a list of lists of rules. If there were multiple solutions, each solution \
would appear as a separate sublist. "
}], "Text",ExpressionUUID->"ef70cf4a-a1b9-4792-889c-5707e5bc42b0"],

Cell[TextData[{
 "In the example above, we gave the second argument in the form ",
 StyleBox["a[n]", "Code"],
 ". This resulted in a rule for ",
 StyleBox["a[n]", "Code"],
 ". The expression on the right side of the rule can be extracted by applying \
",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Code"],
 ") to the expression ",
 StyleBox["a[n]", "Code"],
 "."
}], "Text",ExpressionUUID->"773477e1-ea9b-40f6-8d2c-351a9b01a284"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", "n", "]"}], "/.", 
  RowBox[{"First", "[", "solveOutput", "]"}]}]], "Input",
 CellLabel->"In[65]:=",ExpressionUUID->"50139a77-2fd1-4d44-981d-7bece3f0af69"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], 
     RowBox[{"1", "+", "n"}]], "+", 
    SuperscriptBox["2", "n"]}], ")"}]}]], "Output",
 CellLabel->"Out[65]=",ExpressionUUID->"fe9a7ad1-22f2-4a68-80b2-88ee2fa93b21"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s break that down a bit. The ",
 StyleBox[ButtonBox["First",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/First"], "FunctionLink"],
 " function simply takes the first element of the ",
 StyleBox["solveOutput", "Code"],
 " list, which is the list containing the rule. That is, the above is the \
same as"
}], "Text",ExpressionUUID->"bf8146a8-5070-4355-a5d7-59c25805e46a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", "n", "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "[", "n", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"]}], "+", 
       SuperscriptBox["2", "n"]}], ")"}]}]}], "}"}]}]], "myCode",
 Editable->False,ExpressionUUID->"0599594c-25b5-4696-b031-aec1e20f15f9"],

Cell[TextData[{
 "This uses ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Code"],
 ") on the expression ",
 StyleBox["a[n]", "Code"],
 " by applying the rule that substitutes the expression for the symbol ",
 StyleBox["a[n]", "Code"],
 ". In other words, the above evaluates to the expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "3"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], "+", 
      SuperscriptBox["2", "n"]}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "c9a5862e-4416-4e73-9c7a-1e65c6a10ceb"],
 "."
}], "Text",ExpressionUUID->"02c7dbd0-d60a-4792-9db4-b9606818b7d1"],

Cell[TextData[{
 "If we give the second argument in the form ",
 StyleBox["a", "Code"],
 " instead of ",
 StyleBox["a[n]", "Code"],
 ", the output will have the same structure, a list of lists of rules, but \
the rules will relate the symbol ",
 StyleBox["a", "Code"],
 " to a pure ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " (",
 StyleBox["&", "Code"],
 ") rather than an expression."
}], "Text",ExpressionUUID->"d62d9b97-a7fc-4f64-a256-6781e7de0738"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solveOutput2", "=", 
  RowBox[{"RSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "[", "n", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"a", "[", 
         RowBox[{"n", "-", "1"}], "]"}], "+", 
        RowBox[{"2", "*", 
         RowBox[{"a", "[", 
          RowBox[{"n", "-", "2"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", 
       RowBox[{"a", "[", "2", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "a", 
    ",", "n"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[66]:=",ExpressionUUID->"0cb5e465-174f-4f91-aaf2-b2659bb75fdf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "n", "}"}], ",", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], 
          RowBox[{"1", "+", "n"}]], "+", 
         SuperscriptBox["2", "n"]}], ")"}]}]}], "]"}]}], "}"}], 
  "}"}]], "Output",
 CellLabel->"Out[66]=",ExpressionUUID->"c5747ec1-40ed-4fb6-9362-f07202f790dd"]
}, Open  ]],

Cell[TextData[{
 "This output is more difficult to read, but it makes it easier to transform \
the output of ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " into a function that we can use to compute values. To assign the symbol ",
 StyleBox["F", "Code"],
 " to the function that calculates values of this sequence, we just have to \
assign ",
 StyleBox["F", "Code"],
 " to the pure function, which we can extract just as we did above."
}], "Text",ExpressionUUID->"66887bbb-898c-4498-af91-100160d889b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{"a", "/.", 
   RowBox[{"First", "[", "solveOutput2", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[67]:=",ExpressionUUID->"c8b4db44-0572-43dc-8859-d07c20006ed3"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", "n", "}"}], ",", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"1", "+", "n"}]], "+", 
      SuperscriptBox["2", "n"]}], ")"}]}]}], "]"}]], "Output",
 CellLabel->"Out[67]=",ExpressionUUID->"218ac2da-447d-4aa1-a21d-946190455677"]
}, Open  ]],

Cell[TextData[{
 "Now, ",
 StyleBox["F", "Code"],
 " can be used to compute values."
}], "Text",ExpressionUUID->"a4d34a18-287d-4487-b6a5-732bec9938e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", "42", "]"}]], "Input",
 CellLabel->"In[68]:=",ExpressionUUID->"ef096864-eeb9-483d-84a5-23107dfb42b1"],

Cell[BoxData["1466015503701"], "Output",
 CellLabel->"Out[68]=",ExpressionUUID->"e40f3d59-f263-4207-a2b5-9fd4b53faf7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"F", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[69]:=",ExpressionUUID->"3939989d-e955-467b-8e3d-b577573f7ec0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "3", ",", "5", ",", "11", ",", "21", ",", "43", ",", 
   "85", ",", "171", ",", "341"}], "}"}]], "Output",
 CellLabel->"Out[69]=",ExpressionUUID->"9e96f9f7-ad43-4e10-8896-79a6cea4e234"]
}, Open  ]],

Cell[TextData[{
 "Observe that these agree with the values obtained with ",
 StyleBox[ButtonBox["RecurrenceTable",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RecurrenceTable"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"4c1594cf-1868-45bd-aaa1-78ead0c8cc5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RecurrenceTable", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "n", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "+", 
       RowBox[{"2", "*", 
        RowBox[{"a", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "1", "]"}], "\[Equal]", 
      RowBox[{"a", "[", "2", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "a", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[70]:=",ExpressionUUID->"7cd2d5bd-b876-4b00-934e-ac9a4d08b8f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "3", ",", "5", ",", "11", ",", "21", ",", "43", ",", 
   "85", ",", "171", ",", "341"}], "}"}]], "Output",
 CellLabel->"Out[70]=",ExpressionUUID->"e7c3233a-99bb-4305-84c2-3c53b5c1a532"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " function will let us solve nonhomogeneous recurrence relations like the \
Tower of Hanoi problem very easily. Recall that the Tower of Hanoi problem \
has the recurrence relation"
}], "Text",ExpressionUUID->"97fa47f1-0a1c-425e-9eb4-5ecdf0bc00cb"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["H", "n"], "=", 
   RowBox[{
    RowBox[{"2", "\[CenterDot]", 
     SubscriptBox["H", 
      RowBox[{"n", "-", "1"}]]}], "+", "1"}]}], TraditionalForm]], "Equation",\
ExpressionUUID->"5299f612-fb21-40cc-840a-ef77577de30a"],

Cell[TextData[{
 "with initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["H", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "ae4d8e94-9dda-41dd-8574-cf883b415546"],
 "."
}], "Text",ExpressionUUID->"77b4d4de-64da-449d-b48d-16a0f711d229"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "H", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"H", "=", 
  RowBox[{"H", "/.", 
   RowBox[{"First", "[", 
    RowBox[{"RSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "[", "n", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"H", "[", 
            RowBox[{"n", "-", "1"}], "]"}]}], "+", "1"}]}], ",", 
        RowBox[{
         RowBox[{"H", "[", "1", "]"}], "\[Equal]", "1"}]}], "}"}], ",", "H", 
      ",", "n"}], "]"}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[71]:=",ExpressionUUID->"f2c9f5ca-b0ee-4bb6-bcd2-e7afffe4993c"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", "n", "}"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["2", "n"]}]}], "]"}]], "Output",
 CellLabel->"Out[72]=",ExpressionUUID->"57f7265c-1bdb-4049-b41f-16aef0ab8b04"]
}, Open  ]],

Cell[TextData[{
 "Observe that in the above we used ",
 StyleBox["H", "Code"],
 " for both the name of the sequence and the symbol representing the \
resulting ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 ". While this is natural, it carries the caveat that it can only be executed \
once, because ",
 StyleBox["H", "Code"],
 " now has a value and thus cannot be used within ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 ". Hence, it is a good idea to ",
 StyleBox[ButtonBox["Clear",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Clear"], "FunctionLink"],
 " the symbol before making the assignment."
}], "Text",ExpressionUUID->"ac25e97c-0085-4c7d-bc84-39381c39b878"],

Cell[TextData[{
 "It is not necessary to specify the initial conditions for a recurrence \
relation when applying ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 ". If they are not present, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will still solve the equation, inserting symbolic constants (e.g., ",
 StyleBox["C[1]", "Code"],
 " and ",
 StyleBox["C[2]", "Code"],
 ") in place of numeric values, as the following example illustrates."
}], "Text",ExpressionUUID->"9826e36b-1c4a-4d9c-923f-b210eb8be67f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "G", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"G", "=", 
  RowBox[{"G", "/.", 
   RowBox[{"First", "[", 
    RowBox[{"RSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"G", "[", "n", "]"}], "==", 
       RowBox[{
        RowBox[{"2", "*", 
         RowBox[{"G", "[", 
          RowBox[{"n", "-", "1"}], "]"}]}], "-", 
        RowBox[{"6", "*", 
         RowBox[{"G", "[", 
          RowBox[{"n", "-", "2"}], "]"}]}]}]}], ",", "G", ",", "n"}], "]"}], 
    "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[73]:=",ExpressionUUID->"d849e09f-bfd2-448a-846b-3b5dcb8f0805"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", "n", "}"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["5"]}]}], ")"}], "n"], " ", 
     RowBox[{"C", "[", "1", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["5"]}]}], ")"}], "n"], " ", 
     RowBox[{"C", "[", "2", "]"}]}]}]}], "]"}]], "Output",
 CellLabel->"Out[74]=",ExpressionUUID->"5672d34d-30ab-4bd3-b3df-dd0a3c35b9d5"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["G", "Code"],
 " is still able to compute values, but they will be in terms of the \
constants."
}], "Text",ExpressionUUID->"7e9d001f-be62-429c-aaac-d89d72c8248e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G", "[", "5", "]"}]], "Input",
 CellLabel->"In[75]:=",ExpressionUUID->"59451adf-f53d-4694-ac21-bcd48b913cc7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["5"]}]}], ")"}], "5"], " ", 
   RowBox[{"C", "[", "1", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["5"]}]}], ")"}], "5"], " ", 
   RowBox[{"C", "[", "2", "]"}]}]}]], "Output",
 CellLabel->"Out[75]=",ExpressionUUID->"f17ec076-fa9f-469d-8317-55d7d181711d"]
}, Open  ]],

Cell[TextData[{
 "The capabilities of ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 ", like other Wolfram Language functions, are constantly being enhanced and \
extended. However, ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " is not a panacea\[Dash]\[Dash]you can easily find recurrence relations \
that it is incapable of solving. When ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " is unable to solve a recurrence relation, it simply returns unevaluated, \
as below."
}], "Text",ExpressionUUID->"bdce3446-ddb8-4a7f-821c-be83db9a50ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", "n", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "^", "2"}], "-", 
     RowBox[{"Exp", "[", 
      RowBox[{"2", "*", 
       RowBox[{"e", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "]"}]}]}], ",", "u", ",", "n"}], 
  "]"}]], "Input",
 CellLabel->"In[76]:=",ExpressionUUID->"bf3b522b-2fcb-46bb-a828-375e9df31e15"],

Cell[BoxData[
 RowBox[{"RSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", "n", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"e", "[", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "n"}], "]"}]}]]}], "+", 
     SuperscriptBox[
      RowBox[{"u", "[", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}], "]"}], "2"]}]}], ",", "u", ",", "n"}],
   "]"}]], "Output",
 CellLabel->"Out[76]=",ExpressionUUID->"5a0c4708-e968-4c6b-9fa4-498ee7272de5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Problem Solving with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and Recurrence Relations"
}], "Subsection",
 CellTags->"Section2d",ExpressionUUID->"552a7a6a-43d2-44b7-b485-820bafe2f4c8"],

Cell[TextData[{
 "It is often the case that a problem, as presented, gives no clue that a \
solution may be found using recurrence. Let us explore how we can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve a problem that is not explicitly expressed as one requiring the \
use of recurrence for its solution."
}], "Text",ExpressionUUID->"51fdbca4-bf0a-4648-ae45-84426032f4e7"],

Cell[TextData[{
 "Here is our problem: into how many regions is the plane divided by ",
 Cell[BoxData[
  FormBox["1000", TraditionalForm]],ExpressionUUID->
  "0d3aeb34-98b0-4d1c-a34d-777be88a76b8"],
 " lines, assuming that no two of the lines are parallel, and no three are \
coincident? Such a situation may arise in an attempt to model fissures in the \
ocean floor. "
}], "Text",ExpressionUUID->"a4469702-c2d7-4692-9222-c1a95f959ce7"],

Cell[TextData[{
 "To start, we might try to discover the answer for smaller numbers of lines. \
To generalize the problem, we may ask for the number of regions produced by \
",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "3ab58acf-300c-4f91-874a-dd457a54d5a6"],
 " lines, where ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8d5fd3cb-8486-46f5-9204-286b6dca7dcf"],
 " is some positive integer. It is fairly obvious that a single line \
(corresponding to the case ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "63a90fd0-af03-4854-bb73-b4e6281d4620"],
 ") divides the plane into two regions. Two lines, if they are not parallel, \
can easily be seen to divide the plane into four regions. (Two parallel lines \
produce only three regions.) If we call the number of regions produced by ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "cd9e447f-87cc-43f1-919e-5949e5b7b582"],
 " lines, no two of which are parallel and no three of which are coincident, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "e014635f-4865-4c8c-9a25-e3daa46f58e8"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "1"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "30b4b14b-5458-4867-be8e-cbd568a4d3a7"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "2"], "=", "4"}], TraditionalForm]],ExpressionUUID->
  "26cd2f82-87d3-4091-bd59-29e1f66daa29"],
 ". "
}], "Text",ExpressionUUID->"a8d02776-652d-4c04-b511-75b39e865d98"],

Cell[BoxData[
 GraphicsBox[{
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0]], EdgeForm[None], 
    LineBox[{{0.21250000000000005`, 0.9597222222222224}, {1.1569444444444448`,
      0.03194444444444433}}]}, 
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0]], EdgeForm[None], 
    LineBox[{{1.1125000000000003`, 0.9458333333333335}, {0.04027777777777786, 
     0.1680555555555554}}]}, 
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0]], EdgeForm[None], 
    LineBox[{{0.6847222222222223, 0.9513888888888891}, {0.9236111111111113, 
     0.04583333333333317}}]}},
  ContentSelectable->False,
  ImagePadding->{{0., 0.}, {0., 0.}},
  ImageSize->{327.096, 243.936},
  PlotLabel->"Figure 8.1: Three lines dividing the plane",
  PlotRange->{{0., 1.3333333333333335`}, {0., 1.}},
  PlotRangePadding->Automatic]], "Text",
 TextAlignment->Center,ExpressionUUID->"4339e3d7-9694-458c-90a3-d15df57955ec"],

Cell[TextData[{
 "What does the situation look like when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "3"}], TraditionalForm]],ExpressionUUID->
  "fa9eb7e6-3157-464b-a8c2-7cb7752fe196"],
 "? Figure 8.1 is representative of this situation. In this case, the number \
of regions is 7, so ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "3"], "=", "7"}], TraditionalForm]],ExpressionUUID->
  "fbf06e1d-7463-4bf1-aaba-055faef1fdee"],
 ". To find ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "4"], TraditionalForm]],ExpressionUUID->
  "ef245e9e-1046-4b7a-ba13-f2d007cd47b6"],
 ", we must add a fourth line to the diagram. This suggests trying to compute \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "4"], TraditionalForm]],ExpressionUUID->
  "e191f7eb-5a30-48db-bb30-3138e244a8c6"],
 " in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "3"], TraditionalForm]],ExpressionUUID->
  "aa639ff0-b528-408a-a69b-8c4974e8bb1d"],
 " so that we begin to think of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "5c4c57b4-c788-4293-916e-b3904b44fb51"],
 " as a recurrence relation. Figure 8.2 shows what the situation looks like \
when a fourth line is added to the three existing lines. From the assumptions \
that no two of the lines are parallel and no three pass through a single \
point, it follows that the new line must intersect each of the existing three \
lines in exactly one point. This means that the new line passes through \
exactly four of the regions formed by the original three lines. Each region \
that it passes through is divided into two regions, so the total number of \
new regions added by the fourth point is 4. Thus, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "4"], "=", 
    RowBox[{
     SubscriptBox["R", "3"], "+", "4"}]}], TraditionalForm]],ExpressionUUID->
  "3b20077d-bfba-4871-9ad3-a0b7c18bb772"],
 ". Similar arguments for a general configuration of lines reveals that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["R", "n"], TraditionalForm]],ExpressionUUID->
  "46690653-bb78-4233-9d43-15e49b035543"],
 " satisfies the recurrence relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "n"], "=", 
    RowBox[{
     SubscriptBox["R", 
      RowBox[{"n", "-", "1"}]], "+", "n"}]}], TraditionalForm]],
  ExpressionUUID->"4403c313-b6c5-4b83-88a5-bf46f66a6a20"],
 "."
}], "Text",ExpressionUUID->"7c7a0e9f-9e3b-4370-8744-eaad8f3fd2de"],

Cell[BoxData[
 GraphicsBox[{
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0.]], EdgeForm[None], 
    LineBox[{{0.21250000000000005`, 0.9597222222222224}, {1.1569444444444448`,
      0.03194444444444433}}]}, 
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0.]], EdgeForm[None], 
    LineBox[{{1.1125000000000003`, 0.9458333333333335}, {0.04027777777777786, 
     0.1680555555555554}}]}, 
   {StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[0.]], EdgeForm[None], 
    LineBox[{{0.6847222222222223, 0.9513888888888891}, {0.9236111111111113, 
     0.04583333333333317}}]}, 
   {Dashing[{Medium, Medium}], StrokeForm[Hue[0, 0, 0]], EdgeForm[GrayLevel[
    0]], EdgeForm[None], 
    LineBox[{{0.04166666666666674, 0.43534482758620685`}, {
     1.3261494252873567`, 0.4497126436781609}}]}},
  ContentSelectable->False,
  ImagePadding->{{0., 0.}, {0., 0.}},
  ImageSize->{327.096, 243.936},
  PlotLabel->"Figure 8.2: Four lines dividing the plane",
  PlotRange->{{0., 1.3333333333333335`}, {0., 1.}},
  PlotRangePadding->Automatic]], "Text",
 TextAlignment->Center,ExpressionUUID->"b8272d18-cc17-47ea-ae2a-2f3482d58c0f"],

Cell[TextData[{
 "Furthermore, we have already computed the initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "1"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "d26084db-3094-4bba-b58f-430c0489291a"],
 ". This is enough to solve the recurrence. "
}], "Text",ExpressionUUID->"94436269-9014-47ac-b5d6-c2312113335e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "R", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"R", "=", 
  RowBox[{"R", "/.", 
   RowBox[{"First", "[", 
    RowBox[{"RSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"R", "[", "n", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"n", "-", "1"}], "]"}], "+", "n"}]}], ",", 
        RowBox[{
         RowBox[{"R", "[", "1", "]"}], "\[Equal]", "2"}]}], "}"}], ",", "R", 
      ",", "n"}], "]"}], "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[77]:=",ExpressionUUID->"841df724-3d9e-4df8-9ccb-2114118331f4"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", "n", "}"}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "n", "+", 
      SuperscriptBox["n", "2"]}], ")"}]}]}], "]"}]], "Output",
 CellLabel->"Out[78]=",ExpressionUUID->"d29f8b7d-ffe8-4c6f-b0e9-3936bca29e4f"]
}, Open  ]],

Cell["\<\
To answer the question: how many regions is the plane divided by 1000 lines \
with no two parallel and no three coincident?\
\>", "Text",ExpressionUUID->"979b6697-5571-4f2c-9fc8-f85e99b604b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", "[", "1000", "]"}]], "Input",
 CellLabel->"In[79]:=",ExpressionUUID->"96410e39-20b8-4ed8-9aa2-10dc47f94137"],

Cell[BoxData["500501"], "Output",
 CellLabel->"Out[79]=",ExpressionUUID->"b442956d-4be0-4f52-b35b-7b967301c27f"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.3 Divide-and-Conquer Algorithms and Recurrence Relations", "Section",
 CellTags->"Section3",ExpressionUUID->"3707c835-8de7-4194-9348-ae560cfbadf7"],

Cell["\<\
A very good example of divide and conquer relations is the one provided by \
the binary search algorithm. Here, we consider a practical application of \
this algorithm in an implementation of a binary search on a sorted list of \
integers. This is the implementation of the algorithm described in Algorithm \
3 in Section 3.1 of the textbook and first presented in Section 3.1 of this \
manual. \
\>", "Text",ExpressionUUID->"f42c7728-84a6-455c-8914-57883eed3ced"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"binarySearch", "[", 
    RowBox[{"x_Integer", ",", 
     RowBox[{"A", ":", 
      RowBox[{"{", "__Integer", "}"}]}]}], "]"}], "/;", 
   RowBox[{"Less", "@@", "A"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "j", ",", "m", ",", "location"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "A", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"j", "=", "n"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"i", "<", "j"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"i", "+", "j"}], ")"}], "/", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"x", ">", 
           RowBox[{"A", "[", 
            RowBox[{"[", "m", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"i", "=", 
           RowBox[{"m", "+", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"j", "=", "m"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", 
        RowBox[{"A", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "i"}], ",", "\[IndentingNewLine]", 
       RowBox[{"location", "=", "0"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "location"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[80]:=",ExpressionUUID->"91599cc8-3ea9-4831-b4a7-dd9be3c878c8"],

Cell[TextData[{
 "The variable ",
 StyleBox["A", "Code"],
 " is the list of integers to search, which is assumed to be sorted in \
increasing order, and ",
 StyleBox["x", "Code"],
 " is the integer to search for. The local variables ",
 StyleBox["j", "Code"],
 " and ",
 StyleBox["i", "Code"],
 " are initialized to the number of elements in the list and 1, respectively. \
The ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop continues as long as ",
 StyleBox["i", "Code"],
 " and ",
 StyleBox["j", "Code"],
 " are different from each other. Each step of the loop serves to narrow the \
difference between them by calculating the middle of the list, represented by \
",
 StyleBox["m", "Code"],
 ", and determining which half ",
 StyleBox["x", "Code"],
 " is in. Eventually, the search will focus on one location in the list, \
which is either ",
 StyleBox["x", "Code"],
 " or, if not, the search has failed and the function returns 0."
}], "Text",ExpressionUUID->"ad9b521e-d693-44a8-94d5-b8eccbeeefda"],

Cell["\<\
Let us do the analysis of the algorithm to see how divide and conquer \
recurrence relations are generated. In general, a divide and conquer type \
recurrence relation has the form\
\>", "Text",ExpressionUUID->"1625fca2-75a3-4552-9df4-a404ada2b76b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"a", "\[CenterDot]", 
     RowBox[{"f", "(", 
      RowBox[{"n", "/", "b"}], ")"}]}], "+", 
    RowBox[{"g", "(", "n", ")"}]}]}], TraditionalForm]], "Equation",Expression\
UUID->"8aebe563-a3ea-4ce5-afe4-d04fb50ea6c0"],

Cell[TextData[{
 "Each iteration of the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop of ",
 StyleBox["binarySearch", "Code"],
 " produces a single list half the size of the original. Thus, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "c5397ed2-9d79-4ca7-889f-655d214c644f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "=", "2"}], TraditionalForm]],ExpressionUUID->
  "90168276-f030-4bd5-975e-7b90c53ccc93"],
 ". The function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "3467c747-be49-4da9-86e9-04df28f37539"],
 ", which measures the number of comparisons added in performing the \
reduction, is identically 2. This is because one comparison is added to see \
which half of the list the key is on, and one is added to see if the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop needs to continue. Therefore, for the ",
 StyleBox["binarySearch", "Code"],
 " algorithm, the recurrence relation is"
}], "Text",ExpressionUUID->"e616bb15-485c-47dc-b916-40105095e086"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "n", ")"}], "=", 
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"n", "/", "2"}], ")"}], "+", "2"}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"6a0dd28a-872f-4e1c-b9c0-\
95d969ac174f"],

Cell[TextData[{
 "Additionally, we can see that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "1", ")"}], "=", "2"}], TraditionalForm]],
  ExpressionUUID->"2c89a38f-6a2b-4663-ad40-0043e880bad1"],
 ", because if the list is of length 1, then the algorithm will do one \
comparison to determine that the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop is unnecessary and one comparison to make sure that the element being \
searched for is the one element in the list. We can now use ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " to solve this recurrence."
}], "Text",ExpressionUUID->"cfc5e730-b673-47c5-a268-28e9f8e54e41"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b", "[", "n", "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"b", "[", 
        RowBox[{"n", "/", "2"}], "]"}], "+", "2"}]}], ",", 
     RowBox[{
      RowBox[{"b", "[", "1", "]"}], "\[Equal]", "2"}]}], "}"}], ",", 
   RowBox[{"b", "[", "n", "]"}], ",", "n"}], "]"}]], "Input",
 CellLabel->"In[81]:=",ExpressionUUID->"7a25c73c-cc0e-45ea-a672-5e4c29a00e35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"b", "[", "n", "]"}], "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"Log", "[", "n", "]"}], 
        RowBox[{"Log", "[", "2", "]"}]]}], ")"}]}]}], "}"}], "}"}]], "Output",\

 CellLabel->"Out[81]=",ExpressionUUID->"c5097e66-3d01-4fe8-bdab-00af99a48601"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.4 Generating Functions", "Section",
 CellTags->"Section4",ExpressionUUID->"827c836d-20e9-4288-b62e-388b8a027ebb"],

Cell[TextData[{
 "Generating functions are a powerful tool for manipulating sequences of \
numbers and for solving a variety of counting problems. In this section, we \
will see how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to represent and manipulate generating functions."
}], "Text",ExpressionUUID->"dcb0cd60-e3e5-422b-8abd-6517837d4d61"],

Cell[TextData[{
 "The generating function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", "x", ")"}], TraditionalForm]],ExpressionUUID->
  "01038866-8228-4791-9ed1-4062c30f2fcf"],
 " for a sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SubscriptBox["a", "k"], "}"}], TraditionalForm]],ExpressionUUID->
  "dfc6d02c-27b6-4209-acc7-7ee3a537100e"],
 " is the formal power series"
}], "Text",ExpressionUUID->"ba55d524-b942-4349-baff-ee27a6fd6744"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "0"}], "\[Infinity]",
     LimitsPositioning->False], " ", 
    RowBox[{
     SubscriptBox["a", "k"], 
     SuperscriptBox["x", "k"]}]}], "=", 
   RowBox[{
    SubscriptBox["a", "0"], "+", 
    RowBox[{
     SubscriptBox["a", "1"], "x"}], "+", 
    RowBox[{
     SubscriptBox["a", "2"], 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     SubscriptBox["a", "3"], 
     SuperscriptBox["x", "3"]}], "+", "\[CenterEllipsis]", "+", 
    RowBox[{
     SubscriptBox["a", "k"], 
     SuperscriptBox["x", "k"]}], "+", "\[CenterEllipsis]"}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"95da0964-36b0-47f7-997c-\
a3bf29348dd5"],

Cell[TextData[{
 "It is called formal because we are not interested in evaluating it as a \
function of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "f5336c4d-46d8-4221-ad33-55ee0ef6008d"],
 ". Our focus is on finding a formula for its coefficients. In particular, \
this means that there are no convergence issues to be considered."
}], "Text",ExpressionUUID->"955655cc-7890-4267-8d42-5c89f136f87a"],

Cell[CellGroupData[{

Cell["Generating Functions Tools", "Subsection",
 CellTags->"Section4a",ExpressionUUID->"d61c0a35-b91a-4225-a30f-b2c18ffb08c2"],

Cell["\<\
The Wolfram Language provides extensive facilities for manipulating \
generating functions.\
\>", "Text",ExpressionUUID->"57793ff1-a747-4dd7-9b18-e403c9edad8f"],

Cell[TextData[{
 "The first thing we need to do is to learn how to create a power series in \
the Wolfram Language, which is done with the function ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 ". This function requires three arguments. The last argument is the \
variable, such as ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "46db42ee-3625-4d4d-a868-b91882ce7cd3"],
 ", that the generating function is to be written in terms of. The second \
argument is a variable, such as ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "72977a67-9916-44fd-9dac-01c156e9804f"],
 ", representing the index of summation. The first argument is an expression \
in terms of the index of summation that computes the coefficients of the \
series."
}], "Text",ExpressionUUID->"054d412e-2102-45c0-b62c-86e7c6837c30"],

Cell[TextData[{
 "For example, to create the generating function for the sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    SuperscriptBox["3", "k"], "}"}], TraditionalForm]],ExpressionUUID->
  "995ea9d7-993a-4646-a4b5-34444d32879d"],
 ", we use the following code."
}], "Text",ExpressionUUID->"a41feb07-fb3b-44ff-bbe8-0d02f550dc28"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GeneratingFunction", "[", 
  RowBox[{
   RowBox[{"3", "^", "k"}], ",", "k", ",", "x"}], "]"}]], "Input",
 CellLabel->"In[82]:=",ExpressionUUID->"518a8760-ca64-45f2-885b-e6c4202314dc"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", 
   RowBox[{"3", " ", "x"}]}]]], "Output",
 CellLabel->"Out[82]=",ExpressionUUID->"98cf2919-f3c7-4474-9417-b964d4775980"]
}, Open  ]],

Cell[TextData[{
 "Observe that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has automatically found a rational expression for the generating function. \
While this is a useful and exact representation of the generating function, \
you often want to be able to view the generating function as a power series. \
"
}], "Text",ExpressionUUID->"765266fe-9a7d-4c32-9081-cc714fac8b39"],

Cell[TextData[{
 "To obtain a series representation of the generating function, we use the ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " function. ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " is used to find the Taylor series of a function about a point. If you have \
taken Calculus, you may remember Taylor series. If not, it is enough to know \
that the Taylor series of a generating function around ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "b8ecd0bd-d6a1-4516-8c20-0c35be667c83"],
 " is the correct power series for our purposes."
}], "Text",ExpressionUUID->"f8d1abe5-7b2f-4fc9-a4f9-6aff4276ebf8"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " function requires two arguments. The first is the function, for example, \
",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"1", "-", 
     RowBox[{"3", "x"}]}]], TraditionalForm]],ExpressionUUID->
  "9f7993d3-57ae-49c1-b7cc-65376c65f8ea"],
 ". The second is a list of length three: the variable ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "b4ee3ad1-df03-4769-921e-806c1a5e087f"],
 ", the number 0, and the largest order, or exponent, to be displayed. For \
example, to display the first ten terms of the power series for ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"1", "-", 
     RowBox[{"3", "x"}]}]], TraditionalForm]],ExpressionUUID->
  "69679030-c01a-437c-8d89-cc0b7c133bbc"],
 ", we enter the following."
}], "Text",ExpressionUUID->"98a46fda-cc03-4116-b71a-a42a7f8ea600"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"seriesEx", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", "x"}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[83]:=",ExpressionUUID->"11fc4d62-da64-47d1-8767-8569da609d91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{"3", " ", "x"}], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"27", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"81", " ", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"243", " ", 
    SuperscriptBox["x", "5"]}], "+", 
   RowBox[{"729", " ", 
    SuperscriptBox["x", "6"]}], "+", 
   RowBox[{"2187", " ", 
    SuperscriptBox["x", "7"]}], "+", 
   RowBox[{"6561", " ", 
    SuperscriptBox["x", "8"]}], "+", 
   RowBox[{"19683", " ", 
    SuperscriptBox["x", "9"]}], "+", 
   RowBox[{"59049", " ", 
    SuperscriptBox["x", "10"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "11"],
    SeriesData[$CellContext`x, 0, {}, 0, 11, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 3, 9, 27, 81, 243, 729, 2187, 6561, 19683,
    59049}, 0, 11, 1],
  Editable->False]], "Output",
 CellLabel->"Out[83]=",ExpressionUUID->"123f4c03-b8d4-49bf-ae29-440fc0f254c4"]
}, Open  ]],

Cell[TextData[{
 "The output ends with ",
 Cell[BoxData[
  StyleBox[
   SuperscriptBox[
    RowBox[{"O", "[", "x", "]"}], "11"], "Input"]],
  CellChangeTimes->{{3.5584452767270527`*^9, 3.558445289145015*^9}},
  ExpressionUUID->"c6777a3f-ac4e-4043-b179-bd0345855a9d"],
 ", which indicates that the series continues with terms of degree 11 and \
higher."
}], "Text",ExpressionUUID->"5ebc9529-e356-4a9d-b504-ebbc21fb7ba8"],

Cell[TextData[{
 "If you wish to view the coefficients, without the generating function, you \
can apply ",
 StyleBox[ButtonBox["CoefficientList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CoefficientList"], "FunctionLink"],
 ", as shown below. The first argument is the series and the second is the \
variable."
}], "Text",ExpressionUUID->"69473794-5177-42de-8b5f-bc769ba78f7f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoefficientList", "[", 
  RowBox[{"seriesEx", ",", "x"}], "]"}]], "Input",
 CellLabel->"In[84]:=",ExpressionUUID->"430348bc-c401-4c76-9536-861fbc73fb2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "9", ",", "27", ",", "81", ",", "243", ",", "729", ",", 
   "2187", ",", "6561", ",", "19683", ",", "59049"}], "}"}]], "Output",
 CellLabel->"Out[84]=",ExpressionUUID->"e5f7cb34-e1e0-42c2-aee2-bb5ba29c2da0"]
}, Open  ]],

Cell[TextData[{
 "To create a power series from a recurrence relation, we need to combine the \
techniques of the last section for using ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " to solve a recurrence relation with the ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 " command. For example, consider the recurrence relation given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"2", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}], "-", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]], "+", "1"}]}], TraditionalForm]],
  ExpressionUUID->"c0a6d824-59cc-416c-b235-0ed9989155bc"],
 " with initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "0"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "5af3cc6c-5ad2-4277-aeec-03cd061aab19"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "2"}], TraditionalForm]],ExpressionUUID->
  "fafcd5a2-cbf4-47dc-91b8-950511e8c9f6"],
 "."
}], "Text",ExpressionUUID->"2704cb6e-f229-425b-9a7e-ac2effd2ef73"],

Cell[TextData[{
 "First, we apply the ",
 StyleBox[ButtonBox["RSolve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RSolve"], "FunctionLink"],
 " function and extract an expression for the general term of the sequence. \
Note that because we are interested in an expression that we can use in ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 ", it makes sense to solve for ",
 StyleBox["a[n]", "Code"],
 " rather than solving for ",
 StyleBox["a", "Code"],
 " and obtaining a pure ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 ". Either approach would work, however."
}], "Text",ExpressionUUID->"74cf0266-0121-43f3-8ef8-d8f684bdca5c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"recurrenceFormula", "=", 
  RowBox[{
   RowBox[{"a", "[", "n", "]"}], "/.", 
   RowBox[{"First", "[", "\[IndentingNewLine]", 
    RowBox[{"RSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "n", "]"}], "\[Equal]", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"a", "[", 
            RowBox[{"n", "-", "1"}], "]"}]}], "-", 
          RowBox[{"a", "[", 
           RowBox[{"n", "-", "2"}], "]"}], "+", "1"}]}], ",", 
        RowBox[{
         RowBox[{"a", "[", "0", "]"}], "\[Equal]", "1"}], ",", 
        RowBox[{
         RowBox[{"a", "[", "1", "]"}], "\[Equal]", "2"}]}], "}"}], ",", 
      RowBox[{"a", "[", "n", "]"}], ",", "n"}], "]"}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[85]:=",ExpressionUUID->"bd24dbaa-3abe-4afc-a6bd-61466f3bc693"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"2", "+", "n", "+", 
    SuperscriptBox["n", "2"]}], ")"}]}]], "Output",
 CellLabel->"Out[85]=",ExpressionUUID->"b19cf55b-c500-41bc-a0c3-fcbee5b80a07"]
}, Open  ]],

Cell[TextData[{
 "Now, we apply ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 " to this formula."
}], "Text",ExpressionUUID->"3bae876a-bc5e-4850-9f3c-eb351bb9228c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"recurrenceGFunction", "=", 
  RowBox[{"GeneratingFunction", "[", 
   RowBox[{"recurrenceFormula", ",", "n", ",", "x"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[86]:=",ExpressionUUID->"1ea1a66f-30de-4bf3-a7f6-175238d4ac7f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", "x", "-", 
   SuperscriptBox["x", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "x"}], ")"}], "3"]]], "Output",
 CellLabel->"Out[86]=",ExpressionUUID->"78f29ef3-f21c-41e0-b5f6-6678c227be70"]
}, Open  ]],

Cell[TextData[{
 "As above, we can use ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " to view this as a formal power series."
}], "Text",ExpressionUUID->"d423d6a4-e73e-4356-91a7-07c5fb0eeb27"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"recurrenceSeries", "=", 
  RowBox[{"Series", "[", 
   RowBox[{"recurrenceGFunction", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[87]:=",ExpressionUUID->"35d725e5-526f-482e-896f-2456180124ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   RowBox[{"2", " ", "x"}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"7", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"11", " ", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"16", " ", 
    SuperscriptBox["x", "5"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "6"],
    SeriesData[$CellContext`x, 0, {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 2, 4, 7, 11, 16}, 0, 6, 1],
  Editable->False]], "Output",
 CellLabel->"Out[87]=",ExpressionUUID->"79e0874a-a5fb-4fae-887f-309e4ff7f9e8"]
}, Open  ]],

Cell[TextData[{
 "We can also use the function ",
 StyleBox[ButtonBox["SeriesCoefficient",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SeriesCoefficient"], "FunctionLink"],
 " to obtain specific coefficients, rather than the entire series. This \
function has two distinct forms that are useful. First, you can give the \
output of ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " as the first argument and an integer as the second, and ",
 StyleBox[ButtonBox["SeriesCoefficient",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SeriesCoefficient"], "FunctionLink"],
 " will return the coefficient of that term. Note that for this to work, you \
must have already computed the series to the desired term. That is, the \
second argument of ",
 StyleBox[ButtonBox["SeriesCoefficient",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SeriesCoefficient"], "FunctionLink"],
 " must be no greater than the order of the output from ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"83488fe6-ae86-4648-84bb-086a9ca7e480"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SeriesCoefficient", "[", 
  RowBox[{"recurrenceSeries", ",", "3"}], "]"}]], "Input",
 CellLabel->"In[88]:=",ExpressionUUID->"d2b54227-39b3-4512-8ef4-3e13ba05f03c"],

Cell[BoxData["7"], "Output",
 CellLabel->"Out[88]=",ExpressionUUID->"9138673a-b3b8-42c7-993e-89c4651a18df"]
}, Open  ]],

Cell[TextData[{
 "The second, and even more useful, application of ",
 StyleBox[ButtonBox["SeriesCoefficient",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SeriesCoefficient"], "FunctionLink"],
 " has the same arguments as ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 ". Specifically, a generating function and a list consisting of the variable \
used in the function, the number 0, and a positive integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "2a8d04e6-5ea0-4a24-ac85-79ae46ebe399"],
 ". However, where ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " outputs the entire series out to the term of degree ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "03cb1578-7f59-41aa-af33-e00358ec8163"],
 ", ",
 StyleBox[ButtonBox["SeriesCoefficient",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SeriesCoefficient"], "FunctionLink"],
 " just returns the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "n"], TraditionalForm]],ExpressionUUID->
  "cff0c18a-278f-4861-9a2a-015f3385246c"],
 "."
}], "Text",ExpressionUUID->"f49520fd-8b2d-4005-bf54-9f2fba0a0b64"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SeriesCoefficient", "[", 
  RowBox[{"recurrenceGFunction", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[89]:=",ExpressionUUID->"cf1140fe-2b9a-4ac9-876d-4c6b44d3608f"],

Cell[BoxData["7"], "Output",
 CellLabel->"Out[89]=",ExpressionUUID->"8bbeb50f-406d-4d69-90c5-c4015358aaed"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving Problems with Generating Functions", "Subsection",
 CellTags->"Section4b",ExpressionUUID->"6c056ec8-20af-4ade-ad4c-2352b9692cf0"],

Cell[TextData[{
 "Generating functions are more than just a convenient way to represent \
numerical sequences. They are a powerful tool for solving recurrence \
relations, as well as other kinds of counting problems. This power stems from \
our ability to manipulate them like ordinary power series from Calculus and \
to interpret those manipulations. To illustrate ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s facilities for manipulating generating functions, \
consider Example 12 from Section 8.4 of the text:"
}], "Text",ExpressionUUID->"0ce079ae-05e3-4bb9-90f3-045cc4cfdcc7"],

Cell[TextData[{
 "Use generating functions to determine the number of ways to insert tokens \
worth $1, $2, and $5 into a vending machine to pay for an item that costs ",
 Cell[BoxData[
  FormBox["7", TraditionalForm]],ExpressionUUID->
  "483a309e-e264-4f7b-b25c-007f0b8943fa"],
 " dollars in both the cases when the order in which the tokens are inserted \
does not matter and when the order does matter. "
}], "Item1Paragraph",ExpressionUUID->"9327fb96-278f-4baf-ad3d-085f5b346778"],

Cell[TextData[{
 "Following the text, the solution to the problem when order does matter is \
the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "r"], TraditionalForm]],ExpressionUUID->
  "4616917c-256e-42ff-a969-70e18fbefeec"],
 " in the generating function"
}], "Text",ExpressionUUID->"0eefb3ad-cb1f-4869-a587-a711634ba8ba"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x", "+", 
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["x", "3"], "+", "\[CenterEllipsis]"}], ")"}], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["x", "4"], "+", 
     SuperscriptBox["x", "6"], "+", "\[CenterEllipsis]"}], ")"}], 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["x", "5"], "+", 
     SuperscriptBox["x", "10"], "+", 
     SuperscriptBox["x", "15"], "+", "\[CenterEllipsis]"}], ")"}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"8909390a-5f2f-4b7c-8a1e-\
5860515e8d5f"],

Cell[TextData[{
 "To solve the problem, we need to create the three power series and multiply \
them together. To create the first series, we can use the ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 " command demonstrated above. For example, the first series has every \
coefficient equal to 1, so its generating function can be found as shown \
below."
}], "Text",ExpressionUUID->"060d34d2-f868-4e8a-bacc-c214dcc7db55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"token1D", "=", 
  RowBox[{"GeneratingFunction", "[", 
   RowBox[{"1", ",", "n", ",", "x"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[90]:=",ExpressionUUID->"6818cc62-cbb5-4756-8411-4601a33294e2"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", "x"}]]], "Output",
 CellLabel->"Out[90]=",ExpressionUUID->"5995b411-3f57-4506-bfcb-3404e983a888"]
}, Open  ]],

Cell[TextData[{
 "For the $2 tokens, we need to represent ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    SuperscriptBox["x", "2"], "+", 
    SuperscriptBox["x", "4"], "+", "\[CenterEllipsis]"}], TraditionalForm]],
  ExpressionUUID->"d02bbc84-579a-4ac4-8ac5-a6b97aa28179"],
 ". Remember that ",
 StyleBox[ButtonBox["GeneratingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeneratingFunction"], "FunctionLink"],
 " requires an expression for the general coefficient as its first argument. \
In this case, it is easier to describe the series if we can include the \
entire term, not just the coefficients. That is, it is easier to say that the \
series is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"k", "=", "0"}], "TI"], "\[Infinity]",
     LimitsPositioning->False], " ", 
    SuperscriptBox["x", 
     RowBox[{"2", "k"}]]}], TraditionalForm]],ExpressionUUID->
  "cfa91ac5-04c1-4d94-ac8f-309ea6e3d879"],
 " than to write a formula for the coefficients. "
}], "Text",ExpressionUUID->"7fc90471-fbb9-4bf6-a39c-dfb591fa3e6a"],

Cell[TextData[{
 "Fortunately, we can do exactly that by applying the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function. Recall that the first argument to ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " is an expression for the generic term in terms of an index of summation, \
and the second argument defines the bounds of the summation. In this case, \
those bounds are 0 and ",
 StyleBox[ButtonBox["Infinity",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Infinity"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"47aedbc5-80d3-493a-a7a8-784ceb2fbe0d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"token2D", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"2", "*", "k"}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[91]:=",ExpressionUUID->"b0a078b6-2027-481c-af93-9795bd142c1a"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", 
   SuperscriptBox["x", "2"]}]]], "Output",
 CellLabel->"Out[91]=",ExpressionUUID->"c797f640-0742-4616-a586-200b57005b89"]
}, Open  ]],

Cell[TextData[{
 "Observe that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has automatically calculated the rational expression for this sum."
}], "Text",ExpressionUUID->"2bea4771-38d0-4143-8b4c-967d12d52e88"],

Cell[TextData[{
 "We could also use ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " for the $5 tokens. Alternatively, we could just refer to Table 1 in \
Section 8.4 of the text and enter the rational form ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"1", "-", 
     SuperscriptBox["x", "5"]}]], TraditionalForm]],ExpressionUUID->
  "2b62a4d2-c4ef-4c27-90a0-4cbf8bc63dbd"],
 " directly. "
}], "Text",ExpressionUUID->"bfd9c100-4237-471f-9694-958b99f35c27"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"token5D", "=", 
  RowBox[{"1", "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"x", "^", "5"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[92]:=",ExpressionUUID->"ec5a605a-8bb8-4e7d-a701-2515d1cd8e52"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", 
   SuperscriptBox["x", "5"]}]]], "Output",
 CellLabel->"Out[92]=",ExpressionUUID->"49340987-293c-4180-949f-1b1ff390999d"]
}, Open  ]],

Cell[TextData[{
 "We can use ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " to confirm that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does in fact recognize this as the generating function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", 
    SuperscriptBox["x", "5"], "+", 
    SuperscriptBox["x", "10"], "+", 
    SuperscriptBox["x", "15"], "+", "\[CenterEllipsis]"}], TraditionalForm]],
  ExpressionUUID->"2900960b-53a2-4d30-8161-c75e48599e4b"],
 "."
}], "Text",ExpressionUUID->"530da518-fb80-4207-80f4-c04a531538da"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{"token5D", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[93]:=",ExpressionUUID->"d7c9d6b2-58a3-4c13-b697-cb9c353907cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   SuperscriptBox["x", "5"], "+", 
   SuperscriptBox["x", "10"], "+", 
   SuperscriptBox["x", "15"], "+", 
   SuperscriptBox["x", "20"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "21"],
    SeriesData[$CellContext`x, 0, {}, 0, 21, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
   1, 0, 0, 0, 0, 1}, 0, 21, 1],
  Editable->False]], "Output",
 CellLabel->"Out[93]=",ExpressionUUID->"b9c8aec7-bb31-4f5a-a344-e245ba0246f6"]
}, Open  ]],

Cell[TextData[{
 "We algebraically combine the series with the usual multiplication and ",
 StyleBox[ButtonBox["Series",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Series"], "FunctionLink"],
 " will show us the power series expansion of the result."
}], "Text",ExpressionUUID->"ebcbd7dc-74b3-4ff8-92ac-636512f67935"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tokens", "=", 
  RowBox[{"token1D", "*", "token2D", "*", "token5D"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[94]:=",ExpressionUUID->"a094ba5a-fca5-4b20-93fe-67d7a24572a3"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["x", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["x", "5"]}], ")"}]}]]], "Output",
 CellLabel->"Out[94]=",ExpressionUUID->"e8dbe4b8-be5e-47a4-b735-afe6ae09d408"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{"tokens", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "7"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[95]:=",ExpressionUUID->"191101f4-dfff-4667-969b-b1e3b71900c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", "x", "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["x", "3"]}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x", "4"]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["x", "5"]}], "+", 
   RowBox[{"5", " ", 
    SuperscriptBox["x", "6"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["x", "7"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "8"],
    SeriesData[$CellContext`x, 0, {}, 0, 8, 1],
    Editable->False]}],
  SeriesData[$CellContext`x, 0, {1, 1, 2, 2, 3, 4, 5, 6}, 0, 8, 1],
  Editable->False]], "Output",
 CellLabel->"Out[95]=",ExpressionUUID->"9a476be6-fe76-4331-91b7-913630418071"]
}, Open  ]],

Cell[TextData[{
 "We can see from the above that there are 6 ways to pay for a $7 item (since \
the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "7"], TraditionalForm]],ExpressionUUID->
  "4ec7ff23-2dfc-4fca-aae0-9d102b416491"],
 " is 6), just as was computed in the text. If we wanted to know the number \
of ways to pay for an item costing $234, all we would need to do is find the \
coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "234"], TraditionalForm]],ExpressionUUID->
  "5fd125b9-06c6-4a54-9530-570587531fa4"],
 "."
}], "Text",ExpressionUUID->"89efee9d-22aa-4cf3-b0f7-f2c9cf86f9fd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SeriesCoefficient", "[", 
  RowBox[{"tokens", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "234"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[96]:=",ExpressionUUID->"690b6c65-bbf9-4d80-b942-e336415af613"],

Cell[BoxData["2832"], "Output",
 CellLabel->"Out[96]=",ExpressionUUID->"e7e296c6-376c-49c8-9c7f-086540459ed9"]
}, Open  ]],

Cell["\<\
For the second part of the question, the case where the order does matter, \
the text explains that the generating function we need is\
\>", "Text",ExpressionUUID->"06f52a91-92fc-4800-8da2-f1b0f0af5e00"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["x", "5"]}], ")"}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["x", "5"]}], ")"}], "2"], "+", "\[CenterEllipsis]"}], 
   "=", 
   FractionBox["1", 
    RowBox[{"1", "-", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["x", "5"]}], ")"}]}]]}], TraditionalForm]], "Equation",E\
xpressionUUID->"3966db4f-6ada-418f-82d4-13dfe0fa40b3"],

Cell[TextData[{
 "Again, if we did not already know the rational expression for the \
generating function, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " could find it using ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"c8a683d8-3d90-499f-898e-443d4a0fa292"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tokens2", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"x", "^", "5"}]}], ")"}], "^", "n"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[97]:=",ExpressionUUID->"054025f7-0499-4c4f-8ea3-91370660aed3"],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", "x", "-", 
   SuperscriptBox["x", "2"], "-", 
   SuperscriptBox["x", "5"]}]]], "Output",
 CellLabel->"Out[97]=",ExpressionUUID->"60467956-db50-4cd4-988b-b7fa6c84017e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SeriesCoefficient", "[", 
  RowBox[{"tokens2", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "7"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[98]:=",ExpressionUUID->"5559cad3-9e3b-4d46-92ed-b324fc01e526"],

Cell[BoxData["26"], "Output",
 CellLabel->"Out[98]=",ExpressionUUID->"6dc3bacd-eef1-4a19-b608-332e1c00ebc3"]
}, Open  ]],

Cell[TextData[{
 "Thus, the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "7"], TraditionalForm]],ExpressionUUID->
  "661cf89d-611e-4c1c-92af-b9afbe3e0811"],
 " is 26, so there are 26 ways to pay for a $7 item when order does matter."
}], "Text",ExpressionUUID->"b2cc5d1f-bac1-4a3a-b8e3-1518c329dd3b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.5 Inclusion\[Dash]Exclusion", "Section",
 CellTags->"Section5",ExpressionUUID->"bc3e1ed2-484f-4380-839b-e476fb40560d"],

Cell["\<\
In this section, we will apply the principle of inclusion and exclusion. At \
the heart of the principle of inclusion and exclusion is the formula\
\>", "Text",ExpressionUUID->"326dfc38-5308-4ebc-8ea8-1e1aebae9d40"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"A", "\[Union]", "B"}], "|"}], "=", 
   RowBox[{"|", "A", "|", 
    RowBox[{"+", 
     RowBox[{"|", "B", "|", 
      RowBox[{"-", 
       RowBox[{"|", 
        RowBox[{"A", "\[Intersection]", "B"}], "|"}]}]}]}]}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"5d280777-f835-46d8-93c3-\
31e2581a7e0d"],

Cell[TextData[{
 "which says that, for two finite sets ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]],ExpressionUUID->
  "94bb8066-a747-4343-928c-a26807cd4f74"],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],ExpressionUUID->
  "d8887c48-3cc1-48d7-b751-7a921b291b2e"],
 ", the number of elements in the union ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "\[Union]", "B"}], TraditionalForm]],ExpressionUUID->
  "67ba59ed-14c4-4b8c-87cb-c86994b76541"],
 " of the two sets may be found by adding the sizes of ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]],ExpressionUUID->
  "2b021e2f-b3b9-4458-b49e-237e3a69f2c6"],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],ExpressionUUID->
  "009963d8-244d-443c-93cb-d9576ab5861b"],
 " and then subtracting the number of elements common to both ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]],ExpressionUUID->
  "ca80fcd8-5894-47e3-9660-d157d7de9d72"],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],ExpressionUUID->
  "f9b77ec6-877d-4ef7-9be8-9e0d59137808"],
 ", which would otherwise be counted twice. This formula can be generalized \
to count the number of elements in the union of any finite number of finite \
sets."
}], "Text",ExpressionUUID->"70499103-7086-40e1-be2a-0c32f5749dd5"],

Cell["\<\
Recall that in the Wolfram Language, sets are represented as lists, but that \
the set operations put elements in a canonical order and remove duplicates. \
\>", "Text",ExpressionUUID->"f650b5ff-469a-4b56-a8d2-2b789a326e8b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "=", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[99]:=",ExpressionUUID->"7431bf5c-fb77-456f-b221-2a9dd35b0775"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellLabel->"Out[99]=",ExpressionUUID->"0785606a-1578-407c-9001-7e0eb54cbec8"]
}, Open  ]],

Cell[TextData[{
 "To find the cardinality of a set, you can use ",
 StyleBox[ButtonBox["Length",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Length"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"6a7681b2-dc84-4d05-9fc2-1785ae7913ce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "A", "]"}]], "Input",
 CellLabel->
  "In[100]:=",ExpressionUUID->"95c2cf2f-8ab2-4dcb-b798-5d640d519110"],

Cell[BoxData["3"], "Output",
 CellLabel->
  "Out[100]=",ExpressionUUID->"8a71b1d1-76a5-4e43-946c-3b7a67444449"]
}, Open  ]],

Cell[TextData[{
 "The set operations ",
 StyleBox[ButtonBox["Union",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Union"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Intersection",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Intersection"], "FunctionLink"],
 " can be applied in functional form, with each set an argument. You can also \
access operator forms with the aliases \[EscapeKey]",
 StyleBox["un",
  IgnoreSpellCheck->True],
 "\[EscapeKey] and \[EscapeKey]inter\[EscapeKey]. "
}], "Text",ExpressionUUID->"352a9490-8225-4a1b-9ada-fc25dabda075"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y", "=", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6", ",", "7", ",", "8"}], "}"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[101]:=",ExpressionUUID->"0ef11a52-4e3e-4b78-bb4f-23e96e37fdad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "[", 
  RowBox[{"X", ",", "Y"}], "]"}]], "Input",
 CellLabel->
  "In[103]:=",ExpressionUUID->"9ace9db6-f029-46c1-8160-be92250f2863"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}],
   "}"}]], "Output",
 CellLabel->
  "Out[103]=",ExpressionUUID->"58d762f9-c8ab-484c-b82f-b6c90e2c40af"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"X", "\[Union]", "Y"}]], "Input",
 CellLabel->
  "In[104]:=",ExpressionUUID->"480afa04-3dc1-4c26-b298-94a9e4019f6c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}],
   "}"}]], "Output",
 CellLabel->
  "Out[104]=",ExpressionUUID->"d94f2ac9-b2c5-4eaa-aa6f-a9a874a226e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Intersection", "[", 
  RowBox[{"X", ",", "Y"}], "]"}]], "Input",
 CellLabel->
  "In[105]:=",ExpressionUUID->"74ef6a37-42a4-450e-a2d4-b651238762a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5"}], "}"}]], "Output",
 CellLabel->
  "Out[105]=",ExpressionUUID->"941a6584-0b74-43b8-8086-779c09050b7c"]
}, Open  ]],

Cell[TextData[{
 "The set theoretic difference is computed by the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox[ButtonBox["Complement",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Complement"], "FunctionLink"],
 ". The following computes ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", "-", "Y"}], TraditionalForm]],ExpressionUUID->
  "faa57867-b1f7-4750-96b0-3965093da444"],
 "."
}], "Text",ExpressionUUID->"a8db56c6-e6e4-4536-af4f-91b33a0f8d14"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Complement", "[", 
  RowBox[{"X", ",", "Y"}], "]"}]], "Input",
 CellLabel->
  "In[106]:=",ExpressionUUID->"00edcbe7-adab-4fc2-ad32-c49fe1ffadb6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellLabel->
  "Out[106]=",ExpressionUUID->"a0de7b81-dc39-4d2f-a71c-121add715f6e"]
}, Open  ]],

Cell["\<\
Let us use the operations to illustrate the principle of inclusion and \
exclusion with a particular example.\
\>", "Text",ExpressionUUID->"2e6ff488-585f-4935-999d-8e997be915c1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"flintstones", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Fred\>\"", ",", "\"\<Wilma\>\"", ",", "\"\<Pebbles\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rubbles", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Barney\>\"", ",", "\"\<Betty\>\"", ",", "\"\<Bam Bam\>\""}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"husbands", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Fred\>\"", ",", "\"\<Barney\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wives", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Wilma\>\"", ",", "\"\<Betty\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kids", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Pebbles\>\"", ",", "\"\<Bam Bam\>\""}], "}"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[107]:=",ExpressionUUID->"221c6bc6-b426-4e28-9e3b-553dfd480df9"],

Cell["\<\
If this were a complete census, then the number of children living in Bedrock \
would be\
\>", "Text",ExpressionUUID->"3e7ba25d-8437-48b0-ae6c-705b4d5ed177"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "kids", "]"}]], "Input",
 CellLabel->
  "In[112]:=",ExpressionUUID->"6c5f146e-ffa2-48f8-aba7-a704e1fab60c"],

Cell[BoxData["2"], "Output",
 CellLabel->
  "Out[112]=",ExpressionUUID->"cc181860-8d51-4ebd-85d3-fdcc48dad117"]
}, Open  ]],

Cell["\<\
The number of Bedrock inhabitants who are either Flintstones or children is\
\>", "Text",ExpressionUUID->"3b56a5cb-7173-45f4-8ec7-0a651000b0e7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Union", "[", 
   RowBox[{"flintstones", ",", "kids"}], "]"}], "]"}]], "Input",
 CellLabel->
  "In[113]:=",ExpressionUUID->"47add31a-5c44-4896-9631-e115b5d9a28b"],

Cell[BoxData["4"], "Output",
 CellLabel->
  "Out[113]=",ExpressionUUID->"c7e6e690-7939-4431-b29d-0fb494bbdfcb"]
}, Open  ]],

Cell["\<\
According to the principle of inclusion and exclusion, this number should be \
the same as \
\>", "Text",ExpressionUUID->"bd973525-4083-4563-bcb9-11eb3baeff25"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "flintstones", "]"}], "+", 
  RowBox[{"Length", "[", "kids", "]"}], "-", 
  RowBox[{"Length", "[", 
   RowBox[{"Intersection", "[", 
    RowBox[{"flintstones", ",", "kids"}], "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[114]:=",ExpressionUUID->"ad79b971-50e0-414c-825c-b79946271b86"],

Cell[BoxData["4"], "Output",
 CellLabel->
  "Out[114]=",ExpressionUUID->"58c5747d-3206-4f39-90fb-b7b3de3fcd75"]
}, Open  ]],

Cell["which, of course, it is.", "Text",ExpressionUUID->"eda6f62e-1a46-4e33-9c83-dfdddae56cc1"],

Cell["\<\
As another example, consider the problem of determining the number of \
positive integers less than or equal to 100 that are not divisible by either \
2 or 11. First, we generate the set of positive integers less than or equal \
to 100. \
\>", "Text",ExpressionUUID->"0f4caa68-b0e8-4eeb-8ab9-e2a879e0273a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hundred", "=", 
  RowBox[{"Range", "[", "100", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[115]:=",ExpressionUUID->"e30d80aa-2204-4340-976f-21f257360210"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14", ",", "15",
    ",", "16", ",", "17", ",", "18", ",", "19", ",", "20", ",", "21", ",", 
   "22", ",", "23", ",", "24", ",", "25", ",", "26", ",", "27", ",", "28", 
   ",", "29", ",", "30", ",", "31", ",", "32", ",", "33", ",", "34", ",", 
   "35", ",", "36", ",", "37", ",", "38", ",", "39", ",", "40", ",", "41", 
   ",", "42", ",", "43", ",", "44", ",", "45", ",", "46", ",", "47", ",", 
   "48", ",", "49", ",", "50", ",", "51", ",", "52", ",", "53", ",", "54", 
   ",", "55", ",", "56", ",", "57", ",", "58", ",", "59", ",", "60", ",", 
   "61", ",", "62", ",", "63", ",", "64", ",", "65", ",", "66", ",", "67", 
   ",", "68", ",", "69", ",", "70", ",", "71", ",", "72", ",", "73", ",", 
   "74", ",", "75", ",", "76", ",", "77", ",", "78", ",", "79", ",", "80", 
   ",", "81", ",", "82", ",", "83", ",", "84", ",", "85", ",", "86", ",", 
   "87", ",", "88", ",", "89", ",", "90", ",", "91", ",", "92", ",", "93", 
   ",", "94", ",", "95", ",", "96", ",", "97", ",", "98", ",", "99", ",", 
   "100"}], "}"}]], "Output",
 CellLabel->
  "Out[115]=",ExpressionUUID->"26b6f8ff-2873-4189-b7fc-a485aa4e208c"]
}, Open  ]],

Cell["Next, we remove those elements that are divisible by 2: ", "Text",ExpressionUUID->"e560caaa-556d-45dc-b14c-e88272b82bf4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divBy2", "=", 
  RowBox[{"Complement", "[", 
   RowBox[{"hundred", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"2", "*", "i"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "50"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[116]:=",ExpressionUUID->"ded1ae00-7420-4aac-b3fd-f37b473d487c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "5", ",", "7", ",", "9", ",", "11", ",", "13", ",", 
   "15", ",", "17", ",", "19", ",", "21", ",", "23", ",", "25", ",", "27", 
   ",", "29", ",", "31", ",", "33", ",", "35", ",", "37", ",", "39", ",", 
   "41", ",", "43", ",", "45", ",", "47", ",", "49", ",", "51", ",", "53", 
   ",", "55", ",", "57", ",", "59", ",", "61", ",", "63", ",", "65", ",", 
   "67", ",", "69", ",", "71", ",", "73", ",", "75", ",", "77", ",", "79", 
   ",", "81", ",", "83", ",", "85", ",", "87", ",", "89", ",", "91", ",", 
   "93", ",", "95", ",", "97", ",", "99"}], "}"}]], "Output",
 CellLabel->
  "Out[116]=",ExpressionUUID->"6b3c25eb-af07-4087-90f3-5b630e87bdb6"]
}, Open  ]],

Cell["and those that are divisible by 11: ", "Text",ExpressionUUID->"ff47cda3-cb4e-4e29-9766-add804f776e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divBy11", "=", 
  RowBox[{"Complement", "[", 
   RowBox[{"hundred", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"11", "*", "i"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "9"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[117]:=",ExpressionUUID->"98909643-4ada-4155-8da9-de422fb365c4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10", ",", "12", ",", "13", ",", "14", ",", "15", ",", "16",
    ",", "17", ",", "18", ",", "19", ",", "20", ",", "21", ",", "23", ",", 
   "24", ",", "25", ",", "26", ",", "27", ",", "28", ",", "29", ",", "30", 
   ",", "31", ",", "32", ",", "34", ",", "35", ",", "36", ",", "37", ",", 
   "38", ",", "39", ",", "40", ",", "41", ",", "42", ",", "43", ",", "45", 
   ",", "46", ",", "47", ",", "48", ",", "49", ",", "50", ",", "51", ",", 
   "52", ",", "53", ",", "54", ",", "56", ",", "57", ",", "58", ",", "59", 
   ",", "60", ",", "61", ",", "62", ",", "63", ",", "64", ",", "65", ",", 
   "67", ",", "68", ",", "69", ",", "70", ",", "71", ",", "72", ",", "73", 
   ",", "74", ",", "75", ",", "76", ",", "78", ",", "79", ",", "80", ",", 
   "81", ",", "82", ",", "83", ",", "84", ",", "85", ",", "86", ",", "87", 
   ",", "89", ",", "90", ",", "91", ",", "92", ",", "93", ",", "94", ",", 
   "95", ",", "96", ",", "97", ",", "98", ",", "100"}], "}"}]], "Output",
 CellLabel->
  "Out[117]=",ExpressionUUID->"13365711-172e-4eb1-8327-9f2e87166c8c"]
}, Open  ]],

Cell["\<\
We are looking for integers that belong to either or both of those sets, that \
is, to their union, so we calculate:\
\>", "Text",ExpressionUUID->"a2db659f-5964-42a0-8366-17f4568d0bec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Union", "[", 
   RowBox[{"divBy2", ",", "divBy11"}], "]"}], "]"}]], "Input",
 CellLabel->
  "In[118]:=",ExpressionUUID->"cfeeab08-f645-4c16-976b-7128d9768574"],

Cell[BoxData["96"], "Output",
 CellLabel->
  "Out[118]=",ExpressionUUID->"b8c758e6-544e-4506-b264-52595b42f926"]
}, Open  ]],

Cell["\<\
According to the principle of inclusion and exclusion, this value could also \
be computed as\
\>", "Text",ExpressionUUID->"21060c3f-b5af-4adb-bfdd-dd88b1990a62"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "divBy2", "]"}], "+", 
  RowBox[{"Length", "[", "divBy11", "]"}], "-", 
  RowBox[{"Length", "[", 
   RowBox[{"Intersection", "[", 
    RowBox[{"divBy2", ",", "divBy11"}], "]"}], "]"}]}]], "Input",
 CellLabel->
  "In[119]:=",ExpressionUUID->"e750444f-1bea-42d9-8a9b-f7eb5489b0bb"],

Cell[BoxData["96"], "Output",
 CellLabel->
  "Out[119]=",ExpressionUUID->"1299426d-aa82-42f8-b4a5-f85513f3b115"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.6 Applications of Inclusion\[Dash]Exclusion", "Section",
 CellTags->"Section6",ExpressionUUID->"bcc9c2a2-2728-4f53-adc7-d02705ee65c3"],

Cell["\<\
In this section, we will explore the following problem: Three sets of twins, \
Ashley and Amanda Abel, Brandon and Benjamin Bernoulli, and Christopher and \
Courtney Cartan (none of whom bear any relation to the mathematicians with \
the same surname), are to be seated in a row. List the ways in which they can \
be seated so that no person sits next to their twin. \
\>", "Text",ExpressionUUID->"04f66bd7-b846-4873-96db-e18aeafcc563"],

Cell["\<\
The principle of inclusion\[Dash]exclusion gives us insight into how we might \
accomplish this task. Rather than attempting to generate only those seating \
arrangements in which no person sits next to their twin, it will be easier to \
consider all the possible arrangements of the twins and then exclude those \
that do not satisfy the condition. To begin, we define lists to store the \
names of the twins. \
\>", "Text",ExpressionUUID->"733f926e-e64a-434a-a1a3-fc4f925f2868"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"abels", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Ashley\>\"", ",", "\"\<Amanda\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bernoullis", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Brandon\>\"", ",", "\"\<Benjamin\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cartans", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<Christopher\>\"", ",", "\"\<Courtney\>\""}], "}"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[120]:=",ExpressionUUID->"cf3c8156-b293-43e8-ad25-0208521320da"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twins", "=", 
  RowBox[{"{", 
   RowBox[{"abels", ",", "bernoullis", ",", "cartans"}], "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[123]:=",ExpressionUUID->"205bc153-7ca1-42d0-b682-9d711c60d9e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Ashley\"\>", ",", "\<\"Amanda\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brandon\"\>", ",", "\<\"Benjamin\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Christopher\"\>", ",", "\<\"Courtney\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellLabel->
  "Out[123]=",ExpressionUUID->"e77bfa32-02e8-4980-a39d-37cf23c88618"]
}, Open  ]],

Cell[TextData[{
 "Next, we create a function to test whether an arrangement satisfies the \
condition of having no twins seated next to each other. We will use this \
function to determine which ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 " to accept."
}], "Text",ExpressionUUID->"da25e356-bd80-44bb-88fd-65b0702775d2"],

Cell["\<\
To test whether a given arrangement has a pair of twins seated next to one \
another, we will consider the five pairs of seats, 1 and 2, 2 and 3, ..., 5 \
and 6, and check to see if the people seated in those positions are twins.\
\>", "Text",ExpressionUUID->"e446bea9-65ac-4eaf-ac82-c17dc0891079"],

Cell[BoxData[
 RowBox[{
  RowBox[{"testSeating", "[", "seating_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "twinpair"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Catch", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "5"}], ",", 
        RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"MemberQ", "[", 
              RowBox[{"twinpair", ",", 
               RowBox[{"seating", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "&&", 
             RowBox[{"MemberQ", "[", 
              RowBox[{"twinpair", ",", 
               RowBox[{"seating", "[", 
                RowBox[{"[", 
                 RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"Throw", "[", "False", "]"}]}], "]"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"twinpair", ",", "twins"}], "}"}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Throw", "[", "True", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[124]:=",ExpressionUUID->"4c461936-1818-4532-bba2-bc4734867d38"],

Cell[TextData[{
 "The function is passed a list of the six people\[CloseCurlyQuote]s names, \
representing a seating, so that the person in the third seat is ",
 StyleBox["seating[[3]]", "Code"],
 ". The ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop indexed by ",
 StyleBox["i", "Code"],
 " goes through the five pairs of seats. The inner ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop avoids having to duplicate the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement. We could have written one ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement checking to see if the people in seats ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "df9e5f2c-6dcd-466d-a352-5eeaf5806191"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "22aa4392-e07b-40cd-9440-8051b1641284"],
 " are both ",
 StyleBox["Abels",
  IgnoreSpellCheck->True],
 ", and then a second ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement to see if they are both ",
 StyleBox["Bernoullis",
  IgnoreSpellCheck->True],
 ", and then a third to see if they are both ",
 StyleBox["Cartans",
  IgnoreSpellCheck->True],
 ". Instead, the loop sets the ",
 StyleBox["twinpair", "Code",
  IgnoreSpellCheck->True],
 " variable to each of the lists in ",
 StyleBox["twins", "Code"],
 " in turn. That is, ",
 StyleBox["twinpair", "Code",
  IgnoreSpellCheck->True],
 " represents, at each step in the loop, one of the families. Then, the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement checks to see whether the people in the seats ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "d6fb68cd-3424-43f4-8723-3508c549ce5d"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "e73a7588-aa18-484b-a608-0814dd723b2a"],
 " are members of that family, using the ",
 StyleBox[ButtonBox["MemberQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MemberQ"], "FunctionLink"],
 " test. Recall that ",
 StyleBox[ButtonBox["MemberQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MemberQ"], "FunctionLink"],
 " returns true if the second argument is a member of the first. If any of \
these ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statements are true, that the people in the pair of consecutive seats are \
from the same family, then false is thrown to the enclosing ",
 StyleBox[ButtonBox["Catch",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Catch"], "FunctionLink"],
 ", indicating that the seating is not acceptable. If the seating survives \
all of the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statements, then the function returns true."
}], "Text",ExpressionUUID->"5c78b33e-6aad-464c-b634-3642c9c8e7de"],

Cell[TextData[{
 "To check the ",
 StyleBox["testSeating", "Code"],
 " function, consider the following potential ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 "."
}], "Text",ExpressionUUID->"e245bb17-ab02-4303-a100-ddd57e222661"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"seating1", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Ashley\>\"", ",", "\"\<Amanda\>\"", ",", "\"\<Brandon\>\"", ",", 
     "\"\<Benjamin\>\"", ",", "\"\<Christopher\>\"", ",", 
     "\"\<Courtnet\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seating2", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Ashley\>\"", ",", "\"\<Brandon\>\"", ",", "\"\<Christopher\>\"", 
     ",", "\"\<Amanda\>\"", ",", "\"\<Benjamin\>\"", ",", 
     "\"\<Courtney\>\""}], "}"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[125]:=",ExpressionUUID->"db412539-56e5-47a2-a495-3a5bdc00f942"],

Cell["\<\
We see that the first seating fails but the second passes, as they should. \
\>", "Text",ExpressionUUID->"ac51711d-2462-4547-936a-fa626614fa0c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testSeating", "[", "seating1", "]"}]], "Input",
 CellLabel->
  "In[127]:=",ExpressionUUID->"d6bc8b90-5340-40bc-b480-ca198099b5e4"],

Cell[BoxData["False"], "Output",
 CellLabel->
  "Out[127]=",ExpressionUUID->"032795db-b733-465e-b3d4-3c5320b2339c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testSeating", "[", "seating2", "]"}]], "Input",
 CellLabel->
  "In[128]:=",ExpressionUUID->"f2da1972-0702-427f-8897-fc6356ce3a14"],

Cell[BoxData["True"], "Output",
 CellLabel->
  "Out[128]=",ExpressionUUID->"19d039fd-2ab3-44a0-96b7-67e24e3ce7cb"]
}, Open  ]],

Cell[TextData[{
 "We now have a function to test a potential seating for the condition of not \
having twins seated next to each other. To generate a list of all of such ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 ", we will use the Wolfram Language\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Permutations",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Permutations"], "FunctionLink"],
 " function to generate all the possible permutations of the people and then \
test to see which are valid and which should be discarded. The ",
 StyleBox[ButtonBox["Permutations",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Permutations"], "FunctionLink"],
 " command takes a list and returns all the possible permutations of the \
objects. (Refer to Chapter 6 of this manual for more information about this \
function.)"
}], "Text",ExpressionUUID->"66db2a6f-9ec3-43a0-bb61-ff7c9f8f3770"],

Cell[TextData[{
 "Note that the ",
 StyleBox[ButtonBox["Permutations",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Permutations"], "FunctionLink"],
 " function expects a list of objects, so we will need a list of all the \
people. We can use the ",
 StyleBox[ButtonBox["Flatten",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Flatten"], "FunctionLink"],
 " function to turn our ",
 StyleBox["twins", "Code"],
 " list into a list of all the names. ",
 StyleBox[ButtonBox["Flatten",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Flatten"], "FunctionLink"],
 " takes a list and removes any nesting of lists so that the result is a list \
of the objects."
}], "Text",ExpressionUUID->"18db868b-30f2-42a5-9c61-7e320c90b531"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", "twins", "]"}]], "Input",
 CellLabel->
  "In[129]:=",ExpressionUUID->"34a5a4ba-9782-4f45-9119-0ddc656474e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Ashley\"\>", ",", "\<\"Amanda\"\>", ",", "\<\"Brandon\"\>", 
   ",", "\<\"Benjamin\"\>", ",", "\<\"Christopher\"\>", 
   ",", "\<\"Courtney\"\>"}], "}"}]], "Output",
 CellLabel->
  "Out[129]=",ExpressionUUID->"2adf518c-f5ce-4bf6-b30d-9109a01f3ea0"]
}, Open  ]],

Cell[TextData[{
 "To create the list of only the valid ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 ", we will apply the ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 " function. ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 " requires two arguments. The first is a list of objects, and the second is \
a function of one argument that returns ",
 ButtonBox["true",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"],
 " for those elements of the list that satisfy the desired criterion. The \
result is the list of the elements that passed the test."
}], "Text",ExpressionUUID->"ad6d662a-bf39-4521-ba6c-49e634f99023"],

Cell[TextData[{
 "We apply ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 " to all of the permutations of the flattened list of twins with criterion \
function ",
 StyleBox["testSeating", "Code"],
 " and store its output in the variable ",
 StyleBox["twinSeatings", "Code"],
 " but suppress the output. Then, we use ",
 StyleBox[ButtonBox["Length",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Length"], "FunctionLink"],
 " to check how many possible ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 " there are. (It is generally a good idea to suppress the output of a \
function that is listing what may be a very large number of possibilities \
until you know how many there are, as the output may take some time to \
display.)"
}], "Text",ExpressionUUID->"3019d9d2-0bb1-4265-8480-85fa3c54b252"],

Cell[BoxData[
 RowBox[{
  RowBox[{"twinSeatings", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Permutations", "[", 
      RowBox[{"Flatten", "[", "twins", "]"}], "]"}], ",", "testSeating"}], 
    "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[130]:=",ExpressionUUID->"cbc148f8-c244-48be-9b12-5c0314ffceae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "twinSeatings", "]"}]], "Input",
 CellLabel->
  "In[131]:=",ExpressionUUID->"86bab380-bcaf-4eb0-989b-633141f626fa"],

Cell[BoxData["240"], "Output",
 CellLabel->
  "Out[131]=",ExpressionUUID->"d61c21a1-1f0d-4cb6-a281-6b3d54979490"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twinSeatings", "[", 
  RowBox[{"[", "123", "]"}], "]"}]], "Input",
 CellLabel->
  "In[132]:=",ExpressionUUID->"9b16f703-f413-4461-8e08-a39ee1ff4ce4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Benjamin\"\>", ",", "\<\"Ashley\"\>", 
   ",", "\<\"Christopher\"\>", ",", "\<\"Amanda\"\>", ",", "\<\"Brandon\"\>", 
   ",", "\<\"Courtney\"\>"}], "}"}]], "Output",
 CellLabel->
  "Out[132]=",ExpressionUUID->"5c46366d-dbdb-4734-adf5-e8c46bf2eb57"]
}, Open  ]],

Cell[TextData[{
 "We see that there are 240 possible ",
 StyleBox["seatings",
  IgnoreSpellCheck->True],
 " and have displayed the 123rd seating. "
}], "Text",ExpressionUUID->"5f339ea8-0487-41da-8b7a-361829851c4f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solutions to Computer Projects and Computations and Explorations\
\>", "Section",
 PageBreakWithin->False,
 CellTags->"Solutions",ExpressionUUID->"0e38ce4f-ee7f-4ee0-a234-b83f6c12a79f"],

Cell[CellGroupData[{

Cell["Computer Projects 12", "Subsection",
 PageBreakAbove->False,
 PageBreakWithin->False,
 CellTags->
  "SolutionsCP12",ExpressionUUID->"b31cf265-6ec8-4ddc-bbd7-d097bbda9a2b"],

Cell[TextData[{
 "Given positive integers ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "1689c80c-e66b-4820-b5a6-43359c3d382b"],
 " and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "fac4447e-9c1b-47ac-ab21-5d446e86b461"],
 ", find the number of onto functions from a set with ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "31d04674-3444-45a6-96f4-d89937995974"],
 " elements to a set with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "396530b7-2457-4974-ba40-eee737d5d6ae"],
 " elements."
}], "Problem",
 PageBreakAbove->False,
 PageBreakWithin->
  False,ExpressionUUID->"74b8f80a-02cc-4b41-8cc8-9a7ede5825d3"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " We have a very convenient formula:"
}], "Text",ExpressionUUID->"f0a647e6-4518-40b9-9604-f5920504af28"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "0"}], 
    RowBox[{"n", "-", "1"}],
    LimitsPositioning->False], " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "k"], 
    RowBox[{"C", "(", 
     RowBox[{"n", ",", "k"}], ")"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"n", "-", "k"}], ")"}], "m"]}]}], TraditionalForm]], "Equation",\
ExpressionUUID->"4a559b73-773c-4a39-9c14-7add5718ae7f"],

Cell[TextData[{
 "This is the number of onto functions from a set of ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "26e0faa9-ba9b-4c74-8630-125bbee9917a"],
 " elements to a set of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "053a0421-c4ab-4eb6-a80c-c59b04d35ad7"],
 " elements, assuming ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "\[GreaterEqual]", "n"}], TraditionalForm]],ExpressionUUID->
  "3a8c9b9e-c79d-4c22-b0a0-e105d1b80e0e"],
 ". This formula is derived in the textbook from the principle of inclusion\
\[Dash]exclusion (see Theorem 1 of Section 8.6). The only input required in \
this formula are the integer parameters ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "f5c10f15-9273-4cad-992e-9b621a30139e"],
 " and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "3b3ea268-2bca-4ae5-8c0b-64827f078a0d"],
 ", which represent the sizes of the domain and codomain, respectively. The \
Wolfram Language\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function will compute summations such as the one above. The first argument \
is an expression in terms of an index of summation (e.g., ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "4b28fcfd-a2cf-46be-a6ef-ee7ece994026"],
 "), and the second is of the form ",
 StyleBox["{k,a,b}", "Code"],
 " indicating the bounds of the summation. For example, to compute"
}], "Text",ExpressionUUID->"ff9cf72f-92fe-4496-b275-8edff052c6a7"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"k", "=", "3"}], "8",
    LimitsPositioning->False], " ", 
   FractionBox["1", "k"]}], TraditionalForm]], "Equation",ExpressionUUID->\
"57074cbe-aae1-4803-b8d3-39d2a46e4c65"],

Cell["you would enter the following expressions.", "Text",ExpressionUUID->"0f2eac2a-ae37-4e92-b0d1-5448179903d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{"1", "/", "k"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "3", ",", "8"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[133]:=",ExpressionUUID->"d3de9a66-c6ff-42b5-b3d5-fd82a74c3bba"],

Cell[BoxData[
 FractionBox["341", "280"]], "Output",
 CellLabel->
  "Out[133]=",ExpressionUUID->"a7efdde2-dde8-4bf7-8526-ccc650a2cf3d"]
}, Open  ]],

Cell["We now create a function encapsulating the formula above.", "Text",ExpressionUUID->"8ce4f345-2959-48dc-b642-28dc2084353a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ontoFunctions", "[", 
    RowBox[{"m_Integer", ",", "n_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"m", ">", "0"}], "&&", 
    RowBox[{"n", ">", "0"}]}]}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"m", "\[GreaterEqual]", "n"}], ",", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", "k"}], " ", "*", " ", 
       RowBox[{"Binomial", "[", 
        RowBox[{"n", ",", "k"}], "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "-", "k"}], ")"}], "^", "m"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", "0"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[134]:=",ExpressionUUID->"55833a35-3def-4170-9c04-3690b4ea03a8"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement captures the fact that there are no onto functions from a set to \
a set that is larger and ensures that the result is 0 in that case. The ",
 StyleBox[ButtonBox["Condition",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Condition"], "FunctionLink"],
 " (",
 StyleBox["/;", "Code"],
 ") ensures that the input to the function is positive and will return no \
output if not, since it is meaningless to ask about functions between sets of \
nonpositive ",
 StyleBox["cardinalities",
  IgnoreSpellCheck->True],
 ". "
}], "Text",ExpressionUUID->"a6bc89d3-89e0-41bd-9d35-1fad5e605d25"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ontoFunctions", "[", 
  RowBox[{"4", ",", "9"}], "]"}]], "Input",
 CellLabel->
  "In[135]:=",ExpressionUUID->"6ea5085b-7c89-4109-a75c-4d5cea282c40"],

Cell[BoxData["0"], "Output",
 CellLabel->
  "Out[135]=",ExpressionUUID->"774455c0-724d-43ba-bab8-cd546ace122f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ontoFunctions", "[", 
  RowBox[{
   RowBox[{"-", "3"}], ",", "0"}], "]"}]], "Input",
 CellLabel->
  "In[136]:=",ExpressionUUID->"a7b652b5-be49-4ea5-96ca-f151b58d15f5"],

Cell[BoxData[
 RowBox[{"ontoFunctions", "[", 
  RowBox[{
   RowBox[{"-", "3"}], ",", "0"}], "]"}]], "Output",
 CellLabel->
  "Out[136]=",ExpressionUUID->"57ecef77-21aa-48bc-8c65-ac3bf1df271d"]
}, Open  ]],

Cell["\<\
As an example, we can use our function to compute the number of onto \
functions from a set with 100 elements to a set with 20 elements. \
\>", "Text",ExpressionUUID->"acbf63ab-f864-4fad-8459-249016260d20"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ontoFunctions", "[", 
  RowBox[{"100", ",", "20"}], "]"}]], "Input",
 CellLabel->
  "In[137]:=",ExpressionUUID->"e3a3a3a9-1010-4299-aabc-928d58189e74"],

Cell[BoxData[\
"11238195910319657928539447038143170285517894975095769496294319007413091913959\
828334936464196298192508890182316163261067934269440000"], "Output",
 CellLabel->
  "Out[137]=",ExpressionUUID->"5787f9e2-05e6-498d-ae34-18916ad93dd9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computations and Explorations 2", "Subsection",
 CellTags->
  "SolutionsCE2",ExpressionUUID->"699e3556-6e7b-46dd-874f-93afdcbbaf6f"],

Cell[TextData[{
 "Find the smallest Fibonacci number greater than ",
 Cell[BoxData[
  FormBox["1000000", TraditionalForm]],ExpressionUUID->
  "e017dd6d-91a5-4dae-aab3-5d60f2ebae3c"],
 ", greater than ",
 Cell[BoxData[
  FormBox["1000000000", TraditionalForm]],ExpressionUUID->
  "91a039f1-f1ca-4380-ad6c-4ce997d446ae"],
 ", and greater than ",
 Cell[BoxData[
  FormBox["1000000000000", TraditionalForm]],ExpressionUUID->
  "3db8ead9-a588-4e81-bfa0-b0b23634a48c"],
 ". "
}], "Problem",ExpressionUUID->"92c87551-c109-42d0-b383-c94a67b989a3"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " We can solve this quite easily with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " using a simple ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop. In this chapter, we have seen several ways to compute Fibonacci \
numbers, including the ",
 StyleBox["fibonacci", "Code",
  IgnoreSpellCheck->True],
 " function we created in Section 8.1 and the formula ",
 StyleBox["fibonacci2", "Code"],
 " in Section 8.2. For this exercise, we will use the Wolfram Language \
built-in function ",
 StyleBox[ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"d3daa838-2ea8-4690-af8f-07620f707786"],

Cell[TextData[{
 "The idea is to compute Fibonacci numbers until the value exceeds the \
target. The ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop is well suited to this sort of problem. We will create a function \
that takes the target value as input and prints out the desired Fibonacci \
number and its index."
}], "Text",ExpressionUUID->"8394399b-2035-4b2a-af37-aebd22fa9ce0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findFib", "[", "target_Integer", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", "=", "1"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Fibonacci", "[", "n", "]"}], "<", "target"}], ",", 
       RowBox[{"n", "++"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
      "\"\<The \>\"", ",", "n", ",", "\"\<th Fibonacci number is \>\"", ",", 
       RowBox[{"Fibonacci", "[", "n", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[138]:=",ExpressionUUID->"a0ed6796-517b-4880-acc4-ff4767a4e4e8"],

Cell[TextData[{
 "As long as the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "1f993db3-f47c-4a12-8fdc-9872c0efae50"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " Fibonacci number is smaller than the target value, the index ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "85e7c5d1-a9fb-4b7f-b38e-3bdc0aae66c4"],
 " is increased. Once the target has been exceeded, the ",
 StyleBox[ButtonBox["Print",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Print"], "FunctionLink"],
 " statement displays the index and the value of the Fibonacci number."
}], "Text",ExpressionUUID->"79f018d7-9469-47c4-88f0-95f76a4d92e0"],

Cell["The numbers called for by the question are:", "Text",ExpressionUUID->"823c4476-4a99-4b37-b4d2-33db019a4746"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"findFib", "[", "1000000", "]"}]], "Input",
 CellLabel->
  "In[139]:=",ExpressionUUID->"dcf861c5-2151-4048-af29-056ddf6d6298"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\"th Fibonacci number is \"\>", 
   "\[InvisibleSpace]", "1346269"}],
  SequenceForm["The ", 31, "th Fibonacci number is ", 1346269],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[139]:=",ExpressionUUID->"312cb88b-c98c-4f22-b290-8d83df38ce98"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"findFib", "[", "1000000000", "]"}]], "Input",
 CellLabel->
  "In[140]:=",ExpressionUUID->"e6b95102-dfee-4d99-85f0-fa54aa1c74d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\"th Fibonacci number is \"\>", 
   "\[InvisibleSpace]", "1134903170"}],
  SequenceForm["The ", 45, "th Fibonacci number is ", 1134903170],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[140]:=",ExpressionUUID->"1696dd39-1fd5-4bd2-b094-8ab9b8901ed3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"findFib", "[", "1000000000000", "]"}]], "Input",
 CellLabel->
  "In[141]:=",ExpressionUUID->"6d52d84b-3cf8-44d4-8f66-e09682aa18fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\"th Fibonacci number is \"\>", 
   "\[InvisibleSpace]", "1548008755920"}],
  SequenceForm["The ", 60, "th Fibonacci number is ", 1548008755920],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[141]:=",ExpressionUUID->"e6f46472-e616-4f8e-a028-6db2cab1c949"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computations and Explorations 3", "Subsection",
 CellTags->
  "SolutionsCE3",ExpressionUUID->"65319e19-c333-444b-8489-08a558f02441"],

Cell["\<\
Find as many prime Fibonacci numbers as you can. It is unknown whether there \
are infinitely many of these. \
\>", "Problem",ExpressionUUID->"14990d1a-926a-44a4-ae39-9b2ffde9f17b"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", this sort of problem becomes fairly straightforward. We can simply use \
the Wolfram Language function ",
 StyleBox[ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"], "FunctionLink"],
 " to generate Fibonacci numbers and use the ",
 StyleBox[ButtonBox["PrimeQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PrimeQ"], "FunctionLink"],
 " function to test each for primality. We will wrap this in a function that \
takes a number of seconds as an argument and uses ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " to control the length of the evaluation. Note the use of ",
 StyleBox[ButtonBox["Sow",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sow"], "FunctionLink"],
 " within the ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " block and ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 " surrounding it. This allows the termination of the ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " portion of the function to trigger the ",
 StyleBox[ButtonBox["Reap",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reap"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"754cd4a0-df98-4635-a85f-21f776f0678c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"primeFib", "[", "time_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"i", "=", "0"}], ",", "temp", ",", 
      RowBox[{"primes", "=", 
       RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Reap", "[", "\[IndentingNewLine]", 
      RowBox[{"TimeConstrained", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"While", "[", 
         RowBox[{"True", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"i", "++"}], ";", "\[IndentingNewLine]", 
           RowBox[{"temp", "=", 
            RowBox[{"Fibonacci", "[", "i", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"PrimeQ", "[", "temp", "]"}], ",", 
             RowBox[{"Sow", "[", "temp", "]"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], ",", "time"}], "]"}], 
      "\[IndentingNewLine]", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[142]:=",ExpressionUUID->"19080887-a4e5-43b9-8b8f-2cc74713b630"],

Cell["\<\
We can obtain several examples even in only a hundredth of a second.\
\>", "Text",ExpressionUUID->"3ff3e77b-341e-49dd-84c1-39b0144d0247"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"primeFib", "[", "0.01", "]"}]], "Input",
 CellLabel->
  "In[143]:=",ExpressionUUID->"3d82e3c3-6419-4ed6-888e-281fd413041b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "3", ",", "5", ",", "13", ",", "89", ",", "233", ",", "1597", ",",
    "28657", ",", "514229", ",", "433494437", ",", "2971215073", ",", 
   "99194853094755497", ",", "1066340417491710595814572169", ",", 
   "19134702400093278081449423917"}], "}"}]], "Output",
 CellLabel->
  "Out[143]=",ExpressionUUID->"e14f1968-4fa5-43c3-bfcb-24aca44c1939"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computations and Explorations 11", "Subsection",
 CellTags->
  "SolutionsCE11",ExpressionUUID->"f067e8c9-3665-4beb-85e6-1b12296685cf"],

Cell[TextData[{
 "Compute the probability that a permutation of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "d4b4bd6f-f0fb-4bdf-bb3d-11987c1d4ed2"],
 " objects is a derangement for all positive integers not exceeding 20 and \
determine how quickly these probabilities approach the number ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "e"}], TraditionalForm]],ExpressionUUID->
  "b1da3c41-4e3d-445c-8997-d1bafd898207"],
 "."
}], "Problem",ExpressionUUID->"c34f1a43-5ad4-4e90-acc0-3cbd509ca772"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " To solve this problem, we will make use of the formula which gives the \
number of derangements of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8a65fe3f-9737-4d5c-a532-c60b0fbb6d12"],
 " objects, namely,"
}], "Text",ExpressionUUID->"4966d596-715d-4d25-87d0-4f116d2b153a"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["D", "n"], "=", 
   RowBox[{
    RowBox[{"n", "!"}], " ", "[", 
    RowBox[{"1", "-", 
     FractionBox["1", 
      RowBox[{"1", "!"}]], "+", 
     FractionBox["1", 
      RowBox[{"2", "!"}]], "-", 
     FractionBox["1", 
      RowBox[{"3", "!"}]], "+", "\[Ellipsis]", "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], 
      FractionBox["1", 
       RowBox[{"n", "!"}]]}]}], "]"}]}], TraditionalForm]], "Equation",Express\
ionUUID->"0405d2fe-bd21-4459-82f4-f1d0996db673"],

Cell[TextData[{
 "The total number of permutations of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "41377648-1797-4d8f-9adc-465d5d71b7cc"],
 " objects is, of course, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "!"}], TraditionalForm]],ExpressionUUID->
  "a6cef8a5-4a39-4281-92fd-aa8442292598"],
 "; so, the probability that one of them is a derangement is the ratio ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SubscriptBox["D", "n"], 
    RowBox[{"n", "!"}]], TraditionalForm]],ExpressionUUID->
  "6ba1ae47-6bcb-4509-984b-cab32125f52c"],
 ", which is given by the expression"
}], "Text",ExpressionUUID->"861bb96f-0a56-4964-8a03-ce3bdef4027b"],

Cell[BoxData[
 FormBox[
  RowBox[{"1", "-", 
   FractionBox["1", 
    RowBox[{"1", "!"}]], "+", 
   FractionBox["1", 
    RowBox[{"2", "!"}]], "-", 
   FractionBox["1", 
    RowBox[{"3", "!"}]], "+", "\[Ellipsis]", "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], 
    FractionBox["1", 
     RowBox[{"n", "!"}]]}]}], TraditionalForm]], "Equation",ExpressionUUID->\
"16aa2150-069e-441a-8576-f4078c42c861"],

Cell[TextData[{
 "A very simple ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function will compute these values for us."
}], "Text",ExpressionUUID->"7734d3a4-2669-4b6d-86e6-c318cf50f6a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"derangementP", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", ">", "0"}]}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", "k"}], "*", 
     RowBox[{"1", "/", 
      RowBox[{"k", "!"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[144]:=",ExpressionUUID->"c8c84297-5d4d-4c16-94cd-70af469e4dd5"],

Cell[TextData[{
 "The probabilities that a permutation of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "e9a7fa94-b90e-4be1-961a-41bbc802dcf4"],
 " objects is a derangement for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[LessEqual]", "20"}], TraditionalForm]],ExpressionUUID->
  "ad40ac4f-ace5-4936-a134-c4745abe19df"],
 " are:"
}], "Text",ExpressionUUID->"4faa2833-de1c-4603-8d2e-c2985a7c36e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"derangementP", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[145]:=",ExpressionUUID->"01acb23a-4e4e-4655-b35d-b84670494eb7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", "2"], ",", 
   FractionBox["1", "3"], ",", 
   FractionBox["3", "8"], ",", 
   FractionBox["11", "30"], ",", 
   FractionBox["53", "144"], ",", 
   FractionBox["103", "280"], ",", 
   FractionBox["2119", "5760"], ",", 
   FractionBox["16687", "45360"], ",", 
   FractionBox["16481", "44800"], ",", 
   FractionBox["1468457", "3991680"], ",", 
   FractionBox["16019531", "43545600"], ",", 
   FractionBox["63633137", "172972800"], ",", 
   FractionBox["2467007773", "6706022400"], ",", 
   FractionBox["34361893981", "93405312000"], ",", 
   FractionBox["15549624751", "42268262400"], ",", 
   FractionBox["8178130767479", "22230464256000"], ",", 
   FractionBox["138547156531409", "376610217984000"], ",", 
   FractionBox["92079694567171", "250298560512000"], ",", 
   FractionBox["4282366656425369", "11640679464960000"]}], "}"}]], "Output",
 CellLabel->
  "Out[145]=",ExpressionUUID->"82bd89b8-37a2-4481-b0c2-be28f3ed4b30"]
}, Open  ]],

Cell[TextData[{
 "To see how these probabilities differ from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "e"}], TraditionalForm]],ExpressionUUID->
  "04662639-b090-41c2-bc36-236e172d9ff5"],
 ", we multiply them by ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]],ExpressionUUID->
  "188c6804-3a96-4aed-8dd2-f9f2824a0549"],
 " and subtract 1. The symbol ",
 StyleBox[ButtonBox["E",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/E"], "FunctionLink"],
 " represents the number ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]],ExpressionUUID->
  "89f0f2ac-4822-4cd8-97c1-f91d38caf3d6"],
 " in the Wolfram Language. We apply ",
 StyleBox[ButtonBox["N",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/N"], "FunctionLink"],
 " with second argument 10 in order to obtain numerical approximations with \
10 digits of precision."
}], "Text",ExpressionUUID->"f17fe36e-7244-487b-a564-49ede3ba3c93"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"E", "*", 
       RowBox[{"derangementP", "[", "n", "]"}]}], "-", "1"}], ",", "10"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[146]:=",ExpressionUUID->"c7bf12fc-8f84-48b3-97e2-b776a7c7b01c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.`10."}], ",", 
   "0.35914091422952261768012355543452610235`10.", ",", 
   RowBox[{"-", "0.09390605718031825487991762971031593177`10."}], ",", 
   "0.01935568567214196326009266657589457676`10.", ",", 
   RowBox[{"-", "0.00329666289835008036790939268134752494`10."}], ",", 
   "0.00047872853006526023675761719485949201`10.", ",", 
   RowBox[{"-", "0.00006061310256550270675201201861383325`10."}], ",", 
   "6.80460151334266118908881848809835`10.*^-6", ",", 
   RowBox[{"-", "6.8625449541793524874262650182969`10.*^-7"}], ",", 
   "6.283110545812439504052150068216`10.*^-8", ",", 
   RowBox[{"-", "5.26758553060829984885559045121`10.*^-9"}], ",", 
   "4.0730538511942472525916714324`10.*^-10", ",", 
   RowBox[{"-", "2.922468532116947274966036403`10.*^-11"}], ",", 
   "1.95603399601582710811302935`10.*^-12", ",", 
   RowBox[{"-", "1.2268062512985954907186354`10.*^-13"}], ",", 
   "7.23903869174586700219226`10.*^-15", ",", 
   RowBox[{"-", "4.0329447423092217863455`10.*^-16"}], ",", 
   "2.127959054556610918916`10.*^-17", ",", 
   RowBox[{"-", "1.06641286372274806472`10.*^-18"}], ",", 
   "5.08873067416947979768136793819289509235`10.*^-20"}], "}"}]], "Output",
 CellLabel->
  "Out[146]=",ExpressionUUID->"6c42fd53-f3fb-41d8-a472-f7a7c8e6febd"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "Section",
 CellTags->"Exercises",ExpressionUUID->"4f481c64-033f-47b0-b73b-edf958ab01c2"],

Cell[CellGroupData[{

Cell["\<\
Implement a function to find the optimal schedule that maximizes total \
attendance.\
\>", "Item1Exercise",ExpressionUUID->"723a17ef-549a-4300-871e-67d9f763a6cc"],

Cell["\<\
Implement a dynamic programming algorithm for finding the maximum sum of \
consecutive terms of a sequence of real numbers. (See Exercise 56 in Section \
8.1.) \
\>", "Item1Exercise",ExpressionUUID->"2333e000-e0c9-4094-8bf5-5de420e888a0"],

Cell["\<\
Implement a dynamic programming algorithm for optimally computing \
matrix-chain multiplication. (See Exercise 57 in Section 8.1.) \
\>", "Item1Exercise",ExpressionUUID->"5b5ab776-bb9b-4a96-96f8-99b7afdb9593"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve the following recurrence relations."
}], "Item1Exercise",ExpressionUUID->"703242ad-2d82-4199-bdde-432f8d32433f"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"n", "-", "1"}]], "-", 
     SubscriptBox["a", 
      RowBox[{"n", "-", "2"}]]}]}], TraditionalForm]],ExpressionUUID->
  "300fcd8b-4b62-49bd-baa9-0416a66d1fed"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "f35e5bd0-f5f3-4c7b-a75c-e9b3c944cc90"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "31aa4421-4f49-444d-8964-05b4a2443b84"],
 ";"
}], "Item2Exercise",ExpressionUUID->"56a62d72-8454-4138-81af-e617c475e72e"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "n"], "=", 
    RowBox[{
     RowBox[{"15", 
      SubscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], 
      SubscriptBox["a", 
       RowBox[{"n", "-", "2"}]]}]}]}], TraditionalForm]],ExpressionUUID->
  "5c9a2a2c-281c-4e0f-ab9a-53935217e472"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "1"], "=", 
    FractionBox["23", "22"]}], TraditionalForm]],ExpressionUUID->
  "82538cff-972a-4c4b-b1b8-888740143bfe"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", 
    FractionBox["7", "2"]}], TraditionalForm]],ExpressionUUID->
  "a8f99416-8885-4e43-b834-5d94a871eb79"]
}], "Item2Exercise",ExpressionUUID->"64937cd8-a7ee-4751-ad7e-8a90978c3452"]
}, Open  ]],

Cell["\<\
Solve each of the recurrence relations in Exercise 1 in Section 8.2 of the \
textbook. (Solve even those that are not linear homogeneous recurrence \
relations with constant coefficients.)\
\>", "Item1Exercise",ExpressionUUID->"f372a061-520f-467d-bac0-f40469fa4deb"],

Cell[TextData[{
 "Write a general solver in the Wolfram Language for linear homogeneous \
recurrence relations with constant coefficients of degree 3 with distinct \
roots. Your solver should check that the roots are in fact distinct and, if \
they are not, should issue a ",
 StyleBox[ButtonBox["Message",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Message"], "FunctionLink"],
 " and return ",
 StyleBox[ButtonBox["$Failed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/$Failed"], "FunctionLink"],
 " , which is a standard return value for a Wolfram Language function when it \
cannot complete a computation for some reason."
}], "Item1Exercise",ExpressionUUID->"44f866a7-9c4c-4078-9146-d2cd5f4a076b"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to investigate the behavior of the limit"
}], "Item1Exercise",ExpressionUUID->"f3905348-f94e-417b-8480-906ecdb9ef1e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   UnderscriptBox["lim", 
    RowBox[{"n", "\[Rule]", "\[Infinity]"}]], 
   FractionBox[
    SubscriptBox["\[CurlyPhi]", "n"], 
    SubscriptBox["\[Psi]", "n"]]}], TraditionalForm]], "ExerciseEquation",Expr\
essionUUID->"54e02d06-e37f-4738-b905-877667fc4564"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CurlyPhi]", "n"], TraditionalForm]],ExpressionUUID->
  "30e2c613-c8da-4684-9c88-9fe97f22869b"],
 " is defined to be the number of prime Fibonacci numbers less than or equal \
to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8f6e1035-64a8-4d56-b9b7-31d3c51adab5"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", "n"], TraditionalForm]],ExpressionUUID->
  "87aa86e5-ccbf-406f-b5a0-8aadc50c007d"],
 " is defined to be the number of Fermat numbers less than or equal to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f0c02b37-211c-4871-a154-7190c1c241d3"],
 "."
}], "ExerciseContinuation",ExpressionUUID->"0a4bd13e-a057-4ed3-a043-\
4030024e5153"],

Cell["\<\
Implement the recursive algorithm described in Example 12 of Section 8.3 of \
the textbook for solving the closest-pair problem.\
\>", "Item1Exercise",ExpressionUUID->"fbea028d-523a-4202-9861-1ab343368810"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the number of square-free integers less than ",
 Cell[BoxData[
  FormBox["100000000", TraditionalForm]],ExpressionUUID->
  "b1ea5d2f-d807-4a4e-aa9c-0c233857cfee"],
 "."
}], "Item1Exercise",ExpressionUUID->"aa0ad607-4730-4d10-8468-0c3a46c97df6"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the number of onto functions from a set with ",
 Cell[BoxData[
  FormBox["1000000", TraditionalForm]],ExpressionUUID->
  "e93b92eb-45b2-4980-a5e7-b79263da5405"],
 " elements to a set with 1000 elements."
}], "Item1Exercise",ExpressionUUID->"44c16abe-9606-4e64-a764-daa766574c19"],

Cell[TextData[{
 "It is probably obvious that the number of onto functions from one set to \
another increases with the sizes of either the domain or the range. Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to experiment, explore whether an increase in the size of the domain or \
the size of the range has the greater impact on the number of onto \
functions."
}], "Item1Exercise",ExpressionUUID->"cdcfdff3-b30c-4f0b-8836-1fa397822875"],

Cell[TextData[{
 "To generate the ",
 StyleBox["lucky numbers",
  FontSlant->"Italic"],
 ", start with the positive integers and delete every second integer in the \
list, starting the count with 1 (e.g., delete 2, 4, 6, etc., leaving 1, 3, 5, \
7, ...). Other than 1, the smallest integer left is 3. Continue by deleting \
every third integer from those that remain, starting the counting with 1 \
(since 1, 3, 5, 7, 9, ... remain, 1 is the first number left, 3 is the second \
one left, 5 is the third left and gets deleted, and so on). Continue the \
process where at each stage, every ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "1aaa87fe-3085-4d64-89d2-91904faae242"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " integer is deleted, where ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "ae8f350c-a479-4ae4-916b-c0b8b0c82ac2"],
 " is the smallest integer left, other than 1 and the previous values of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "cfd79ddc-7012-488e-ae38-065ff7ce2ed9"],
 ". The integers that remain are the lucky numbers. Develop a function in the \
Wolfram Language that generates the lucky numbers up to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f5770705-d20e-4ce6-9bcc-014251825990"],
 "."
}], "Item1Exercise",ExpressionUUID->"d7921327-6784-420e-b501-e3706375376d"],

Cell[TextData[{
 "Can you make any conjectures about lucky numbers by looking at a list of \
the first ",
 Cell[BoxData[
  FormBox["1000", TraditionalForm]],ExpressionUUID->
  "3396d045-75e4-47c1-8fd9-07621d0c83d2"],
 " of them? For example, what sort of conjectures can you make about twin \
lucky numbers? What evidence do you have for your conjectures?"
}], "Item1Exercise",ExpressionUUID->"f51bfaac-5e9a-4a10-9308-2c18bd29e1d3"],

Cell[TextData[{
 "Generalize the ",
 StyleBox["listSeatings", "Code"],
 " function to accept one argument, a list of lists (the same structure as \
the twins list), and determines the arrangements such that no two from the \
same sublist are seated next to one another."
}], "Item1Exercise",ExpressionUUID->"856c9c2e-fe10-4244-aa00-570dc8912567"],

Cell[TextData[{
 "Further generalize the ",
 StyleBox["listSeatings", "Code"],
 " function so that it takes two arguments: a list of lists as before and a \
number ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8b896f45-e4cb-4f27-a874-b126d07ebe03"],
 ". The function should determine the arrangements of the people such that no \
",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "220970b5-d5b0-4d6b-a6f7-f37b6cb87ba6"],
 " from the same sublist are seated together."
}], "Item1Exercise",ExpressionUUID->"fe1abec2-bd2e-4a6c-a61d-224dd94e81d4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Working",
WindowSize->{725, 850},
WindowMargins->{{Automatic, 155}, {Automatic, 0}},
DockedCells->Cell[
  BoxData[
   TagBox[
    GridBox[{{"\"Exploring Discrete Mathematics with Mathematica\"", 
       ActionMenuBox[
       "\"Navigation\"", {
        "\"CloseAll\"" :> Module[{$CellContext`DJSection$}, SelectionMove[
             SelectedNotebook[], All, Notebook]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken["OpenCloseGroup"]], {$CellContext`DJSection$, {
              "Section1a", "Section1b", "Section2a", "Section2b", "Section2c",
                "Section2d", "Section4a", "Section4b", "SolutionsCE11", 
               "SolutionsCE2", "SolutionsCE3", "SolutionsCP12", "Section1", 
               "Section2", "Section3", "Section4", "Section5", "Section6", 
               "Solutions", "Exercises"}}]; SelectionMove[
             SelectedNotebook[], Before, Notebook]], "\"Section1\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section1"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section2\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section2"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section3\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section3"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section4\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section4"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section5\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section5"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section6\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Section6"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Solutions\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Solutions"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Exercises\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Solutions", "Exercises"}}] 
            NotebookLocate["Exercises"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Open All\"" :> 
         Module[{$CellContext`DJSection$}, 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken[
               "SelectionOpenAllGroups"]], {$CellContext`DJSection$, {
              "Exercises", "Section1", "Section1a", "Section1b", "Section2", 
               "Section2a", "Section2b", "Section2c", "Section2d", "Section3",
                "Section4", "Section4a", "Section4b", "Section5", "Section6", 
               "Solutions", "SolutionsCE11", "SolutionsCE2", "SolutionsCE3", 
               "SolutionsCP12"}}] SelectionMove[
             SelectedNotebook[], Before, Notebook]]}]}}, 
     GridBoxAlignment -> {
      "Columns" -> {Left, Baseline}, "Rows" -> {Right, Baseline}}, AutoDelete -> 
     False, GridBoxItemSize -> {"Columns" -> {
         Scaled[0.8], 
         Scaled[0.2]}}], "Grid"]], "DockedCell", FontFamily -> "Times"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData[All, "Printout"], PageWidth -> PaperWidth, 
    CellHorizontalScrolling -> True, 
    CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
    ShowAutoStyles -> False, 
    AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, ScriptMinSize -> 
    9, MenuSortingValue -> 1500, 
    PrivateFontOptions -> {"FontType" -> "Outline"}, Magnification -> 1], 
   Cell[
    StyleData["Title"], Editable -> False, ShowCellBracket -> Automatic, 
    CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
    DefaultNewInlineCellStyle -> {}, LanguageCategory -> "NaturalLanguage", 
    FontFamily -> "Helvetica", FontSize -> 25, FontWeight -> "Bold", 
    FontColor -> GrayLevel[0.137255]], 
   Cell[
    StyleData["BookChapterTitle", StyleDefinitions -> StyleData["Title"]], 
    CellFrame -> {{0, 0}, {1, 1}}, CellDingbat -> Cell[
      BoxData[
       GraphicsBox[{{
          RGBColor[0.09375, 0.570313, 0.816406], 
          RectangleBox[{0, 0}]}, {
          GrayLevel[1], FontSize -> 35, FontWeight -> Bold, FontFamily -> 
          "Helvetica", 
          InsetBox[
           CounterBox["ChapterNumber"], {0.5, 0.45}, {Center, Center}]}}, 
        ImageSize -> {70, 70}]], "Output"], 
    CellMargins -> {{100, 0}, {20, 20}}, CellFrameColor -> GrayLevel[1]], 
   Cell[
    StyleData["DockedCell"], CellMargins -> {{12, 12}, {20, 0}}, 
    CellGroupingRules -> "TitleGrouping", 
    ConversionRules :> {"TeX" -> {"\n\\chapter{", "}"}}, 
    TaggingRules :> {"CounterSettings" -> {"CounterTarget" -> "CellGroup"}}, 
    PageBreakAbove -> False, PageBreakBelow -> False, LineSpacing -> {1, 2}, 
    MenuSortingValue -> 1105, FontFamily -> "Helvetica", FontSize -> 27, 
    FontWeight -> "Bold", Background -> RGBColor[0.09375, 0.570313, 0.816406],
     CounterBoxOptions -> {
     CounterFunction :> Identity}, $CellContext`DefaultReturnCreatedCellStyle -> 
    "Section"], 
   Cell[
    StyleData["FunctionLink"], ConversionRules :> {"TeX" -> {{"", 
         $CellContext`ExportAsHyperRef[], ""}, {"", Automatic, ""}}}, 
    MenuSortingValue -> 1105, ButtonStyleMenuListing -> None, FontFamily -> 
    "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
    RGBColor[0, 0, 1], 
    ButtonBoxOptions -> {Active -> True, ButtonFunction :> (FrontEndExecute[{
         FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> ButtonData}], 
   Cell[
    StyleData["Problem"], CellMargins -> {{40, 12}, {15, 15}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 15010}, 
    ConversionRules :> {
     "TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, ""}}}, 
    TaggingRules :> {
     "ExtraConversionRules" -> {"General" -> {"RestartList" -> False}}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {30, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item1Exercise", 
       CounterAssignments -> {{"Item2Exercise", 0}}, MenuSortingValue -> 
       4100], 
      Cell[
       StyleData["Item1Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{35, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseContinuation"], CellMargins -> {{50, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, MenuSortingValue -> 4101], 
      Cell[
       StyleData["ExerciseContinuation", "Printout"], 
       CellMargins -> {{35, 12}, {1, 3}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item2Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{75, 12}, {1, 2}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17100}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item2Exercise", MenuSortingValue -> 4200, 
       CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}], 
      Cell[
       StyleData["Item2Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {1, 2}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}]}, Open]], 
   Cell[
    StyleData["ExerciseEquation"], CellMargins -> {{36, 12}, {7, 7}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 17200}, 
    CellHorizontalScrolling -> True, 
    CellFrameLabels -> {{None, None}, {None, None}}, DefaultFormatType -> 
    TraditionalForm, InputAutoReplacements -> {}, TextAlignment -> Center, 
    MenuSortingValue -> 4300, 
    ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["myCode"], CellMargins -> {{66, 10}, {5, 10}}, 
    StyleKeyMapping -> {"=" -> "WolframAlphaShort"}, Evaluatable -> False, 
    CellGroupingRules -> "InputGrouping", TextClipboardType -> "InputText", 
    PageBreakWithin -> False, GroupPageBreakWithin -> False, 
    DefaultFormatType -> DefaultInputFormatType, ContextMenu -> 
    FEPrivate`FrontEndResource["ContextMenus", "myCode"], ShowAutoStyles -> 
    True, "TwoByteSyntaxCharacterAutoReplacement" -> True, 
    HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"}, 
    AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
    PasteAutoQuoteCharacters -> {}, LanguageCategory -> "Mathematica", 
    FormatType -> InputForm, NumberMarks -> True, 
    LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> "Code", 
    MenuSortingValue -> 1495, MenuCommandKey -> "8", FontWeight -> 
    "Bold", $CellContext`StripStyleOnPaste -> True], 
   Cell[
    StyleData["CodeVar"], DefaultFormatType -> DefaultInputFormatType, 
    LineBreakWithin -> False, MenuSortingValue -> 10000, FontWeight -> "Bold",
     FontSlant -> "Italic", FontColor -> GrayLevel[0.4]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, ShowCellBracket -> 
       Automatic, CellMargins -> {{12, 12}, {3, 24}}, 
       CellGroupingRules -> {"SectionGrouping", 30}, 
       ConversionRules :> {
        "TeX" -> {"\n\\section{", "}"}, 
         "HTML" -> {"<h3 class=\"Section\">", "</h3>"}}, 
       TaggingRules :> {
        "CounterSettings" -> {
          "CounterFormat" -> {"BookChapterNumber", ".", "Section"}, 
           "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{8, 8}, {4, 6}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], TabSpacings -> 
       2.1, CounterIncrements -> {
        "Section", "SectionHeader", "SubsectionHeader", "SubsubsectionHeader",
          "SubsubsubsectionHeader"}, FontFamily -> "Helvetica", FontSize -> 
       16, FontWeight -> "Bold", Background -> GrayLevel[0.999985]], 
      Cell[
       StyleData["Section", "Printout"], CellFrame -> {{4, 0}, {0, 0.5}}, 
       CellMargins -> {{2, 2}, {3, 21}}, CellFrameMargins -> {{6, 6}, {3, 5}},
        CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406]], 
      Cell[
       StyleData["Section", "DoubleSpacedPrintout"], 
       CellFrame -> {{4, 0}, {0, 0.5}}, CellMargins -> {{2, 2}, {3, 21}}, 
       CellFrameMargins -> {{6, 6}, {3, 5}}, CellFrameColor -> 
       RGBColor[0.09375, 0.570313, 0.816406], FontSize -> 14]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellDingbat -> None, 
       CellMargins -> {{12, 12}, {0, 6}}, 
       CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
       CellGroupingRules -> {"SectionGrouping", 50}, 
       ConversionRules :> {
        "TeX" -> {"\n\\subsubsection{", "}"}, 
         "HTML" -> {"<h5 class=\"Subsubsection\">", "</h5>"}}, PageBreakBelow -> 
       False, CellFrameLabelMargins -> 4, 
       CounterIncrements -> {
        "Subsubsection", "SubsubsectionHeader", "SubsubsubsectionHeader"}, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"], 
      Cell[
       StyleData["Subsubsection", "Printout"], FontFamily -> "Helvetica", 
       FontSize -> 11, FontWeight -> "Bold", FontSlant -> "Italic"]}, Open]], 
   
   Cell[
    StyleData["Equation"], CellMargins -> {{26, 10}, {7, 7}}, 
    ConversionRules :> {
     "HTML" -> {{"", ""}, {"<p class=\"Equation\">", "</p>"}}}, 
    CellHorizontalScrolling -> True, DefaultFormatType -> TraditionalForm, 
    InputAutoReplacements -> {}, TextAlignment -> Center, CounterIncrements -> 
    "Equation", ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Numbered"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Numbered"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, 
         TextJustification -> (FontWeight -> "Plain")], 
       CellMargins -> {{36, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
       ConversionRules :> {{"TeX" -> {"\n\\item ", ""}}, {
         "HTML" -> {"<li>", "</li>"}}}, 
       TaggingRules :> {
        "ExtraConversionRules" -> {
          "General" -> {"NestingLevel" -> 30}, 
           "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, 
           "HTML" -> {"CellGroupEnvironment" -> "ol"}}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, TextJustification -> 1, CounterIncrements -> "Item1Numbered", 
       CounterAssignments -> {{"Item2Numbered", 0}, {"Item3Numbered", 0}}], 
      Cell[
       StyleData["Item1Numbered", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Numbered"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Plain"], 
       CellMargins -> {{24, 2}, {1, 2}}, CellFrameLabelMargins -> 3, 
       TextJustification -> 1]}, Open]], 
   Cell[
    StyleData["InitializationCell"], Background -> GrayLevel[1]], 
   Cell[
    StyleData["Item1"], TextJustification -> 1], 
   Cell[
    StyleData["Item1Printout"], TextJustification -> 1, MenuSortingValue -> 
    10000], 
   Cell[
    StyleData["Code"], FormatType -> InputForm]}, Visible -> False, 
  FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Section1"->{
  Cell[1726, 52, 121, 1, 55, "Section",ExpressionUUID->"3dd88c94-41fe-4900-aa96-71d35a31eecd",
   CellTags->"Section1"]},
 "Section1a"->{
  Cell[20176, 593, 123, 1, 32, "Subsection",ExpressionUUID->"3386d020-aef5-4fe6-95ac-4c0d54acf17b",
   CellTags->"Section1a"]},
 "Section1b"->{
  Cell[31425, 905, 120, 1, 32, "Subsection",ExpressionUUID->"ac410640-c2e7-4eef-a96b-5f7a60a708bc",
   CellTags->"Section1b"]},
 "Section2"->{
  Cell[48067, 1380, 136, 1, 55, "Section",ExpressionUUID->"aa7a30bb-ab63-496b-b659-a8c50e1b4419",
   CellTags->"Section2"]},
 "Section2a"->{
  Cell[49343, 1411, 175, 3, 32, "Subsection",ExpressionUUID->"7d3f1f76-a830-4815-86c9-b6bb7afa6391",
   CellTags->"Section2a"]},
 "Section2b"->{
  Cell[110840, 3382, 136, 1, 32, "Subsection",ExpressionUUID->"eaaff216-bb72-4fa2-bf9c-f297be33940a",
   CellTags->"Section2b"]},
 "Section2c"->{
  Cell[125899, 3875, 202, 5, 32, "Subsection",ExpressionUUID->"06538a81-a148-4776-9511-e73252624068",
   CellTags->"Section2c"]},
 "Section2d"->{
  Cell[145678, 4510, 216, 6, 32, "Subsection",ExpressionUUID->"552a7a6a-43d2-44b7-b485-820bafe2f4c8",
   CellTags->"Section2d"]},
 "Section3"->{
  Cell[154762, 4752, 155, 1, 55, "Section",ExpressionUUID->"3707c835-8de7-4194-9348-ae560cfbadf7",
   CellTags->"Section3"]},
 "Section4"->{
  Cell[162077, 4959, 121, 1, 55, "Section",ExpressionUUID->"827c836d-20e9-4288-b62e-388b8a027ebb",
   CellTags->"Section4"]},
 "Section4a"->{
  Cell[164217, 5024, 127, 1, 32, "Subsection",ExpressionUUID->"d61c0a35-b91a-4225-a30f-b2c18ffb08c2",
   CellTags->"Section4a"]},
 "Section4b"->{
  Cell[179594, 5474, 143, 1, 32, "Subsection",ExpressionUUID->"6c056ec8-20af-4ade-ad4c-2352b9692cf0",
   CellTags->"Section4b"]},
 "Section5"->{
  Cell[193443, 5893, 126, 1, 55, "Section",ExpressionUUID->"bc3e1ed2-484f-4380-839b-e476fb40560d",
   CellTags->"Section5"]},
 "Section6"->{
  Cell[208577, 6347, 142, 1, 55, "Section",ExpressionUUID->"bcc9c2a2-2728-4f53-adc7-d02705ee65c3",
   CellTags->"Section6"]},
 "Solutions"->{
  Cell[223028, 6762, 195, 4, 55, "Section",ExpressionUUID->"0e38ce4f-ee7f-4ee0-a234-b83f6c12a79f",
   PageBreakWithin->False,
   CellTags->"Solutions"]},
 "SolutionsCP12"->{
  Cell[223248, 6770, 177, 4, 32, "Subsection",ExpressionUUID->"b31cf265-6ec8-4ddc-bbd7-d097bbda9a2b",
   PageBreakAbove->False,
   PageBreakWithin->False,
   CellTags->"SolutionsCP12"]},
 "SolutionsCE2"->{
  Cell[230370, 6995, 138, 2, 32, "Subsection",ExpressionUUID->"699e3556-6e7b-46dd-874f-93afdcbbaf6f",
   CellTags->"SolutionsCE2"]},
 "SolutionsCE3"->{
  Cell[235616, 7152, 138, 2, 32, "Subsection",ExpressionUUID->"65319e19-c333-444b-8489-08a558f02441",
   CellTags->"SolutionsCE3"]},
 "SolutionsCE11"->{
  Cell[239503, 7263, 140, 2, 32, "Subsection",ExpressionUUID->"f067e8c9-3665-4beb-85e6-1b12296685cf",
   CellTags->"SolutionsCE11"]},
 "Exercises"->{
  Cell[247350, 7499, 107, 1, 55, "Section",ExpressionUUID->"4f481c64-033f-47b0-b73b-edf958ab01c2",
   CellTags->"Exercises"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Section1", 274823, 8108},
 {"Section1a", 274961, 8111},
 {"Section1b", 275105, 8114},
 {"Section2", 275248, 8117},
 {"Section2a", 275389, 8120},
 {"Section2b", 275534, 8123},
 {"Section2c", 275680, 8126},
 {"Section2d", 275826, 8129},
 {"Section3", 275971, 8132},
 {"Section4", 276112, 8135},
 {"Section4a", 276254, 8138},
 {"Section4b", 276400, 8141},
 {"Section5", 276545, 8144},
 {"Section6", 276686, 8147},
 {"Solutions", 276828, 8150},
 {"SolutionsCP12", 277002, 8154},
 {"SolutionsCE2", 277208, 8159},
 {"SolutionsCE3", 277360, 8162},
 {"SolutionsCE11", 277513, 8165},
 {"Exercises", 277663, 8168}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 165, 3, 108, "BookChapterTitle",ExpressionUUID->"90393f42-285c-49fe-9b1e-ff41c080fa3d",
 CounterAssignments->{{"ChapterNumber", 8}}],
Cell[CellGroupData[{
Cell[770, 29, 86, 0, 55, "Section",ExpressionUUID->"634f0c93-103e-4a16-ba57-88c3f248d241"],
Cell[859, 31, 830, 16, 80, "Text",ExpressionUUID->"1bcc21bd-863e-49c5-b4ff-2a6a5e78fcc0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1726, 52, 121, 1, 55, "Section",ExpressionUUID->"3dd88c94-41fe-4900-aa96-71d35a31eecd",
 CellTags->"Section1"],
Cell[1850, 55, 433, 10, 35, "Text",ExpressionUUID->"177fce75-0e91-4c5f-9e8c-ffd8103dde05"],
Cell[2286, 67, 285, 9, 26, "Equation",ExpressionUUID->"025b8f0d-3dfb-4b6c-a36c-d88e0c1e3246"],
Cell[2574, 78, 672, 20, 20, "Text",ExpressionUUID->"2ec85a55-c5d7-4c86-8329-0d42828ee921"],
Cell[3249, 100, 724, 15, 65, "Text",ExpressionUUID->"e2145534-174e-4b2d-8c5a-244170afa7ad"],
Cell[3976, 117, 1153, 32, 50, "Text",ExpressionUUID->"2a30eaad-a41d-455e-83b1-329bc221e5db"],
Cell[5132, 151, 444, 6, 50, "Text",ExpressionUUID->"749a671e-4b5a-4286-8ecc-c98b05dfd1b4"],
Cell[5579, 159, 655, 20, 70, "Input",ExpressionUUID->"b496d452-f253-421f-882a-f5db8b504704",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[6259, 183, 256, 6, 31, "Input",ExpressionUUID->"e49ae543-e79f-455a-9c27-9fd0c8334ff3"],
Cell[6518, 191, 372, 7, 31, "Output",ExpressionUUID->"94e72dba-4dc9-4a7e-981a-f9df6502d3ad"]
}, Open  ]],
Cell[6905, 201, 399, 6, 50, "Text",ExpressionUUID->"713e1b7d-f1e7-4f72-b12a-b87cbeab253c"],
Cell[7307, 209, 2052, 57, 128, "Text",ExpressionUUID->"72efb391-23f8-486b-82ac-b4d6566703ee"],
Cell[9362, 268, 166, 3, 20, "Text",ExpressionUUID->"d84c1a3b-3195-4d7e-9d84-e2fed349cf44"],
Cell[CellGroupData[{
Cell[9553, 275, 634, 18, 31, "Input",ExpressionUUID->"ea5f9f0f-d88b-40e1-9900-0840dbba1900"],
Cell[10190, 295, 372, 7, 31, "Output",ExpressionUUID->"b3df81ec-8cab-4092-b00b-c2710b21b2ae"]
}, Open  ]],
Cell[10577, 305, 408, 8, 36, "Text",ExpressionUUID->"053fdd6a-43b3-4555-b486-92ce8b47605b"],
Cell[CellGroupData[{
Cell[11010, 317, 141, 2, 31, "Input",ExpressionUUID->"46d0133d-a6dd-4f4f-950b-0fd03b752a91"],
Cell[11154, 321, 108, 1, 31, "Output",ExpressionUUID->"223be65b-9c83-43af-a0dc-e7a8a3b03a65"]
}, Open  ]],
Cell[11277, 325, 1641, 48, 74, "Text",ExpressionUUID->"b13735d2-05cc-4254-bb3b-e3a52e9c0944"],
Cell[CellGroupData[{
Cell[12943, 377, 746, 22, 31, "Input",ExpressionUUID->"5ef972ed-d277-443f-a5b7-f29fcbabe148"],
Cell[13692, 401, 149, 1, 31, "Output",ExpressionUUID->"9e2ad163-b35f-42ee-af75-ab9f39fa694c"]
}, Open  ]],
Cell[13856, 405, 871, 19, 53, "Text",ExpressionUUID->"a0db4996-bd6c-4e76-b944-60a471864d1a"],
Cell[14730, 426, 512, 17, 26, "Equation",ExpressionUUID->"c5348678-893c-4ce2-b9cf-b3f4be998b45"],
Cell[15245, 445, 1406, 35, 66, "Text",ExpressionUUID->"af887004-7ea2-4798-8eb0-9a79c3bf0892"],
Cell[16654, 482, 1206, 37, 36, "Text",ExpressionUUID->"03a416df-df89-41bf-8837-ec1e92e5624d"],
Cell[CellGroupData[{
Cell[17885, 523, 835, 24, 51, "Input",ExpressionUUID->"38e9a73d-67ce-4d9e-b342-be482a658e24"],
Cell[18723, 549, 528, 12, 51, "Output",ExpressionUUID->"b049695d-7300-407c-bd41-291fa5a5efd0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19288, 566, 320, 8, 31, "Input",ExpressionUUID->"b36c3d73-3bae-4ee6-be2d-d15057f42c97"],
Cell[19611, 576, 528, 12, 51, "Output",ExpressionUUID->"f22e375d-4609-4056-a997-d98d2d077976"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20176, 593, 123, 1, 32, "Subsection",ExpressionUUID->"3386d020-aef5-4fe6-95ac-4c0d54acf17b",
 CellTags->"Section1a"],
Cell[20302, 596, 264, 4, 35, "Text",ExpressionUUID->"305c9edb-4cdf-4b4e-90d9-c02135b63a06"],
Cell[20569, 602, 343, 11, 26, "Equation",ExpressionUUID->"25392025-56df-41bf-b168-5757fe3eb6f0"],
Cell[20915, 615, 465, 11, 20, "Text",ExpressionUUID->"a3af472d-23da-4292-a5f8-f0a49e04ce0d"],
Cell[21383, 628, 212, 6, 26, "Equation",ExpressionUUID->"c0956d7d-0d26-447e-9449-6142a34d5248"],
Cell[21598, 636, 208, 5, 20, "Text",ExpressionUUID->"23ce5eb4-21b2-4c29-b814-63e86a884ece"],
Cell[21809, 643, 609, 14, 54, "Text",ExpressionUUID->"6e586275-b95d-4811-8b97-92dd3e6831ab"],
Cell[22421, 659, 222, 4, 24, "Text",ExpressionUUID->"4c8a7a0d-df4a-478f-a9db-8a6543ae0a5b"],
Cell[22646, 665, 384, 9, 51, "Input",ExpressionUUID->"8cb030af-43cc-4cc5-a207-3636297b0392",
 InitializationCell->True],
Cell[23033, 676, 271, 6, 21, "Text",ExpressionUUID->"c26bab90-7c17-4601-b127-b01ddc4dc6aa"],
Cell[23307, 684, 1215, 28, 107, "Text",ExpressionUUID->"44df87a5-a9a7-48fd-9dcf-935d478d70cb"],
Cell[24525, 714, 964, 22, 146, "Input",ExpressionUUID->"fcf2ffe6-7ef3-473d-8ebc-731c896e5bee",
 InitializationCell->True],
Cell[25492, 738, 263, 5, 24, "Text",ExpressionUUID->"0038cfbc-837e-421d-b87c-81bf51dd86be"],
Cell[25758, 745, 371, 9, 31, "Input",ExpressionUUID->"bfc64105-7dfa-4e2a-b9dd-84c5ada9d8ee",
 InitializationCell->True],
Cell[26132, 756, 245, 6, 24, "Text",ExpressionUUID->"4302b43e-b1e6-41ca-bc3e-9bc285d67fe3"],
Cell[CellGroupData[{
Cell[26402, 766, 137, 2, 31, "Input",ExpressionUUID->"509d0210-5270-4810-8dd8-0f7b5709c6e3"],
Cell[CellGroupData[{
Cell[26564, 772, 428, 9, 24, "Print",ExpressionUUID->"4c24c4b7-cbe5-4ae7-a231-10b2151d0b6a"],
Cell[26995, 783, 428, 9, 24, "Print",ExpressionUUID->"def43aa4-cebd-4b15-b6c4-9305fce1f91e"],
Cell[27426, 794, 428, 9, 24, "Print",ExpressionUUID->"323e90df-a3c7-475a-acd6-9024b92a69bf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27903, 809, 137, 2, 31, "Input",ExpressionUUID->"ece993d3-fce9-4846-8326-9c67dd1b4088"],
Cell[CellGroupData[{
Cell[28065, 815, 428, 9, 24, "Print",ExpressionUUID->"183508d6-1b14-40c5-ac1f-49cc7d364e30"],
Cell[28496, 826, 428, 9, 24, "Print",ExpressionUUID->"5275c861-8be5-4afe-acf1-b63ce380025e"],
Cell[28927, 837, 428, 9, 24, "Print",ExpressionUUID->"d587e16a-20d3-4d9b-9e29-552126f05e90"],
Cell[29358, 848, 428, 9, 24, "Print",ExpressionUUID->"394639e9-9c9d-4b07-a1d9-0f9d7ba42793"],
Cell[29789, 859, 428, 9, 24, "Print",ExpressionUUID->"80defe3d-5128-4731-b3d6-6063904c61da"],
Cell[30220, 870, 428, 9, 24, "Print",ExpressionUUID->"405143eb-9e4f-43b3-ac03-9af103858a9f"],
Cell[30651, 881, 428, 9, 24, "Print",ExpressionUUID->"dffbc256-bab9-4839-b32c-8aa2060205cd"]
}, Open  ]]
}, Open  ]],
Cell[31106, 894, 282, 6, 39, "Text",ExpressionUUID->"5495407f-1427-47fe-993c-71b65d5ef673"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31425, 905, 120, 1, 32, "Subsection",ExpressionUUID->"ac410640-c2e7-4eef-a96b-5f7a60a708bc",
 CellTags->"Section1b"],
Cell[31548, 908, 303, 4, 35, "Text",ExpressionUUID->"91711a7f-b36c-4556-a65d-30b0a35529f4"],
Cell[31854, 914, 531, 7, 65, "Text",ExpressionUUID->"4f515774-88a6-454a-bee0-bbcb80c688e5"],
Cell[32388, 923, 122, 0, 20, "Text",ExpressionUUID->"b2270ff5-e761-423f-b288-546e8d92aeb7"],
Cell[32513, 925, 1437, 50, 166, "Text",ExpressionUUID->"35bd8660-cb2a-4b05-95f8-3b141b03c782"],
Cell[33953, 977, 141, 2, 20, "Text",ExpressionUUID->"1447f91d-ef49-4b38-9a1d-5dcaa08fc1b0"],
Cell[CellGroupData[{
Cell[34119, 983, 788, 21, 51, "Input",ExpressionUUID->"78e27e43-7541-46eb-849d-89b093e922e6",
 InitializationCell->True],
Cell[34910, 1006, 724, 19, 51, "Output",ExpressionUUID->"de7ee490-3492-44e6-b46e-7165362fd078"]
}, Open  ]],
Cell[35649, 1028, 190, 3, 20, "Text",ExpressionUUID->"c9c3ccd0-1e03-4699-b725-33f1e7987205"],
Cell[CellGroupData[{
Cell[35864, 1035, 128, 0, 16, "Item1Numbered",ExpressionUUID->"20038812-4b83-4c51-b1d8-9fb9b58691ea"],
Cell[35995, 1037, 785, 23, 16, "Item1Numbered",ExpressionUUID->"39739be4-06d1-469d-9197-e49f842585db"],
Cell[36783, 1062, 1029, 32, 33, "Item1Numbered",ExpressionUUID->"057e84ce-5639-4e71-a846-01c8659b4e22"],
Cell[37815, 1096, 423, 11, 16, "Item1Numbered",ExpressionUUID->"bb4ad7ea-e202-41c0-970c-971dc5e34adf"]
}, Open  ]],
Cell[38253, 1110, 1136, 28, 86, "Text",ExpressionUUID->"d917f556-ef19-4658-b371-a7a1893821a3"],
Cell[39392, 1140, 251, 7, 31, "myCode",ExpressionUUID->"35af29e9-492f-471d-9924-6cbe80503d04"],
Cell[39646, 1149, 927, 23, 54, "Text",ExpressionUUID->"740bfea8-03e8-453c-8cae-634243e3d409"],
Cell[40576, 1174, 1457, 34, 88, "Text",ExpressionUUID->"6fd37306-2308-470c-a8c9-4db956488602"],
Cell[42036, 1210, 1900, 47, 279, "Input",ExpressionUUID->"c6cfbc8c-3401-448e-b307-221f1c4f1d39",
 InitializationCell->True],
Cell[43939, 1259, 1181, 32, 58, "Text",ExpressionUUID->"1a31da92-b190-4832-af5f-4211b402ce44"],
Cell[45123, 1293, 1249, 33, 146, "Input",ExpressionUUID->"caaf965c-d9ac-438d-9092-e6647010a97e",
 InitializationCell->True],
Cell[46375, 1328, 160, 3, 20, "Text",ExpressionUUID->"c884001d-b501-4571-85d4-75041046fb9a"],
Cell[46538, 1333, 1030, 27, 127, "Input",ExpressionUUID->"3ad7dce0-6cf3-4edd-93f7-d39cfdc212dc",
 InitializationCell->True],
Cell[47571, 1362, 146, 2, 20, "Text",ExpressionUUID->"cf3ae91b-d961-4970-89dd-bcf73fa2b05c"],
Cell[CellGroupData[{
Cell[47742, 1368, 153, 2, 31, "Input",ExpressionUUID->"f9309f81-3b64-4003-8c4c-8c056aee2a6e"],
Cell[47898, 1372, 108, 1, 31, "Output",ExpressionUUID->"e5727142-3b76-4a81-8889-544dae1d87bc"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48067, 1380, 136, 1, 55, "Section",ExpressionUUID->"aa7a30bb-ab63-496b-b659-a8c50e1b4419",
 CellTags->"Section2"],
Cell[48206, 1383, 511, 9, 51, "Text",ExpressionUUID->"7051c954-fe89-43d2-951c-3287d168d234"],
Cell[48720, 1394, 598, 13, 35, "Text",ExpressionUUID->"dfa3f506-1840-4e6a-991d-ce1022d182bf"],
Cell[CellGroupData[{
Cell[49343, 1411, 175, 3, 32, "Subsection",ExpressionUUID->"7d3f1f76-a830-4815-86c9-b6bb7afa6391",
 CellTags->"Section2a"],
Cell[49521, 1416, 226, 3, 35, "Text",ExpressionUUID->"f7b4f78c-fdaf-453a-b0d0-8819c9de31a2"],
Cell[49750, 1421, 512, 17, 26, "Equation",ExpressionUUID->"ff9cc218-d816-41cd-aae9-6d99847e06ae"],
Cell[50265, 1440, 881, 24, 35, "Text",ExpressionUUID->"e12e5475-745c-4fdc-82aa-d11e4a3f1720"],
Cell[51149, 1466, 199, 3, 20, "Text",ExpressionUUID->"6f708d1d-03c4-40a9-ba55-38ab7589f6df"],
Cell[51351, 1471, 501, 16, 29, "Equation",ExpressionUUID->"0b8b6e09-e533-4cda-bc81-dfa6afe6b576"],
Cell[51855, 1489, 446, 10, 35, "Text",ExpressionUUID->"4450d464-9882-43e1-a9f7-f4ccd9b610b5"],
Cell[CellGroupData[{
Cell[52326, 1503, 95, 0, 18, "Subsubsection",ExpressionUUID->"15dbe47e-7e7b-449d-a3e1-7e3938c5445b"],
Cell[52424, 1505, 174, 3, 20, "Text",ExpressionUUID->"eba5d25c-08fe-41a8-b903-9f5e8332bee8"],
Cell[52601, 1510, 329, 11, 26, "Equation",ExpressionUUID->"66ae4fe5-dd6b-491b-b0e3-64663db5ec0d"],
Cell[52933, 1523, 479, 14, 20, "Text",ExpressionUUID->"63da9f00-c40b-4086-a7f5-7f86a20fcb87"],
Cell[53415, 1539, 218, 6, 29, "Equation",ExpressionUUID->"e0a0be4b-444f-4062-bf12-4030e642eb3f"],
Cell[53636, 1547, 289, 7, 21, "Text",ExpressionUUID->"504e9d35-453c-4c3e-a807-b867db34112b"],
Cell[CellGroupData[{
Cell[53950, 1558, 276, 8, 31, "Input",ExpressionUUID->"2f9844ad-1666-4e0f-93f1-c048d192285e"],
Cell[54229, 1568, 283, 8, 31, "Output",ExpressionUUID->"ef7c2579-48f3-4b19-a767-7b5c535bf9be"]
}, Open  ]],
Cell[54527, 1579, 530, 12, 36, "Text",ExpressionUUID->"678ff6ca-1713-4c09-99b9-8bae8d337f70"],
Cell[55060, 1593, 552, 16, 35, "Text",ExpressionUUID->"efefc077-d297-4305-a0e7-3be476c5e481"],
Cell[55615, 1611, 374, 11, 26, "Equation",ExpressionUUID->"f1a2c418-b0ba-48e8-a41f-25553d2a22f4"],
Cell[55992, 1624, 144, 1, 20, "Text",ExpressionUUID->"8ae34b1e-5044-4de9-bf2e-29490473b1fa"],
Cell[56139, 1627, 517, 14, 20, "Text",ExpressionUUID->"0e236bb0-80f2-4b37-813b-446c5ee789c1"],
Cell[56659, 1643, 388, 13, 46, "Equation",ExpressionUUID->"2b646ee3-c641-4efb-875e-d782286297e4"],
Cell[57050, 1658, 264, 6, 21, "Text",ExpressionUUID->"376dcbd7-788b-4f44-8132-3bac52a778a2"],
Cell[CellGroupData[{
Cell[57339, 1668, 492, 15, 31, "Input",ExpressionUUID->"5729e6bf-179e-4710-a81f-4ece136cd5d4"],
Cell[57834, 1685, 315, 9, 47, "Output",ExpressionUUID->"b92d6563-4e41-497d-a9ee-ecc628af2cbd"]
}, Open  ]],
Cell[58164, 1697, 264, 4, 35, "Text",ExpressionUUID->"92867c96-1672-4267-94ed-a64629882afb"],
Cell[58431, 1703, 198, 3, 20, "Text",ExpressionUUID->"fcc3d964-af35-4700-b692-b1f4476c7329"],
Cell[58632, 1708, 399, 14, 46, "Equation",ExpressionUUID->"9aac857e-a382-4b04-ae75-356a231877cf"],
Cell[59034, 1724, 386, 9, 35, "Text",ExpressionUUID->"cc0085a1-0b9d-450c-8c49-7e6b2443b7f6"],
Cell[59423, 1735, 465, 15, 31, "Input",ExpressionUUID->"caab3f0e-50ac-4cbf-a358-e53cf8e1f02c"],
Cell[CellGroupData[{
Cell[59913, 1754, 256, 6, 31, "Input",ExpressionUUID->"fbaa04c0-c00c-4eec-9d24-159baf6df851"],
Cell[60172, 1762, 258, 5, 31, "Output",ExpressionUUID->"f5dc63e5-4d7d-4e5a-9a59-a27608190087"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60479, 1773, 96, 0, 18, "Subsubsection",ExpressionUUID->"37b11016-7e92-45ba-9107-b5ff8212b057"],
Cell[60578, 1775, 145, 2, 20, "Text",ExpressionUUID->"0d854eda-871d-4bcf-b2ba-d98e9c152aad"],
Cell[60726, 1779, 399, 14, 46, "Equation",ExpressionUUID->"a460cb23-d45e-460e-ae93-2ce712dc56ce"],
Cell[61128, 1795, 461, 15, 30, "Text",ExpressionUUID->"3d932fc2-e641-48ed-84c1-ef86ffe2b391"],
Cell[61592, 1812, 475, 9, 50, "Text",ExpressionUUID->"e16d0948-5f50-4585-96ba-30bb4dc1153a"],
Cell[CellGroupData[{
Cell[62092, 1825, 460, 14, 31, "Input",ExpressionUUID->"d4f6d575-8021-48c1-b227-4ae1349db655",
 InitializationCell->True],
Cell[62555, 1841, 307, 9, 47, "Output",ExpressionUUID->"b1ca4e7c-ca71-44af-bcb7-1261e76a4c22"]
}, Open  ]],
Cell[62877, 1853, 377, 9, 39, "Text",ExpressionUUID->"1cd809a9-14d8-4d0f-b625-aeccda603716"],
Cell[CellGroupData[{
Cell[63279, 1866, 199, 4, 31, "Input",ExpressionUUID->"5fdaaae0-4196-4f02-8313-38787f70eb53",
 InitializationCell->True],
Cell[63481, 1872, 193, 5, 47, "Output",ExpressionUUID->"82c5ce9a-e2b7-4991-930f-c6e6a648ef86"]
}, Open  ]],
Cell[63689, 1880, 346, 7, 36, "Text",ExpressionUUID->"4992d311-edd4-482b-beb7-35dd47280cd2"],
Cell[64038, 1889, 216, 3, 20, "Text",ExpressionUUID->"5a4f6757-9f9d-4d83-b317-c5d3b3852e3a"],
Cell[CellGroupData[{
Cell[64279, 1896, 920, 27, 51, "Input",ExpressionUUID->"07d4f508-b2c6-42fc-8e47-5f5107309d3d"],
Cell[65202, 1925, 296, 8, 47, "Output",ExpressionUUID->"e11362e4-8d9c-472d-92ca-8ea037729006"]
}, Open  ]],
Cell[65513, 1936, 140, 2, 20, "Text",ExpressionUUID->"e4a26ec5-3ba4-4d2f-88f7-799444999525"],
Cell[65656, 1940, 433, 15, 47, "Equation",ExpressionUUID->"17150132-d530-49f1-b5d4-85ceaa2b13d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66126, 1960, 102, 0, 18, "Subsubsection",ExpressionUUID->"ce90a4f6-8b65-476d-b175-98ed971d9c8c"],
Cell[66231, 1962, 220, 3, 35, "Text",ExpressionUUID->"7aa4e6b8-2c21-4a0e-bdac-4f2c408c2b5e"],
Cell[66454, 1967, 176, 5, 29, "Equation",ExpressionUUID->"3d56e77f-fa10-477f-a85a-429bbdbe0037"],
Cell[66633, 1974, 120, 0, 20, "Text",ExpressionUUID->"8ac1ac4a-2028-493f-bc25-44e94a666b98"],
Cell[CellGroupData[{
Cell[66778, 1978, 349, 10, 31, "Input",ExpressionUUID->"24cac90c-f7f4-481b-b99f-d621814931e8",
 InitializationCell->True],
Cell[67130, 1990, 380, 13, 47, "Output",ExpressionUUID->"6111a753-6dae-4427-b39d-e2e235a91596"]
}, Open  ]],
Cell[67525, 2006, 305, 8, 20, "Text",ExpressionUUID->"9a412f5d-ce68-4487-95d3-7c0c132379d3"],
Cell[CellGroupData[{
Cell[67855, 2018, 416, 12, 31, "Input",ExpressionUUID->"7ce4231e-a9ca-4e1b-bb1b-e0c52989e37e",
 InitializationCell->True],
Cell[68274, 2032, 530, 18, 46, "Output",ExpressionUUID->"890dfc19-4060-4485-ae95-405bd297096c"]
}, Open  ]],
Cell[68819, 2053, 174, 3, 20, "Text",ExpressionUUID->"cda31b3d-9533-43b7-b2c6-137dac2ed518"],
Cell[CellGroupData[{
Cell[69018, 2060, 947, 28, 70, "Input",ExpressionUUID->"120e1f28-c2db-430d-95b7-3a09201bc54c",
 InitializationCell->True],
Cell[69968, 2090, 531, 18, 57, "Output",ExpressionUUID->"07339e11-f1a5-4b40-9e23-8453bc3ee726"]
}, Open  ]],
Cell[70514, 2111, 505, 12, 39, "Text",ExpressionUUID->"e5c502ba-dcb4-4f30-b706-1b7de7bc36c4"],
Cell[CellGroupData[{
Cell[71044, 2127, 187, 4, 31, "Input",ExpressionUUID->"5473f3a5-88a7-4ef4-b126-fca26e3c7624"],
Cell[71234, 2133, 697, 26, 60, "Output",ExpressionUUID->"b3fb89a4-fa33-4804-a10a-64fc87581527"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71968, 2164, 224, 5, 31, "Input",ExpressionUUID->"52f6c1b5-ca5e-494a-9ace-e18d02d62b72"],
Cell[72195, 2171, 643, 23, 62, "Output",ExpressionUUID->"67d09d8d-f8bf-4a45-8b31-36b4e57ddb86"]
}, Open  ]],
Cell[72853, 2197, 354, 5, 50, "Text",ExpressionUUID->"909ab1b5-8de5-4587-9d34-05ba13e0a74a"],
Cell[CellGroupData[{
Cell[73232, 2206, 277, 7, 31, "Input",ExpressionUUID->"9a37ba77-54b1-4f5e-af01-37eb99588075",
 InitializationCell->True],
Cell[73512, 2215, 697, 26, 60, "Output",ExpressionUUID->"c1720eff-8296-41f5-8f8c-1c21b9868fe7"]
}, Open  ]],
Cell[74224, 2244, 539, 15, 39, "Text",ExpressionUUID->"370f0a01-9c72-43ef-a904-f784abd0c661"],
Cell[74766, 2261, 205, 5, 20, "Text",ExpressionUUID->"4c8145b8-5483-4a25-84fd-afc4edf465c3"],
Cell[CellGroupData[{
Cell[74996, 2270, 142, 2, 31, "Input",ExpressionUUID->"7107d01e-db31-44b9-994e-ce71a1523127"],
Cell[75141, 2274, 359, 13, 54, "Output",ExpressionUUID->"37e77bf9-b893-4c7b-96dd-42aa46517d63"]
}, Open  ]],
Cell[75515, 2290, 280, 6, 21, "Text",ExpressionUUID->"8f89add6-4516-4091-a0aa-4f482171fb88"],
Cell[CellGroupData[{
Cell[75820, 2300, 173, 3, 31, "Input",ExpressionUUID->"f801fdc0-72bb-4ff8-b2cb-61f7a8885611"],
Cell[75996, 2305, 107, 1, 31, "Output",ExpressionUUID->"b1d8895d-ffd9-45ee-af06-6beb5431a769"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76152, 2312, 88, 0, 18, "Subsubsection",ExpressionUUID->"8e6c93a9-33af-48b3-9eaa-0edeaa44998a"],
Cell[76243, 2314, 436, 7, 54, "Text",ExpressionUUID->"d32a1086-3455-4b6f-a376-a29feec15ea2"],
Cell[76682, 2323, 361, 11, 26, "Equation",ExpressionUUID->"d8a3ade7-08de-4b53-a70a-9fb706df7332"],
Cell[77046, 2336, 632, 18, 21, "Text",ExpressionUUID->"3ef87e57-9635-4057-8f04-99f73182579f"],
Cell[77681, 2356, 621, 12, 53, "Text",ExpressionUUID->"5f5e65c4-517b-4cfb-9ddb-7f933e4d34da"],
Cell[78305, 2370, 2793, 75, 203, "Input",ExpressionUUID->"303f1c21-8b6a-4cf8-8b83-d825145c9d83",
 InitializationCell->True],
Cell[81101, 2447, 862, 21, 56, "Text",ExpressionUUID->"2264fc0e-c2db-4210-a671-3c2f3941e6aa"],
Cell[81966, 2470, 745, 21, 39, "Text",ExpressionUUID->"77f6b445-a636-4ffb-81b7-7487e852511c"],
Cell[CellGroupData[{
Cell[82736, 2495, 474, 13, 51, "Input",ExpressionUUID->"f18a8c25-5919-4730-af28-ee49dedf3999",
 InitializationCell->True],
Cell[83213, 2510, 243, 5, 31, "Output",ExpressionUUID->"a4163ad6-5955-4a06-96e1-74c8e7d0b2fa"]
}, Open  ]],
Cell[83471, 2518, 213, 5, 24, "Text",ExpressionUUID->"080e127a-06a6-45f1-94ab-088ad1231ede"],
Cell[CellGroupData[{
Cell[83709, 2527, 164, 3, 31, "Input",ExpressionUUID->"88e1d0db-1cc6-4032-a551-854f29f5de29"],
Cell[83876, 2532, 643, 23, 62, "Output",ExpressionUUID->"86547043-799c-4097-a2d4-d94031dbd444"]
}, Open  ]],
Cell[84534, 2558, 485, 13, 40, "Text",ExpressionUUID->"4f022a14-a97c-4097-bb72-a345d776d98f"],
Cell[CellGroupData[{
Cell[85044, 2575, 106, 1, 31, "Input",ExpressionUUID->"12c3c2e3-6f66-4f7f-9d86-09bf46e2bfe5"],
Cell[85153, 2578, 573, 16, 64, "Output",ExpressionUUID->"f9020c75-7656-44b7-810f-fc969a822c66"]
}, Open  ]],
Cell[85741, 2597, 991, 25, 78, "Text",ExpressionUUID->"17da2d36-d51d-449d-b986-1296f734bbf5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86769, 2627, 112, 0, 18, "Subsubsection",ExpressionUUID->"654d4e8b-1488-432e-a574-3370380867b2"],
Cell[86884, 2629, 294, 4, 35, "Text",ExpressionUUID->"9a8859f9-5d1c-455c-8f19-1da7b66f43f5"],
Cell[87181, 2635, 329, 11, 26, "Equation",ExpressionUUID->"71e2f4b5-4fc6-4369-a0c3-ddb2cca8a63b"],
Cell[87513, 2648, 98, 0, 20, "Text",ExpressionUUID->"7d1f3cbd-2871-400d-b382-4b7f3587fade"],
Cell[CellGroupData[{
Cell[87636, 2652, 275, 7, 31, "Input",ExpressionUUID->"0851f034-4b24-4e15-9ffc-5cc08e2c8ca9",
 InitializationCell->True],
Cell[87914, 2661, 218, 5, 32, "Output",ExpressionUUID->"9c832680-8e55-4472-82d4-9f7908ffbae0"]
}, Open  ]],
Cell[88147, 2669, 85, 0, 20, "Text",ExpressionUUID->"6863c26d-69bf-4ac7-a402-964ce86d97a2"],
Cell[CellGroupData[{
Cell[88257, 2673, 249, 6, 31, "Input",ExpressionUUID->"91c71cfe-6e0d-45cb-84b9-693d3b9ac8af",
 InitializationCell->True],
Cell[88509, 2681, 152, 3, 31, "Output",ExpressionUUID->"b7af534c-a9e5-4c66-b90f-4020340e1c44"]
}, Open  ]],
Cell[88676, 2687, 259, 5, 20, "Text",ExpressionUUID->"c0d1a498-3455-4253-b35b-a8a4bce0d0d8"],
Cell[CellGroupData[{
Cell[88960, 2696, 251, 6, 31, "Input",ExpressionUUID->"8d296261-4aca-4fb2-afa2-a472ae21b73c"],
Cell[89214, 2704, 110, 1, 31, "Output",ExpressionUUID->"5170dd79-277c-4223-877c-6317eb715748"]
}, Open  ]],
Cell[89339, 2708, 322, 7, 20, "Text",ExpressionUUID->"6dac7caa-a8f0-4228-b448-e78507310b21"],
Cell[89664, 2717, 361, 9, 28, "Equation",ExpressionUUID->"caa56a50-5fab-42cd-9873-9f271fbad8b0"],
Cell[90028, 2728, 657, 18, 20, "Text",ExpressionUUID->"de08b8ea-cc73-443b-a9ab-1e0d8cfc3475"],
Cell[90688, 2748, 642, 18, 50, "Equation",ExpressionUUID->"98c41362-e3b7-4714-bbba-1b5618b04663"],
Cell[91333, 2768, 128, 0, 20, "Text",ExpressionUUID->"369fc591-5f23-4519-bf3e-1d19a4ec2353"],
Cell[CellGroupData[{
Cell[91486, 2772, 1027, 30, 70, "Input",ExpressionUUID->"fab7669a-e105-45ee-a2a2-e9b914b4f305",
 InitializationCell->True],
Cell[92516, 2804, 242, 6, 47, "Output",ExpressionUUID->"568dcbaf-f23a-42fc-8c97-e2e807a5b4a4"]
}, Open  ]],
Cell[92773, 2813, 512, 13, 22, "Text",ExpressionUUID->"4a208ca7-ee24-4d1d-8ce3-9f16b61b1bd2"],
Cell[CellGroupData[{
Cell[93310, 2830, 404, 12, 31, "Input",ExpressionUUID->"aca4da73-36c5-4d09-9efd-d82ebacca5b7"],
Cell[93717, 2844, 197, 5, 32, "Output",ExpressionUUID->"a65c0508-cd21-47a8-9b3f-62ee637e263f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93963, 2855, 112, 0, 18, "Subsubsection",ExpressionUUID->"ff0af02b-213b-4fe6-bb1f-18d29c855458"],
Cell[94078, 2857, 425, 6, 54, "Text",ExpressionUUID->"7ca1f596-ba81-4e15-97ab-43a7350331be"],
Cell[94506, 2865, 361, 11, 26, "Equation",ExpressionUUID->"fffc08dd-b4f5-4afb-8ce0-8ccd535e6c6f"],
Cell[94870, 2878, 438, 14, 20, "Text",ExpressionUUID->"3faca974-3cf0-403f-8d1b-5557722aaa11"],
Cell[95311, 2894, 5223, 134, 336, "Input",ExpressionUUID->"c3651833-92e2-4e31-95b5-53aa958434db",
 InitializationCell->True],
Cell[100537, 3030, 302, 6, 39, "Text",ExpressionUUID->"421b4674-29aa-47cc-b512-1363ab979458"],
Cell[CellGroupData[{
Cell[100864, 3040, 217, 5, 31, "Input",ExpressionUUID->"f9396282-6c14-4bbc-98a4-c77d6e6394f8"],
Cell[101084, 3047, 697, 26, 60, "Output",ExpressionUUID->"3d777c8e-7b48-490b-b01c-481d15a41a51"]
}, Open  ]],
Cell[101796, 3076, 106, 0, 20, "Text",ExpressionUUID->"89b6a466-33ce-4c61-a4ac-cc570e6e3baf"],
Cell[CellGroupData[{
Cell[101927, 3080, 236, 6, 31, "Input",ExpressionUUID->"711d2859-d653-4f1e-bc87-e473a6f1be35"],
Cell[102166, 3088, 197, 5, 32, "Output",ExpressionUUID->"769544f5-2d8f-417e-8ebe-28b720043c12"]
}, Open  ]],
Cell[102378, 3096, 308, 4, 35, "Text",ExpressionUUID->"5f45494d-8cfc-48ab-a60e-71c56c2e431d"],
Cell[102689, 3102, 508, 17, 26, "Equation",ExpressionUUID->"93d6969b-0cb2-4bdf-8fde-c9ca3deffc37"],
Cell[103200, 3121, 323, 6, 39, "Text",ExpressionUUID->"14db3f90-11ea-4bdc-a27c-08f80ac57e9c"],
Cell[103526, 3129, 277, 7, 31, "Input",ExpressionUUID->"12389314-7da9-4ec2-93ee-7c842e19f538",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[103828, 3140, 286, 7, 31, "Input",ExpressionUUID->"cf882c47-159e-4df1-95a6-30709351f45e"],
Cell[104117, 3149, 254, 5, 31, "Output",ExpressionUUID->"c309932f-e9e9-4240-83f1-1917ec42f31e"]
}, Open  ]],
Cell[104386, 3157, 141, 2, 20, "Text",ExpressionUUID->"33bc1fbb-25d6-470b-bb97-46073b882d76"],
Cell[104530, 3161, 307, 10, 26, "Equation",ExpressionUUID->"794f2195-af85-485c-9bf2-997d859b3897"],
Cell[104840, 3173, 438, 14, 20, "Text",ExpressionUUID->"0b99b2a6-5927-40a8-bb71-3c592d1c9f82"],
Cell[CellGroupData[{
Cell[105303, 3191, 358, 10, 51, "Input",ExpressionUUID->"1cb2ec1f-46b7-4566-9db5-023df2ca42e9",
 InitializationCell->True],
Cell[105664, 3203, 1155, 42, 63, "Output",ExpressionUUID->"2c9ff2e5-7821-4583-940c-bc59919bf0f1"]
}, Open  ]],
Cell[106834, 3248, 409, 9, 35, "Text",ExpressionUUID->"06decb25-4e97-4406-bfa0-2b9121fb3d4f"],
Cell[CellGroupData[{
Cell[107268, 3261, 286, 7, 31, "Input",ExpressionUUID->"dfc3b10c-62e2-48d9-bc64-d08d1545aeca"],
Cell[107557, 3270, 289, 6, 31, "Output",ExpressionUUID->"51ff6713-5e49-4825-935d-0f5c2e8f97f9"]
}, Open  ]],
Cell[107861, 3279, 245, 5, 20, "Text",ExpressionUUID->"460f3583-9c9d-485a-b9f8-793eaa01ceaf"],
Cell[CellGroupData[{
Cell[108131, 3288, 370, 10, 51, "Input",ExpressionUUID->"ddd15485-89bb-4da9-8edf-dcd38c892d70",
 InitializationCell->True],
Cell[108504, 3300, 1210, 43, 63, "Output",ExpressionUUID->"bde861b9-7d88-4f71-a00c-53f05e27c472"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109751, 3348, 286, 7, 31, "Input",ExpressionUUID->"cb2497cc-0c46-49e4-b53e-c557382d27c8"],
Cell[110040, 3357, 455, 12, 31, "Output",ExpressionUUID->"06c839ca-6a28-4269-879e-b23de263e7fe"]
}, Open  ]],
Cell[110510, 3372, 281, 4, 35, "Text",ExpressionUUID->"400eca21-8e92-4119-a756-034a292c7e6d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110840, 3382, 136, 1, 32, "Subsection",ExpressionUUID->"eaaff216-bb72-4fa2-bf9c-f297be33940a",
 CellTags->"Section2b"],
Cell[110979, 3385, 396, 6, 50, "Text",ExpressionUUID->"af610aba-b09f-4456-8246-17b9add99072"],
Cell[111378, 3393, 552, 18, 26, "Equation",ExpressionUUID->"9de55e70-d39b-4ae7-9ff9-1f08c991d32d"],
Cell[111933, 3413, 1034, 26, 50, "Text",ExpressionUUID->"05abdf17-2aa1-43d6-8318-b0efd4f0fae0"],
Cell[112970, 3441, 103, 0, 20, "Text",ExpressionUUID->"f69463cc-5ee5-4b27-b4f7-d3b049f67a1d"],
Cell[113076, 3443, 402, 13, 26, "Equation",ExpressionUUID->"ebaee1e7-1693-42ac-aa8d-b1427961dc81"],
Cell[113481, 3458, 114, 0, 20, "Text",ExpressionUUID->"ca88b651-7c48-400a-ad50-1db3c4fc7119"],
Cell[113598, 3460, 170, 3, 20, "Text",ExpressionUUID->"1623ee01-0608-4f26-924a-23af21dfebfa"],
Cell[113771, 3465, 329, 11, 26, "Equation",ExpressionUUID->"4294e357-c5a4-49cf-8814-cd9ca3fdc81d"],
Cell[114103, 3478, 248, 5, 24, "Text",ExpressionUUID->"09635580-fd4a-4df3-b108-68ba49eda592"],
Cell[CellGroupData[{
Cell[114376, 3487, 366, 9, 51, "Input",ExpressionUUID->"3c00d87a-510f-4357-937c-0172607f3dff",
 InitializationCell->True],
Cell[114745, 3498, 530, 18, 32, "Output",ExpressionUUID->"b483c7b5-1e34-4848-adb6-91e6f8aa2d87"]
}, Open  ]],
Cell[115290, 3519, 809, 17, 69, "Text",ExpressionUUID->"af9a0ae3-be35-496a-8606-d497507da310"],
Cell[116102, 3538, 275, 8, 29, "Equation",ExpressionUUID->"9b5c6669-6567-46d4-8a0b-2d6a50904d9e"],
Cell[116380, 3548, 146, 2, 20, "Text",ExpressionUUID->"f8ad793a-9708-4906-ace3-5cd1c608f1df"],
Cell[CellGroupData[{
Cell[116551, 3554, 344, 10, 31, "Input",ExpressionUUID->"376bb80a-6fdf-4883-9088-313def479341",
 InitializationCell->True],
Cell[116898, 3566, 259, 7, 32, "Output",ExpressionUUID->"a8c90fcd-0455-45b0-a46c-e53bc61ef5da"]
}, Open  ]],
Cell[117172, 3576, 883, 24, 39, "Text",ExpressionUUID->"b1d9e0b1-6195-44ff-b65e-2a031dc9acec"],
Cell[CellGroupData[{
Cell[118080, 3604, 480, 14, 31, "Input",ExpressionUUID->"2e639f58-d430-4e0b-a79f-168242c9e990",
 InitializationCell->True],
Cell[118563, 3620, 1043, 37, 32, "Output",ExpressionUUID->"909b1130-68f5-4004-8eb3-034a113c08f0"]
}, Open  ]],
Cell[119621, 3660, 230, 6, 21, "Text",ExpressionUUID->"18d230a3-d356-456a-8b1a-ac8390b70788"],
Cell[CellGroupData[{
Cell[119876, 3670, 196, 4, 31, "Input",ExpressionUUID->"98056576-8c5e-4d97-baf6-e45260265ba9",
 InitializationCell->True],
Cell[120075, 3676, 451, 14, 31, "Output",ExpressionUUID->"752da592-e221-4f56-a3fc-d62914d53f4c"]
}, Open  ]],
Cell[120541, 3693, 990, 31, 35, "Text",ExpressionUUID->"becea88c-e5f7-4339-bff2-64ce6686e4ca"],
Cell[121534, 3726, 483, 16, 26, "Equation",ExpressionUUID->"44321418-5a6a-4258-8937-8cb68afeb2b8"],
Cell[122020, 3744, 684, 17, 58, "Text",ExpressionUUID->"116cbddc-6617-45e2-ae82-cb8c229470a4"],
Cell[CellGroupData[{
Cell[122729, 3765, 330, 9, 31, "Input",ExpressionUUID->"f15f6f13-8140-45ba-89ae-2bb6609fb9e5",
 InitializationCell->True],
Cell[123062, 3776, 286, 8, 47, "Output",ExpressionUUID->"9dc90fbf-f016-4482-a876-20631133bcd4"]
}, Open  ]],
Cell[123363, 3787, 104, 0, 20, "Text",ExpressionUUID->"a5442893-40d3-4453-bf40-6113d0533a98"],
Cell[CellGroupData[{
Cell[123492, 3791, 217, 5, 31, "Input",ExpressionUUID->"5ed943f6-10b2-47d2-9aab-0919b1371820"],
Cell[123712, 3798, 280, 8, 47, "Output",ExpressionUUID->"28182ac4-8fdb-44f7-bafa-af14f0f896df"]
}, Open  ]],
Cell[124007, 3809, 661, 19, 20, "Text",ExpressionUUID->"69e021d0-00fb-4ec6-a47b-4da0ff8fa8af"],
Cell[CellGroupData[{
Cell[124693, 3832, 306, 8, 31, "Input",ExpressionUUID->"acdb790d-0476-42b9-acd9-bd88e562e46d"],
Cell[125002, 3842, 720, 25, 47, "Output",ExpressionUUID->"50b71482-15a5-4f48-bebd-824372463699"]
}, Open  ]],
Cell[125737, 3870, 125, 0, 20, "Text",ExpressionUUID->"d7cf57c6-041d-4723-b465-67415e36b6d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125899, 3875, 202, 5, 32, "Subsection",ExpressionUUID->"06538a81-a148-4776-9511-e73252624068",
 CellTags->"Section2c"],
Cell[126104, 3882, 338, 7, 35, "Text",ExpressionUUID->"8a02b186-e551-4809-bb04-bc51f7f4e60d"],
Cell[126445, 3891, 1686, 42, 144, "Text",ExpressionUUID->"8ac5fbb7-3fdc-4344-a912-0b1bd308ab1a"],
Cell[128134, 3935, 727, 22, 20, "Text",ExpressionUUID->"5d474616-5ee7-429c-a6d7-fb45e1d26cf3"],
Cell[CellGroupData[{
Cell[128886, 3961, 657, 18, 31, "Input",ExpressionUUID->"61b69945-cdd6-4365-bbc8-0e642ebfaad6"],
Cell[129546, 3981, 455, 14, 47, "Output",ExpressionUUID->"724933a5-fc7c-4743-b527-120006d66e29"]
}, Open  ]],
Cell[130016, 3998, 375, 7, 36, "Text",ExpressionUUID->"ef70cf4a-a1b9-4792-889c-5707e5bc42b0"],
Cell[130394, 4007, 522, 15, 43, "Text",ExpressionUUID->"773477e1-ea9b-40f6-8d2c-351a9b01a284"],
Cell[CellGroupData[{
Cell[130941, 4026, 199, 4, 31, "Input",ExpressionUUID->"50139a77-2fd1-4d44-981d-7bece3f0af69"],
Cell[131143, 4032, 323, 10, 47, "Output",ExpressionUUID->"fe9a7ad1-22f2-4a68-80b2-88ee2fa93b21"]
}, Open  ]],
Cell[131481, 4045, 411, 9, 39, "Text",ExpressionUUID->"bf8146a8-5070-4355-a5d7-59c25805e46a"],
Cell[131895, 4056, 475, 15, 47, "myCode",ExpressionUUID->"0599594c-25b5-4696-b031-aec1e20f15f9"],
Cell[132373, 4073, 794, 25, 49, "Text",ExpressionUUID->"02c7dbd0-d60a-4792-9db4-b9606818b7d1"],
Cell[133170, 4100, 522, 15, 43, "Text",ExpressionUUID->"d62d9b97-a7fc-4f64-a256-6781e7de0738"],
Cell[CellGroupData[{
Cell[133717, 4119, 660, 19, 31, "Input",ExpressionUUID->"0cb5e465-174f-4f91-aaf2-b2659bb75fdf",
 InitializationCell->True],
Cell[134380, 4140, 536, 17, 47, "Output",ExpressionUUID->"c5747ec1-40ed-4fb6-9362-f07202f790dd"]
}, Open  ]],
Cell[134931, 4160, 565, 12, 55, "Text",ExpressionUUID->"66887bbb-898c-4498-af91-100160d889b9"],
Cell[CellGroupData[{
Cell[135521, 4176, 223, 5, 31, "Input",ExpressionUUID->"c8b4db44-0572-43dc-8859-d07c20006ed3",
 InitializationCell->True],
Cell[135747, 4183, 422, 13, 47, "Output",ExpressionUUID->"218ac2da-447d-4aa1-a21d-946190455677"]
}, Open  ]],
Cell[136184, 4199, 151, 4, 24, "Text",ExpressionUUID->"a4d34a18-287d-4487-b6a5-732bec9938e2"],
Cell[CellGroupData[{
Cell[136360, 4207, 134, 2, 31, "Input",ExpressionUUID->"ef096864-eeb9-483d-84a5-23107dfb42b1"],
Cell[136497, 4211, 119, 1, 31, "Output",ExpressionUUID->"e40f3d59-f263-4207-a2b5-9fd4b53faf7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136653, 4217, 249, 6, 31, "Input",ExpressionUUID->"3939989d-e955-467b-8e3d-b577573f7ec0"],
Cell[136905, 4225, 247, 5, 31, "Output",ExpressionUUID->"9e96f9f7-ad43-4e10-8896-79a6cea4e234"]
}, Open  ]],
Cell[137167, 4233, 269, 6, 21, "Text",ExpressionUUID->"4c1594cf-1868-45bd-aaa1-78ead0c8cc5e"],
Cell[CellGroupData[{
Cell[137461, 4243, 649, 18, 31, "Input",ExpressionUUID->"7cd2d5bd-b876-4b00-934e-ac9a4d08b8f2"],
Cell[138113, 4263, 247, 5, 31, "Output",ExpressionUUID->"e7c3233a-99bb-4305-84c2-3c53b5c1a532"]
}, Open  ]],
Cell[138375, 4271, 378, 8, 36, "Text",ExpressionUUID->"97fa47f1-0a1c-425e-9eb4-5ecdf0bc00cb"],
Cell[138756, 4281, 273, 8, 26, "Equation",ExpressionUUID->"5299f612-fb21-40cc-840a-ef77577de30a"],
Cell[139032, 4291, 271, 8, 20, "Text",ExpressionUUID->"77b4d4de-64da-449d-b48d-16a0f711d229"],
Cell[CellGroupData[{
Cell[139328, 4303, 697, 20, 51, "Input",ExpressionUUID->"f2c9f5ca-b0ee-4bb6-bcd2-e7afffe4993c",
 InitializationCell->True],
Cell[140028, 4325, 258, 7, 33, "Output",ExpressionUUID->"57f7265c-1bdb-4049-b41f-16aef0ab8b04"]
}, Open  ]],
Cell[140301, 4335, 797, 20, 59, "Text",ExpressionUUID->"ac25e97c-0085-4c7d-bc84-39381c39b878"],
Cell[141101, 4357, 576, 14, 55, "Text",ExpressionUUID->"9826e36b-1c4a-4d9c-923f-b210eb8be67f"],
Cell[CellGroupData[{
Cell[141702, 4375, 646, 19, 51, "Input",ExpressionUUID->"d849e09f-bfd2-448a-846b-3b5dcb8f0805",
 InitializationCell->True],
Cell[142351, 4396, 608, 19, 38, "Output",ExpressionUUID->"5672d34d-30ab-4bd3-b3df-dd0a3c35b9d5"]
}, Open  ]],
Cell[142974, 4418, 207, 5, 24, "Text",ExpressionUUID->"7e9d001f-be62-429c-aaac-d89d72c8248e"],
Cell[CellGroupData[{
Cell[143206, 4427, 133, 2, 31, "Input",ExpressionUUID->"59451adf-f53d-4694-ac21-bcd48b913cc7"],
Cell[143342, 4431, 497, 16, 35, "Output",ExpressionUUID->"f17ec076-fa9f-469d-8317-55d7d181711d"]
}, Open  ]],
Cell[143854, 4450, 726, 17, 52, "Text",ExpressionUUID->"bdce3446-ddb8-4a7f-821c-be83db9a50ef"],
Cell[CellGroupData[{
Cell[144605, 4471, 468, 14, 31, "Input",ExpressionUUID->"bf3b522b-2fcb-46bb-a828-375e9df31e15"],
Cell[145076, 4487, 553, 17, 34, "Output",ExpressionUUID->"5a0c4708-e968-4c6b-9fa4-498ee7272de5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[145678, 4510, 216, 6, 32, "Subsection",ExpressionUUID->"552a7a6a-43d2-44b7-b485-820bafe2f4c8",
 CellTags->"Section2d"],
Cell[145897, 4518, 395, 7, 35, "Text",ExpressionUUID->"51fdbca4-bf0a-4648-ae45-84426032f4e7"],
Cell[146295, 4527, 437, 8, 35, "Text",ExpressionUUID->"a4469702-c2d7-4692-9222-c1a95f959ce7"],
Cell[146735, 4537, 1606, 41, 80, "Text",ExpressionUUID->"a8d02776-652d-4c04-b511-75b39e865d98"],
Cell[148344, 4580, 899, 17, 252, "Text",ExpressionUUID->"4339e3d7-9694-458c-90a3-d15df57955ec"],
Cell[149246, 4599, 2476, 64, 125, "Text",ExpressionUUID->"7c7a0e9f-9e3b-4370-8744-eaad8f3fd2de"],
Cell[151725, 4665, 1115, 21, 252, "Text",ExpressionUUID->"b8272d18-cc17-47ea-ae2a-2f3482d58c0f"],
Cell[152843, 4688, 349, 8, 20, "Text",ExpressionUUID->"94436269-9014-47ac-b5d6-c2312113335e"],
Cell[CellGroupData[{
Cell[153217, 4700, 664, 19, 51, "Input",ExpressionUUID->"841df724-3d9e-4df8-9ccb-2114118331f4",
 InitializationCell->True],
Cell[153884, 4721, 324, 9, 47, "Output",ExpressionUUID->"d29f8b7d-ffe8-4c6f-b0e9-3936bca29e4f"]
}, Open  ]],
Cell[154223, 4733, 202, 3, 20, "Text",ExpressionUUID->"979b6697-5571-4f2c-9fc8-f85e99b604b0"],
Cell[CellGroupData[{
Cell[154450, 4740, 136, 2, 31, "Input",ExpressionUUID->"96410e39-20b8-4ed8-9aa2-10dc47f94137"],
Cell[154589, 4744, 112, 1, 31, "Output",ExpressionUUID->"b442956d-4be0-4f52-b35b-7b967301c27f"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[154762, 4752, 155, 1, 55, "Section",ExpressionUUID->"3707c835-8de7-4194-9348-ae560cfbadf7",
 CellTags->"Section3"],
Cell[154920, 4755, 474, 7, 50, "Text",ExpressionUUID->"f42c7728-84a6-455c-8914-57883eed3ced"],
Cell[155397, 4764, 1863, 47, 336, "Input",ExpressionUUID->"91599cc8-3ea9-4831-b4a7-dd9be3c878c8",
 InitializationCell->True],
Cell[157263, 4813, 1067, 29, 96, "Text",ExpressionUUID->"ad9b521e-d693-44a8-94d5-b8eccbeeefda"],
Cell[158333, 4844, 259, 4, 35, "Text",ExpressionUUID->"1625fca2-75a3-4552-9df4-a404ada2b76b"],
Cell[158595, 4850, 315, 9, 26, "Equation",ExpressionUUID->"8aebe563-a3ea-4ce5-afe4-d04fb50ea6c0"],
Cell[158913, 4861, 1206, 31, 74, "Text",ExpressionUUID->"e616bb15-485c-47dc-b916-40105095e086"],
Cell[160122, 4894, 250, 8, 26, "Equation",ExpressionUUID->"6a0dd28a-872f-4e1c-b9c0-95d969ac174f"],
Cell[160375, 4904, 767, 18, 52, "Text",ExpressionUUID->"cfc5e730-b673-47c5-a268-28e9f8e54e41"],
Cell[CellGroupData[{
Cell[161167, 4926, 468, 13, 31, "Input",ExpressionUUID->"7a25c73c-cc0e-45ea-a672-5e4c29a00e35"],
Cell[161638, 4941, 390, 12, 50, "Output",ExpressionUUID->"c5097e66-3d01-4fe8-bdab-00af99a48601"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[162077, 4959, 121, 1, 55, "Section",ExpressionUUID->"827c836d-20e9-4288-b62e-388b8a027ebb",
 CellTags->"Section4"],
Cell[162201, 4962, 366, 7, 35, "Text",ExpressionUUID->"dcb0cd60-e3e5-422b-8abd-6517837d4d61"],
Cell[162570, 4971, 456, 13, 20, "Text",ExpressionUUID->"ba55d524-b942-4349-baff-ee27a6fd6744"],
Cell[163029, 4986, 735, 24, 51, "Equation",ExpressionUUID->"95da0964-36b0-47f7-997c-a3bf29348dd5"],
Cell[163767, 5012, 425, 8, 35, "Text",ExpressionUUID->"955655cc-7890-4267-8d42-5c89f136f87a"],
Cell[CellGroupData[{
Cell[164217, 5024, 127, 1, 32, "Subsection",ExpressionUUID->"d61c0a35-b91a-4225-a30f-b2c18ffb08c2",
 CellTags->"Section4a"],
Cell[164347, 5027, 170, 3, 20, "Text",ExpressionUUID->"57793ff1-a747-4dd7-9b18-e403c9edad8f"],
Cell[164520, 5032, 927, 19, 66, "Text",ExpressionUUID->"054d412e-2102-45c0-b62c-86e7c6837c30"],
Cell[165450, 5053, 341, 8, 26, "Text",ExpressionUUID->"a41feb07-fb3b-44ff-bbe8-0d02f550dc28"],
Cell[CellGroupData[{
Cell[165816, 5065, 207, 4, 31, "Input",ExpressionUUID->"518a8760-ca64-45f2-885b-e6c4202314dc"],
Cell[166026, 5071, 174, 4, 47, "Output",ExpressionUUID->"98cf2919-f3c7-4474-9417-b964d4775980"]
}, Open  ]],
Cell[166215, 5078, 388, 8, 35, "Text",ExpressionUUID->"765266fe-9a7d-4c32-9081-cc714fac8b39"],
Cell[166606, 5088, 783, 17, 51, "Text",ExpressionUUID->"f8d1abe5-7b2f-4fc9-a4f9-6aff4276ebf8"],
Cell[167392, 5107, 967, 26, 70, "Text",ExpressionUUID->"98a46fda-cc03-4116-b71a-a42a7f8ea600"],
Cell[CellGroupData[{
Cell[168384, 5137, 382, 11, 31, "Input",ExpressionUUID->"11fc4d62-da64-47d1-8767-8569da609d91",
 InitializationCell->True],
Cell[168769, 5150, 1018, 30, 32, "Output",ExpressionUUID->"123f4c03-b8d4-49bf-ae29-440fc0f254c4"]
}, Open  ]],
Cell[169802, 5183, 419, 10, 24, "Text",ExpressionUUID->"5ebc9529-e356-4a9d-b504-ebbc21fb7ba8"],
Cell[170224, 5195, 384, 8, 36, "Text",ExpressionUUID->"69473794-5177-42de-8b5f-bc769ba78f7f"],
Cell[CellGroupData[{
Cell[170633, 5207, 177, 3, 31, "Input",ExpressionUUID->"430348bc-c401-4c76-9536-861fbc73fb2f"],
Cell[170813, 5212, 269, 5, 31, "Output",ExpressionUUID->"e5f7cb34-e1e0-42c2-aee2-bb5ba29c2da0"]
}, Open  ]],
Cell[171097, 5220, 1229, 35, 52, "Text",ExpressionUUID->"2704cb6e-f229-425b-9a7e-ac2effd2ef73"],
Cell[172329, 5257, 785, 19, 56, "Text",ExpressionUUID->"74cf0266-0121-43f3-8ef8-d8f684bdca5c"],
Cell[CellGroupData[{
Cell[173139, 5280, 898, 24, 70, "Input",ExpressionUUID->"bd24dbaa-3abe-4afc-a6bd-61466f3bc693",
 InitializationCell->True],
Cell[174040, 5306, 233, 6, 47, "Output",ExpressionUUID->"b19cf55b-c500-41bc-a0c3-fcbee5b80a07"]
}, Open  ]],
Cell[174288, 5315, 250, 6, 21, "Text",ExpressionUUID->"3bae876a-bc5e-4850-9f3c-eb351bb9228c"],
Cell[CellGroupData[{
Cell[174563, 5325, 268, 5, 31, "Input",ExpressionUUID->"1ea1a66f-30de-4bf3-a7f6-175238d4ac7f",
 InitializationCell->True],
Cell[174834, 5332, 298, 9, 54, "Output",ExpressionUUID->"78f29ef3-f21c-41e0-b5f6-6678c227be70"]
}, Open  ]],
Cell[175147, 5344, 255, 6, 21, "Text",ExpressionUUID->"d423d6a4-e73e-4356-91a7-07c5fb0eeb27"],
Cell[CellGroupData[{
Cell[175427, 5354, 306, 7, 31, "Input",ExpressionUUID->"35d725e5-526f-482e-896f-2456180124ed",
 InitializationCell->True],
Cell[175736, 5363, 659, 19, 32, "Output",ExpressionUUID->"79e0874a-a5fb-4fae-887f-309e4ff7f9e8"]
}, Open  ]],
Cell[176410, 5385, 1165, 26, 85, "Text",ExpressionUUID->"83488fe6-ae86-4648-84bb-086a9ca7e480"],
Cell[CellGroupData[{
Cell[177600, 5415, 187, 3, 31, "Input",ExpressionUUID->"d2b54227-39b3-4512-8ef4-3e13ba05f03c"],
Cell[177790, 5420, 107, 1, 31, "Output",ExpressionUUID->"9138673a-b3b8-42c7-993e-89c4651a18df"]
}, Open  ]],
Cell[177912, 5424, 1249, 32, 52, "Text",ExpressionUUID->"f49520fd-8b2d-4005-bf54-9f2fba0a0b64"],
Cell[CellGroupData[{
Cell[179186, 5460, 249, 5, 31, "Input",ExpressionUUID->"cf1140fe-2b9a-4ac9-876d-4c6b44d3608f"],
Cell[179438, 5467, 107, 1, 31, "Output",ExpressionUUID->"8bbeb50f-406d-4d69-90c5-c4015358aaed"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[179594, 5474, 143, 1, 32, "Subsection",ExpressionUUID->"6c056ec8-20af-4ade-ad4c-2352b9692cf0",
 CellTags->"Section4b"],
Cell[179740, 5477, 610, 10, 65, "Text",ExpressionUUID->"0ce079ae-05e3-4bb9-90f3-045cc4cfdcc7"],
Cell[180353, 5489, 484, 8, 41, "Item1Paragraph",ExpressionUUID->"9327fb96-278f-4baf-ad3d-085f5b346778"],
Cell[180840, 5499, 346, 8, 20, "Text",ExpressionUUID->"0eefb3ad-cb1f-4869-a587-a711634ba8ba"],
Cell[181189, 5509, 644, 18, 36, "Equation",ExpressionUUID->"8909390a-5f2f-4b7c-8a1e-5860515e8d5f"],
Cell[181836, 5529, 507, 9, 51, "Text",ExpressionUUID->"060d34d2-f868-4e8a-bacc-c214dcc7db55"],
Cell[CellGroupData[{
Cell[182368, 5542, 240, 5, 31, "Input",ExpressionUUID->"6818cc62-cbb5-4756-8411-4601a33294e2",
 InitializationCell->True],
Cell[182611, 5549, 150, 3, 47, "Output",ExpressionUUID->"5995b411-3f57-4506-bfcb-3404e983a888"]
}, Open  ]],
Cell[182776, 5555, 1102, 27, 71, "Text",ExpressionUUID->"7fc90471-fbb9-4bf6-a39c-dfb591fa3e6a"],
Cell[183881, 5584, 679, 16, 52, "Text",ExpressionUUID->"47aedbc5-80d3-493a-a7a8-784ceb2fbe0d"],
Cell[CellGroupData[{
Cell[184585, 5604, 361, 10, 31, "Input",ExpressionUUID->"b0a078b6-2027-481c-af93-9795bd142c1a",
 InitializationCell->True],
Cell[184949, 5616, 175, 4, 48, "Output",ExpressionUUID->"c797f640-0742-4616-a586-200b57005b89"]
}, Open  ]],
Cell[185139, 5623, 220, 5, 20, "Text",ExpressionUUID->"2bea4771-38d0-4143-8b4c-967d12d52e88"],
Cell[185362, 5630, 528, 14, 48, "Text",ExpressionUUID->"bfd9c100-4237-471f-9694-958b99f35c27"],
Cell[CellGroupData[{
Cell[185915, 5648, 259, 7, 31, "Input",ExpressionUUID->"ec5a605a-8bb8-4e7d-a701-2515d1cd8e52",
 InitializationCell->True],
Cell[186177, 5657, 175, 4, 48, "Output",ExpressionUUID->"49340987-293c-4180-949f-1b1ff390999d"]
}, Open  ]],
Cell[186367, 5664, 597, 17, 24, "Text",ExpressionUUID->"530da518-fb80-4207-80f4-c04a531538da"],
Cell[CellGroupData[{
Cell[186989, 5685, 227, 5, 31, "Input",ExpressionUUID->"d7c9d6b2-58a3-4c13-b697-cb9c353907cb"],
Cell[187219, 5692, 576, 15, 32, "Output",ExpressionUUID->"b9c8aec7-bb31-4f5a-a344-e245ba0246f6"]
}, Open  ]],
Cell[187810, 5710, 320, 6, 21, "Text",ExpressionUUID->"ebcbd7dc-74b3-4ff8-92ac-636512f67935"],
Cell[CellGroupData[{
Cell[188155, 5720, 211, 4, 31, "Input",ExpressionUUID->"a094ba5a-fca5-4b20-93fe-67d7a24572a3",
 InitializationCell->True],
Cell[188369, 5726, 361, 11, 53, "Output",ExpressionUUID->"e8dbe4b8-be5e-47a4-b735-afe6ae09d408"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188767, 5742, 225, 5, 31, "Input",ExpressionUUID->"191101f4-dfff-4667-969b-b1e3b71900c4"],
Cell[188995, 5749, 757, 22, 32, "Output",ExpressionUUID->"9a476be6-fe76-4331-91b7-913630418071"]
}, Open  ]],
Cell[189767, 5774, 632, 15, 41, "Text",ExpressionUUID->"89efee9d-22aa-4cf3-b0f7-f2c9cf86f9fd"],
Cell[CellGroupData[{
Cell[190424, 5793, 238, 5, 31, "Input",ExpressionUUID->"690b6c65-bbf9-4d80-b942-e336415af613"],
Cell[190665, 5800, 110, 1, 31, "Output",ExpressionUUID->"e7e296c6-376c-49c8-9c7f-086540459ed9"]
}, Open  ]],
Cell[190790, 5804, 213, 3, 20, "Text",ExpressionUUID->"06f52a91-92fc-4800-8da2-f1b0f0af5e00"],
Cell[191006, 5809, 634, 20, 54, "Equation",ExpressionUUID->"3966db4f-6ada-418f-82d4-13dfe0fa40b3"],
Cell[191643, 5831, 354, 10, 21, "Text",ExpressionUUID->"c8a683d8-3d90-499f-898e-443d4a0fa292"],
Cell[CellGroupData[{
Cell[192022, 5845, 427, 12, 31, "Input",ExpressionUUID->"054025f7-0499-4c4f-8ea3-91370660aed3",
 InitializationCell->True],
Cell[192452, 5859, 220, 5, 48, "Output",ExpressionUUID->"60467956-db50-4cd4-988b-b7fa6c84017e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192709, 5869, 237, 5, 31, "Input",ExpressionUUID->"5559cad3-9e3b-4d46-92ed-b324fc01e526"],
Cell[192949, 5876, 108, 1, 31, "Output",ExpressionUUID->"6dc3bacd-eef1-4a19-b608-332e1c00ebc3"]
}, Open  ]],
Cell[193072, 5880, 322, 7, 23, "Text",ExpressionUUID->"b2cc5d1f-bac1-4a3a-b8e3-1518c329dd3b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[193443, 5893, 126, 1, 55, "Section",ExpressionUUID->"bc3e1ed2-484f-4380-839b-e476fb40560d",
 CellTags->"Section5"],
Cell[193572, 5896, 225, 3, 35, "Text",ExpressionUUID->"326dfc38-5308-4ebc-8ea8-1e1aebae9d40"],
Cell[193800, 5901, 370, 12, 28, "Equation",ExpressionUUID->"5d280777-f835-46d8-93c3-31e2581a7e0d"],
Cell[194173, 5915, 1270, 33, 50, "Text",ExpressionUUID->"70499103-7086-40e1-be2a-0c32f5749dd5"],
Cell[195446, 5950, 234, 3, 35, "Text",ExpressionUUID->"f650b5ff-469a-4b56-a8d2-2b789a326e8b"],
Cell[CellGroupData[{
Cell[195705, 5957, 212, 5, 31, "Input",ExpressionUUID->"7431bf5c-fb77-456f-b221-2a9dd35b0775",
 InitializationCell->True],
Cell[195920, 5964, 162, 3, 31, "Output",ExpressionUUID->"0785606a-1578-407c-9001-7e0eb54cbec8"]
}, Open  ]],
Cell[196097, 5970, 242, 6, 21, "Text",ExpressionUUID->"6a7681b2-dc84-4d05-9fc2-1785ae7913ce"],
Cell[CellGroupData[{
Cell[196364, 5980, 142, 3, 31, "Input",ExpressionUUID->"95c2cf2f-8ab2-4dcb-b798-5d640d519110"],
Cell[196509, 5985, 111, 2, 31, "Output",ExpressionUUID->"8a71b1d1-76a5-4e43-946c-3b7a67444449"]
}, Open  ]],
Cell[196635, 5990, 563, 14, 36, "Text",ExpressionUUID->"352a9490-8225-4a1b-9ada-fc25dabda075"],
Cell[197201, 6006, 411, 13, 51, "Input",ExpressionUUID->"0ef11a52-4e3e-4b78-bb4f-23e96e37fdad",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[197637, 6023, 164, 4, 31, "Input",ExpressionUUID->"9ace9db6-f029-46c1-8160-be92250f2863"],
Cell[197804, 6029, 222, 6, 31, "Output",ExpressionUUID->"58d762f9-c8ab-484c-b82f-b6c90e2c40af"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198063, 6040, 139, 3, 31, "Input",ExpressionUUID->"480afa04-3dc1-4c26-b298-94a9e4019f6c"],
Cell[198205, 6045, 222, 6, 31, "Output",ExpressionUUID->"d94f2ac9-b2c5-4eaa-aa6f-a9a874a226e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198464, 6056, 171, 4, 31, "Input",ExpressionUUID->"74ef6a37-42a4-450e-a2d4-b651238762a9"],
Cell[198638, 6062, 156, 4, 31, "Output",ExpressionUUID->"941a6584-0b74-43b8-8086-779c09050b7c"]
}, Open  ]],
Cell[198809, 6069, 478, 14, 21, "Text",ExpressionUUID->"a8db56c6-e6e4-4536-af4f-91b33a0f8d14"],
Cell[CellGroupData[{
Cell[199312, 6087, 169, 4, 31, "Input",ExpressionUUID->"00edcbe7-adab-4fc2-ad32-c49fe1ffadb6"],
Cell[199484, 6093, 166, 4, 31, "Output",ExpressionUUID->"a0de7b81-dc39-4d2f-a71c-121add715f6e"]
}, Open  ]],
Cell[199665, 6100, 188, 3, 20, "Text",ExpressionUUID->"2e6ff488-585f-4935-999d-8e997be915c1"],
Cell[199856, 6105, 917, 28, 108, "Input",ExpressionUUID->"221c6bc6-b426-4e28-9e3b-553dfd480df9",
 InitializationCell->True],
Cell[200776, 6135, 167, 3, 20, "Text",ExpressionUUID->"3e7ba25d-8437-48b0-ae6c-705b4d5ed177"],
Cell[CellGroupData[{
Cell[200968, 6142, 145, 3, 31, "Input",ExpressionUUID->"6c5f146e-ffa2-48f8-aba7-a704e1fab60c"],
Cell[201116, 6147, 111, 2, 31, "Output",ExpressionUUID->"cc181860-8d51-4ebd-85d3-fdcc48dad117"]
}, Open  ]],
Cell[201242, 6152, 154, 2, 20, "Text",ExpressionUUID->"3b56a5cb-7173-45f4-8ec7-0a651000b0e7"],
Cell[CellGroupData[{
Cell[201421, 6158, 211, 5, 31, "Input",ExpressionUUID->"47add31a-5c44-4896-9631-e115b5d9a28b"],
Cell[201635, 6165, 111, 2, 31, "Output",ExpressionUUID->"c7e6e690-7939-4431-b29d-0fb494bbdfcb"]
}, Open  ]],
Cell[201761, 6170, 170, 3, 20, "Text",ExpressionUUID->"bd973525-4083-4563-bcb9-11eb3baeff25"],
Cell[CellGroupData[{
Cell[201956, 6177, 332, 8, 31, "Input",ExpressionUUID->"ad79b971-50e0-414c-825c-b79946271b86"],
Cell[202291, 6187, 111, 2, 31, "Output",ExpressionUUID->"58c5747d-3206-4f39-90fb-b7b3de3fcd75"]
}, Open  ]],
Cell[202417, 6192, 95, 0, 20, "Text",ExpressionUUID->"eda6f62e-1a46-4e33-9c83-dfdddae56cc1"],
Cell[202515, 6194, 316, 5, 35, "Text",ExpressionUUID->"0f4caa68-b0e8-4eeb-8ab9-e2a879e0273a"],
Cell[CellGroupData[{
Cell[202856, 6203, 199, 5, 31, "Input",ExpressionUUID->"e30d80aa-2204-4340-976f-21f257360210",
 InitializationCell->True],
Cell[203058, 6210, 1291, 20, 108, "Output",ExpressionUUID->"26b6f8ff-2873-4189-b7fc-a485aa4e208c"]
}, Open  ]],
Cell[204364, 6233, 127, 0, 20, "Text",ExpressionUUID->"e560caaa-556d-45dc-b14c-e88272b82bf4"],
Cell[CellGroupData[{
Cell[204516, 6237, 374, 11, 31, "Input",ExpressionUUID->"ded1ae00-7420-4aac-b3fd-f37b473d487c",
 InitializationCell->True],
Cell[204893, 6250, 712, 12, 70, "Output",ExpressionUUID->"6b3c25eb-af07-4087-90f3-5b630e87bdb6"]
}, Open  ]],
Cell[205620, 6265, 107, 0, 20, "Text",ExpressionUUID->"ff47cda3-cb4e-4e29-9766-add804f776e8"],
Cell[CellGroupData[{
Cell[205752, 6269, 375, 11, 31, "Input",ExpressionUUID->"98909643-4ada-4155-8da9-de422fb365c4",
 InitializationCell->True],
Cell[206130, 6282, 1184, 18, 89, "Output",ExpressionUUID->"13365711-172e-4eb1-8327-9f2e87166c8c"]
}, Open  ]],
Cell[207329, 6303, 195, 3, 20, "Text",ExpressionUUID->"a2db659f-5964-42a0-8366-17f4568d0bec"],
Cell[CellGroupData[{
Cell[207549, 6310, 209, 5, 31, "Input",ExpressionUUID->"cfeeab08-f645-4c16-976b-7128d9768574"],
Cell[207761, 6317, 112, 2, 31, "Output",ExpressionUUID->"b8c758e6-544e-4506-b264-52595b42f926"]
}, Open  ]],
Cell[207888, 6322, 172, 3, 20, "Text",ExpressionUUID->"21060c3f-b5af-4adb-bfdd-dd88b1990a62"],
Cell[CellGroupData[{
Cell[208085, 6329, 328, 8, 31, "Input",ExpressionUUID->"e750444f-1bea-42d9-8a9b-f7eb5489b0bb"],
Cell[208416, 6339, 112, 2, 31, "Output",ExpressionUUID->"1299426d-aa82-42f8-b4a5-f85513f3b115"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[208577, 6347, 142, 1, 55, "Section",ExpressionUUID->"bcc9c2a2-2728-4f53-adc7-d02705ee65c3",
 CellTags->"Section6"],
Cell[208722, 6350, 446, 6, 50, "Text",ExpressionUUID->"04f66bd7-b846-4873-96db-e18aeafcc563"],
Cell[209171, 6358, 490, 7, 50, "Text",ExpressionUUID->"733f926e-e64a-434a-a1a3-fc4f925f2868"],
Cell[209664, 6367, 578, 18, 70, "Input",ExpressionUUID->"cf3c8156-b293-43e8-ad25-0208521320da",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[210267, 6389, 239, 6, 31, "Input",ExpressionUUID->"205bc153-7ca1-42d0-b682-9d711c60d9e1",
 InitializationCell->True],
Cell[210509, 6397, 404, 11, 31, "Output",ExpressionUUID->"e77bfa32-02e8-4980-a39d-37cf23c88618"]
}, Open  ]],
Cell[210928, 6411, 328, 7, 35, "Text",ExpressionUUID->"da25e356-bd80-44bb-88fd-65b0702775d2"],
Cell[211259, 6420, 308, 4, 35, "Text",ExpressionUUID->"e446bea9-65ac-4eaf-ac82-c17dc0891079"],
Cell[211570, 6426, 1474, 37, 203, "Input",ExpressionUUID->"4c461936-1818-4532-bba2-bc4734867d38",
 InitializationCell->True],
Cell[213047, 6465, 3181, 89, 161, "Text",ExpressionUUID->"5c78b33e-6aad-464c-b634-3642c9c8e7de"],
Cell[216231, 6556, 237, 7, 24, "Text",ExpressionUUID->"e245bb17-ab02-4303-a100-ddd57e222661"],
Cell[216471, 6565, 649, 17, 51, "Input",ExpressionUUID->"db412539-56e5-47a2-a495-3a5bdc00f942",
 InitializationCell->True],
Cell[217123, 6584, 154, 2, 20, "Text",ExpressionUUID->"ac51711d-2462-4547-936a-fa626614fa0c"],
Cell[CellGroupData[{
Cell[217302, 6590, 154, 3, 31, "Input",ExpressionUUID->"d6bc8b90-5340-40bc-b480-ca198099b5e4"],
Cell[217459, 6595, 115, 2, 31, "Output",ExpressionUUID->"032795db-b733-465e-b3d4-3c5320b2339c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217611, 6602, 154, 3, 31, "Input",ExpressionUUID->"f2da1972-0702-427f-8897-fc6356ce3a14"],
Cell[217768, 6607, 114, 2, 31, "Output",ExpressionUUID->"19d039fd-2ab3-44a0-96b7-67e24e3ce7cb"]
}, Open  ]],
Cell[217897, 6612, 889, 17, 67, "Text",ExpressionUUID->"66db2a6f-9ec3-43a0-bb61-ff7c9f8f3770"],
Cell[218789, 6631, 723, 18, 55, "Text",ExpressionUUID->"18db868b-30f2-42a5-9c61-7e320c90b531"],
Cell[CellGroupData[{
Cell[219537, 6653, 147, 3, 31, "Input",ExpressionUUID->"34a5a4ba-9782-4f45-9119-0ddc656474e2"],
Cell[219687, 6658, 292, 6, 31, "Output",ExpressionUUID->"2adf518c-f5ce-4bf6-b30d-9109a01f3ea0"]
}, Open  ]],
Cell[219994, 6667, 752, 19, 51, "Text",ExpressionUUID->"ad6d662a-bf39-4521-ba6c-49e634f99023"],
Cell[220749, 6688, 865, 21, 73, "Text",ExpressionUUID->"3019d9d2-0bb1-4265-8480-85fa3c54b252"],
Cell[221617, 6711, 346, 10, 31, "Input",ExpressionUUID->"cbc148f8-c244-48be-9b12-5c0314ffceae",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[221988, 6725, 153, 3, 31, "Input",ExpressionUUID->"86bab380-bcaf-4eb0-989b-633141f626fa"],
Cell[222144, 6730, 113, 2, 31, "Output",ExpressionUUID->"d61c21a1-1f0d-4cb6-a281-6b3d54979490"]
}, Open  ]],
Cell[CellGroupData[{
Cell[222294, 6737, 173, 4, 31, "Input",ExpressionUUID->"9b16f703-f413-4461-8e08-a39ee1ff4ce4"],
Cell[222470, 6743, 292, 6, 31, "Output",ExpressionUUID->"5c46366d-dbdb-4734-adf5-e8c46bf2eb57"]
}, Open  ]],
Cell[222777, 6752, 214, 5, 20, "Text",ExpressionUUID->"5f339ea8-0487-41da-8b7a-361829851c4f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223028, 6762, 195, 4, 55, "Section",ExpressionUUID->"0e38ce4f-ee7f-4ee0-a234-b83f6c12a79f",
 PageBreakWithin->False,
 CellTags->"Solutions"],
Cell[CellGroupData[{
Cell[223248, 6770, 177, 4, 32, "Subsection",ExpressionUUID->"b31cf265-6ec8-4ddc-bbd7-d097bbda9a2b",
 PageBreakAbove->False,
 PageBreakWithin->False,
 CellTags->"SolutionsCP12"],
Cell[223428, 6776, 708, 21, 42, "Problem",ExpressionUUID->"74b8f80a-02cc-4b41-8cc8-9a7ede5825d3",
 PageBreakAbove->False,
 PageBreakWithin->False],
Cell[224139, 6799, 168, 4, 20, "Text",ExpressionUUID->"f0a647e6-4518-40b9-9604-f5920504af28"],
Cell[224310, 6805, 490, 16, 53, "Equation",ExpressionUUID->"4a559b73-773c-4a39-9c14-7add5718ae7f"],
Cell[224803, 6823, 1576, 37, 85, "Text",ExpressionUUID->"ff9cf72f-92fe-4496-b275-8edff052c6a7"],
Cell[226382, 6862, 254, 7, 53, "Equation",ExpressionUUID->"57074cbe-aae1-4803-b8d3-39d2a46e4c65"],
Cell[226639, 6871, 113, 0, 20, "Text",ExpressionUUID->"0f2eac2a-ae37-4e92-b0d1-5448179903d1"],
Cell[CellGroupData[{
Cell[226777, 6875, 245, 7, 31, "Input",ExpressionUUID->"d3de9a66-c6ff-42b5-b3d5-fd82a74c3bba"],
Cell[227025, 6884, 135, 3, 47, "Output",ExpressionUUID->"a7efdde2-dde8-4bf7-8526-ccc650a2cf3d"]
}, Open  ]],
Cell[227175, 6890, 128, 0, 20, "Text",ExpressionUUID->"8ce4f345-2959-48dc-b642-28dc2084353a"],
Cell[227306, 6892, 884, 28, 51, "Input",ExpressionUUID->"55833a35-3def-4170-9c04-3690b4ea03a8",
 InitializationCell->True],
Cell[228193, 6922, 715, 18, 55, "Text",ExpressionUUID->"a6bc89d3-89e0-41bd-9d35-1fad5e605d25"],
Cell[CellGroupData[{
Cell[228933, 6944, 172, 4, 31, "Input",ExpressionUUID->"6ea5085b-7c89-4109-a75c-4d5cea282c40"],
Cell[229108, 6950, 111, 2, 31, "Output",ExpressionUUID->"774455c0-724d-43ba-bab8-cd546ace122f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229256, 6957, 191, 5, 31, "Input",ExpressionUUID->"a7b652b5-be49-4ea5-96ca-f151b58d15f5"],
Cell[229450, 6964, 192, 5, 31, "Output",ExpressionUUID->"57ecef77-21aa-48bc-8c65-ac3bf1df271d"]
}, Open  ]],
Cell[229657, 6972, 216, 3, 35, "Text",ExpressionUUID->"acbf63ab-f864-4fad-8459-249016260d20"],
Cell[CellGroupData[{
Cell[229898, 6979, 175, 4, 31, "Input",ExpressionUUID->"e3a3a3a9-1010-4299-aabc-928d58189e74"],
Cell[230076, 6985, 245, 4, 51, "Output",ExpressionUUID->"5787f9e2-05e6-498d-ae34-18916ad93dd9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[230370, 6995, 138, 2, 32, "Subsection",ExpressionUUID->"699e3556-6e7b-46dd-874f-93afdcbbaf6f",
 CellTags->"SolutionsCE2"],
Cell[230511, 6999, 539, 14, 42, "Problem",ExpressionUUID->"92c87551-c109-42d0-b383-c94a67b989a3"],
Cell[231053, 7015, 801, 22, 56, "Text",ExpressionUUID->"d3daa838-2ea8-4690-af8f-07620f707786"],
Cell[231857, 7039, 447, 9, 36, "Text",ExpressionUUID->"8394399b-2035-4b2a-af37-aebd22fa9ce0"],
Cell[232307, 7050, 745, 20, 89, "Input",ExpressionUUID->"a0ed6796-517b-4880-acc4-ff4767a4e4e8",
 InitializationCell->True],
Cell[233055, 7072, 661, 16, 36, "Text",ExpressionUUID->"79f018d7-9469-47c4-88f0-95f76a4d92e0"],
Cell[233719, 7090, 114, 0, 20, "Text",ExpressionUUID->"823c4476-4a99-4b37-b4d2-33db019a4746"],
Cell[CellGroupData[{
Cell[233858, 7094, 149, 3, 31, "Input",ExpressionUUID->"dcf861c5-2151-4048-af29-056ddf6d6298"],
Cell[234010, 7099, 384, 9, 24, "Print",ExpressionUUID->"312cb88b-c98c-4f22-b290-8d83df38ce98"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234431, 7113, 152, 3, 31, "Input",ExpressionUUID->"e6b95102-dfee-4d99-85f0-fa54aa1c74d1"],
Cell[234586, 7118, 390, 9, 24, "Print",ExpressionUUID->"1696dd39-1fd5-4bd2-b094-8ab9b8901ed3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235013, 7132, 155, 3, 31, "Input",ExpressionUUID->"6d52d84b-3cf8-44d4-8f66-e09682aa18fc"],
Cell[235171, 7137, 396, 9, 24, "Print",ExpressionUUID->"e6f46472-e616-4f8e-a028-6db2cab1c949"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[235616, 7152, 138, 2, 32, "Subsection",ExpressionUUID->"65319e19-c333-444b-8489-08a558f02441",
 CellTags->"SolutionsCE3"],
Cell[235757, 7156, 191, 3, 42, "Problem",ExpressionUUID->"14990d1a-926a-44a4-ae39-9b2ffde9f17b"],
Cell[235951, 7161, 1561, 41, 84, "Text",ExpressionUUID->"754cd4a0-df98-4635-a85f-21f776f0678c"],
Cell[237515, 7204, 1219, 32, 203, "Input",ExpressionUUID->"19080887-a4e5-43b9-8b8f-2cc74713b630",
 InitializationCell->True],
Cell[238737, 7238, 147, 2, 20, "Text",ExpressionUUID->"3ff3e77b-341e-49dd-84c1-39b0144d0247"],
Cell[CellGroupData[{
Cell[238909, 7244, 147, 3, 31, "Input",ExpressionUUID->"3d82e3c3-6419-4ed6-888e-281fd413041b"],
Cell[239059, 7249, 395, 8, 70, "Output",ExpressionUUID->"e14f1968-4fa5-43c3-bfcb-24aca44c1939"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[239503, 7263, 140, 2, 32, "Subsection",ExpressionUUID->"f067e8c9-3665-4beb-85e6-1b12296685cf",
 CellTags->"SolutionsCE11"],
Cell[239646, 7267, 523, 12, 55, "Problem",ExpressionUUID->"c34f1a43-5ad4-4e90-acc0-3cbd509ca772"],
Cell[240172, 7281, 363, 9, 20, "Text",ExpressionUUID->"4966d596-715d-4d25-87d0-4f116d2b153a"],
Cell[240538, 7292, 577, 19, 46, "Equation",ExpressionUUID->"0405d2fe-bd21-4459-82f4-f1d0996db673"],
Cell[241118, 7313, 673, 18, 46, "Text",ExpressionUUID->"861bb96f-0a56-4964-8a03-ce3bdef4027b"],
Cell[241794, 7333, 451, 15, 46, "Equation",ExpressionUUID->"16aa2150-069e-441a-8576-f4078c42c861"],
Cell[242248, 7350, 197, 5, 20, "Text",ExpressionUUID->"7734d3a4-2669-4b6d-86e6-c318cf50f6a0"],
Cell[242448, 7357, 520, 17, 31, "Input",ExpressionUUID->"c8c84297-5d4d-4c16-94cd-70af469e4dd5",
 InitializationCell->True],
Cell[242971, 7376, 423, 11, 20, "Text",ExpressionUUID->"4faa2833-de1c-4603-8d2e-c2985a7c36e5"],
Cell[CellGroupData[{
Cell[243419, 7391, 254, 7, 31, "Input",ExpressionUUID->"01acb23a-4e4e-4655-b35d-b84670494eb7"],
Cell[243676, 7400, 995, 23, 119, "Output",ExpressionUUID->"82bd89b8-37a2-4481-b0c2-be28f3ed4b30"]
}, Open  ]],
Cell[244686, 7426, 897, 24, 37, "Text",ExpressionUUID->"f17fe36e-7244-487b-a564-49ede3ba3c93"],
Cell[CellGroupData[{
Cell[245608, 7454, 371, 12, 31, "Input",ExpressionUUID->"c7bf12fc-8f84-48b3-97e2-b776a7c7b01c"],
Cell[245982, 7468, 1307, 24, 116, "Output",ExpressionUUID->"6c42fd53-f3fb-41d8-a472-f7a7c8e6febd"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[247350, 7499, 107, 1, 55, "Section",ExpressionUUID->"4f481c64-033f-47b0-b73b-edf958ab01c2",
 CellTags->"Exercises"],
Cell[CellGroupData[{
Cell[247482, 7504, 172, 3, 20, "Item1Exercise",ExpressionUUID->"723a17ef-549a-4300-871e-67d9f763a6cc"],
Cell[247657, 7509, 248, 4, 33, "Item1Exercise",ExpressionUUID->"2333e000-e0c9-4094-8bf5-5de420e888a0"],
Cell[247908, 7515, 219, 3, 33, "Item1Exercise",ExpressionUUID->"5b5ab776-bb9b-4a96-96f8-99b7afdb9593"],
Cell[248130, 7520, 198, 5, 20, "Item1Exercise",ExpressionUUID->"703242ad-2d82-4199-bdde-432f8d32433f"],
Cell[CellGroupData[{
Cell[248353, 7529, 707, 24, 15, "Item2Exercise",ExpressionUUID->"56a62d72-8454-4138-81af-e617c475e72e"],
Cell[249063, 7555, 821, 28, 25, "Item2Exercise",ExpressionUUID->"64937cd8-a7ee-4751-ad7e-8a90978c3452"]
}, Open  ]],
Cell[249899, 7586, 276, 4, 33, "Item1Exercise",ExpressionUUID->"f372a061-520f-467d-bac0-f40469fa4deb"],
Cell[250178, 7592, 708, 14, 60, "Item1Exercise",ExpressionUUID->"44f866a7-9c4c-4078-9146-d2cd5f4a076b"],
Cell[250889, 7608, 194, 5, 20, "Item1Exercise",ExpressionUUID->"f3905348-f94e-417b-8480-906ecdb9ef1e"],
Cell[251086, 7615, 294, 8, 45, "ExerciseEquation",ExpressionUUID->"54e02d06-e37f-4738-b905-877667fc4564"],
Cell[251383, 7625, 779, 22, 29, "ExerciseContinuation",ExpressionUUID->"0a4bd13e-a057-4ed3-a043-4030024e5153"],
Cell[252165, 7649, 216, 3, 20, "Item1Exercise",ExpressionUUID->"fbea028d-523a-4202-9861-1ab343368810"],
Cell[252384, 7654, 329, 9, 20, "Item1Exercise",ExpressionUUID->"aa0ad607-4730-4d10-8468-0c3a46c97df6"],
Cell[252716, 7665, 364, 9, 20, "Item1Exercise",ExpressionUUID->"44c16abe-9606-4e64-a764-daa766574c19"],
Cell[253083, 7676, 452, 8, 46, "Item1Exercise",ExpressionUUID->"cdcfdff3-b30c-4f0b-8836-1fa397822875"],
Cell[253538, 7686, 1394, 30, 85, "Item1Exercise",ExpressionUUID->"d7921327-6784-420e-b501-e3706375376d"],
Cell[254935, 7718, 432, 8, 33, "Item1Exercise",ExpressionUUID->"f51bfaac-5e9a-4a10-9308-2c18bd29e1d3"],
Cell[255370, 7728, 346, 6, 37, "Item1Exercise",ExpressionUUID->"856c9c2e-fe10-4244-aa00-570dc8912567"],
Cell[255719, 7736, 588, 14, 37, "Item1Exercise",ExpressionUUID->"fe1abec2-bd2e-4a6c-a61d-224dd94e81d4"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

